@@ -7,8 +7,8 @@
  *     Vincent Barichard, 2012
  *
  *  Last modified:
- *     $Date: 2013-07-08 14:22:40 +0200 (Mon, 08 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13820 $
+ *     $Date: 2016-04-19 17:19:45 +0200 (Tue, 19 Apr 2016) $ by $Author: schulte $
+ *     $Revision: 14967 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -56,11 +56,11 @@ using namespace Gecode;
  * \f[
  * \operatorname{abs}(b) = \frac{\operatorname{ln}(\phi)}{\frac{\pi}{2}}
  * \f]
- * 
+ *
  * To get cartesian coordinates, it can be solved for \f$x\f$
  * and \f$y\f$ in terms of \f$r\f$ and \f$\theta\f$.
  * By setting \f$a=1\f$, it yields to the equation:
- * 
+ *
  * \f[
  * r = e^{0.30649\times\theta}
  * \f]
@@ -68,26 +68,24 @@ using namespace Gecode;
  * \f[
  * x=r\operatorname{cos}(\theta), \quad y=r\operatorname{sin}(\theta)
  * \f]
- * 
+ *
  * The tuple \f$(r,\theta)\f$ is related to the position for
  * \f$x\f$ and \f$y\f$ on the curve.  \f$r\f$ and \f$\theta\f$
- * are positive numbers.  
+ * are positive numbers.
  *
  * To get reasonable interval starting sizes, \f$x\f$ and \f$y\f$
  * are restricted to \f$[-20;20]\f$.
  *
  * \ingroup Example
  */
-class GoldenSpiral : public Script {
+class GoldenSpiral : public FloatMaximizeScript {
 protected:
   /// The numbers
   FloatVarArray f;
-  /// Minimum distance between two solutions
-  FloatNum step;
 public:
   /// Actual model
-  GoldenSpiral(const Options&) 
-    : f(*this,4,-20,20), step(0.1) {
+  GoldenSpiral(const Options& opt)
+    : FloatMaximizeScript(opt), f(*this,4,-20,20) {
     // Post equation
     FloatVar theta = f[0];
     FloatVar r = f[3];
@@ -102,18 +100,17 @@ public:
     branch(*this,theta,FLOAT_VAL_SPLIT_MIN());
   }
   /// Constructor for cloning \a p
-  GoldenSpiral(bool share, GoldenSpiral& p) 
-    : Script(share,p), step(p.step) {
+  GoldenSpiral(bool share, GoldenSpiral& p)
+    : FloatMaximizeScript(share,p) {
     f.update(*this,share,p.f);
   }
   /// Copy during cloning
-  virtual Space* copy(bool share) { 
-    return new GoldenSpiral(share,*this); 
+  virtual Space* copy(bool share) {
+    return new GoldenSpiral(share,*this);
   }
-  /// Add constraint to current model to get next solution (not too close)
-  virtual void constrain(const Space& _b) {
-    const GoldenSpiral& b = static_cast<const GoldenSpiral&>(_b);
-    rel(*this, f[0] >= (b.f[0].max()+step));
+  /// Cost function
+  virtual FloatVar cost(void) const {
+    return f[0];
   }
   /// Print solution coordinates
   virtual void print(std::ostream& os) const {
@@ -128,9 +125,10 @@ public:
  */
 int main(int argc, char* argv[]) {
   Options opt("GoldenSpiral");
-  opt.parse(argc,argv);
   opt.solutions(0);
-  Script::run<GoldenSpiral,BAB,Options>(opt);
+  opt.step(0.1);
+  opt.parse(argc,argv);
+  FloatMaximizeScript::run<GoldenSpiral,BAB,Options>(opt);
   return 0;
 }
 
