@@ -11,8 +11,8 @@
  *     Christian Schulte, 2007
  *
  *  Last modified:
- *     $Date: 2015-03-17 16:09:39 +0100 (Tue, 17 Mar 2015) $ by $Author: schulte $
- *     $Revision: 14447 $
+ *     $Date: 2016-04-19 17:19:45 +0200 (Tue, 19 Apr 2016) $ by $Author: schulte $
+ *     $Revision: 14967 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -118,7 +118,7 @@ public:
           for (int j=0; j<k-1; j++)
             rel(*this, p(i,j)+i+2 == p(i,j+1));
 
-        distinct(*this, pv, opt.icl());
+        distinct(*this, pv, opt.ipl());
 
         // Channel positions <-> values
         for (int i=0; i<n; i++)
@@ -155,7 +155,7 @@ public:
         // the sequence on the value.
         REG r0(0), r1(1);
         for (int v=1; v<=n; v++)
-          extensional(*this, b.row(v-1), 
+          extensional(*this, b.row(v-1),
                       *r0 + r1 + (r0(v,v) + r1)(k-1,k-1) + *r0);
       }
       break;
@@ -193,7 +193,7 @@ public:
 int
 main(int argc, char* argv[]) {
   LangfordNumberOptions opt("Langford Numbers",3,9);
-  opt.icl(ICL_DOM);
+  opt.ipl(IPL_DOM);
   opt.propagation(LangfordNumber::PROP_EXTENSIONAL_CHANNEL);
   opt.propagation(LangfordNumber::PROP_REIFIED,
                   "reified");
