@@ -7,8 +7,8 @@
  *     Christian Schulte, 2001
  *
  *  Last modified:
- *     $Date: 2013-07-08 14:22:40 +0200 (Mon, 08 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13820 $
+ *     $Date: 2015-09-11 16:29:45 +0200 (Fri, 11 Sep 2015) $ by $Author: schulte $
+ *     $Revision: 14672 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -59,9 +59,14 @@ private:
   IntVarArray x;
 
 public:
+  /// Branching to use for model
+  enum {
+    BRANCH_SIZE,    ///< Branch by size
+    BRANCH_AFC_SIZE ///< Branch by size over AFC
+  };
   /// Post constraints
   MagicSquare(const SizeOptions& opt)
-    : n(opt.size()), x(*this,n*n,1,n*n) {
+    : Script(opt), n(opt.size()), x(*this,n*n,1,n*n) {
     // Number of fields on square
     const int nn = n*n;
 
@@ -72,8 +77,8 @@ public:
     Matrix<IntVarArray> m(x, n, n);
 
     for (int i = n; i--; ) {
-      linear(*this, m.row(i), IRT_EQ, s, opt.icl());
-      linear(*this, m.col(i), IRT_EQ, s, opt.icl());
+      linear(*this, m.row(i), IRT_EQ, s, opt.ipl());
+      linear(*this, m.col(i), IRT_EQ, s, opt.ipl());
     }
     // Both diagonals must have sum s
     {
@@ -83,18 +88,25 @@ public:
         d1y[i] = m(i,i);
         d2y[i] = m(n-i-1,i);
       }
-      linear(*this, d1y, IRT_EQ, s, opt.icl());
-      linear(*this, d2y, IRT_EQ, s, opt.icl());
+      linear(*this, d1y, IRT_EQ, s, opt.ipl());
+      linear(*this, d2y, IRT_EQ, s, opt.ipl());
     }
 
     // All fields must be distinct
-    distinct(*this, x, opt.icl());
+    distinct(*this, x, opt.ipl());
 
     // Break some (few) symmetries
     rel(*this, m(0,0), IRT_GR, m(0,n-1));
     rel(*this, m(0,0), IRT_GR, m(n-1,0));
 
-    branch(*this, x, INT_VAR_SIZE_MIN(), INT_VAL_SPLIT_MIN());
+    switch (opt.branching()) {
+    case BRANCH_SIZE:
+      branch(*this, x, INT_VAR_SIZE_MIN(), INT_VAL_SPLIT_MIN());
+      break;
+    case BRANCH_AFC_SIZE:
+      branch(*this, x, INT_VAR_AFC_SIZE_MAX(opt.decay()), INT_VAL_SPLIT_MIN());
+      break;
+    }
   }
 
   /// Constructor for cloning \a s
@@ -132,6 +144,9 @@ main(int argc, char* argv[]) {
   SizeOptions opt("MagicSquare");
   opt.iterations(1);
   opt.size(7);
+  opt.branching(MagicSquare::BRANCH_SIZE);
+  opt.branching(MagicSquare::BRANCH_SIZE, "size");
+  opt.branching(MagicSquare::BRANCH_AFC_SIZE, "afc-size");
   opt.parse(argc,argv);
   Script::run<MagicSquare,DFS,SizeOptions>(opt);
   return 0;
