@@ -7,8 +7,8 @@
  *     Guido Tack, 2009
  *
  *  Last modified:
- *     $Date: 2015-03-17 16:09:39 +0100 (Tue, 17 Mar 2015) $ by $Author: schulte $
- *     $Revision: 14447 $
+ *     $Date: 2017-02-16 12:11:51 +0100 (Thu, 16 Feb 2017) $ by $Author: schulte $
+ *     $Revision: 15434 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -132,7 +132,7 @@ protected:
       for (int j=spec.n; j--;)
         new (&tasks[k++]) Task(j,i,dur(i,j));
     int* t0_tasks = re.alloc<int>(spec.n*spec.m); // Earliest possible tasks
-    
+
     bool stopCROSH = false;
 
     int maxIterations;
@@ -185,7 +185,7 @@ protected:
         if (cmax > maxmakespan)
           break;
       }
-      
+
       maxmakespan = std::min(maxmakespan,cmax);
       if (iteration++ > maxIterations)
         stopCROSH = true; // Iterate a couple of times
@@ -220,7 +220,7 @@ public:
           rel(*this,
               b[k++] == (start(m,j1) + dur(m,j1) > start(m,j0)));
         }
-    
+
     for (int j=0; j<spec.n; j++)
       for (int m0=0; m0<spec.m-1; m0++)
         for (int m1=m0+1; m1<spec.m; m1++) {
@@ -239,7 +239,7 @@ public:
     }
 
     // First branch over the precedences
-    branch(*this, b, INT_VAR_AFC_MAX(opt.decay()), INT_VAL_MAX());
+    branch(*this, b, BOOL_VAR_AFC_MAX(opt.decay()), BOOL_VAL_MAX());
     // When the precedences are fixed, simply assign the start times
     assign(*this, _start, INT_ASSIGN_MIN());
     // When the start times are fixed, use the tightest makespan
@@ -298,7 +298,7 @@ public:
     }
     os << "Makespan: " << makespan << std::endl;
   }
-  
+
 };
 
 /** \brief Main-function
