@@ -11,8 +11,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2013-07-08 14:22:40 +0200 (Mon, 08 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13820 $
+ *     $Date: 2015-03-17 16:09:39 +0100 (Tue, 17 Mar 2015) $ by $Author: schulte $
+ *     $Revision: 14447 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -340,7 +340,7 @@ private:
 public:
   /// Construction of the model.
   Pentominoes(const SizeOptions& opt)
-    : spec(examples[opt.size()]),
+    : Script(opt), spec(examples[opt.size()]),
       width(spec[0].width+1), // Add one for extra row at end.
       height(spec[0].height),
       filled(spec[0].amount),
