@@ -7,8 +7,8 @@
  *     Mikael Lagerkvist, 2006
  *
  *  Last modified:
- *     $Date: 2015-03-17 16:09:39 +0100 (Tue, 17 Mar 2015) $ by $Author: schulte $
- *     $Revision: 14447 $
+ *     $Date: 2017-02-16 12:11:51 +0100 (Thu, 16 Feb 2017) $ by $Author: schulte $
+ *     $Revision: 15434 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -113,11 +113,11 @@ public:
     linear(*this, b, IRT_EQ, unknowns);
 
     if (opt.branching() == BRANCH_NAIVE) {
-      branch(*this, w, INT_VAR_NONE(), INT_VAL_MAX());
-      branch(*this, b, INT_VAR_NONE(), INT_VAL_MAX());
+      branch(*this, w, BOOL_VAR_NONE(), BOOL_VAL_MAX());
+      branch(*this, b, BOOL_VAR_NONE(), BOOL_VAL_MAX());
     } else {
       QueenBranch::post(*this);
-      assign(*this, b, INT_ASSIGN_MAX());
+      assign(*this, b, BOOL_ASSIGN_MAX());
     }
   }
   /// Constructor for cloning
@@ -170,7 +170,7 @@ public:
       int pos;
       /// Value of variable
       bool val;
-      /** Initialize choice for brancher \a b, position \a pos0, 
+      /** Initialize choice for brancher \a b, position \a pos0,
        *  and value \a val0.
        */
       Choice(const Brancher& b, int pos0, bool val0)
@@ -245,7 +245,7 @@ public:
         : ES_OK;
     }
     /// Print explanation
-    virtual void print(const Space&, const Gecode::Choice& _c, 
+    virtual void print(const Space&, const Gecode::Choice& _c,
                        unsigned int a,
                        std::ostream& o) const {
       const Choice& c = static_cast<const Choice&>(_c);
@@ -257,8 +257,8 @@ public:
       return new (home) QueenBranch(home, share, *this);
     }
     /// Post brancher
-    static BrancherHandle post(QueenArmies& home) {
-      return *new (home) QueenBranch(home);
+    static void post(QueenArmies& home) {
+      (void) new (home) QueenBranch(home);
     }
     /// Delete brancher and return its size
     virtual size_t dispose(Space&) {
