@@ -9,8 +9,8 @@
  *     Guido Tack, 2008
  *
  *  Last modified:
- *     $Date: 2013-07-08 14:22:40 +0200 (Mon, 08 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13820 $
+ *     $Date: 2017-02-16 12:11:51 +0100 (Thu, 16 Feb 2017) $ by $Author: schulte $
+ *     $Revision: 15434 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -118,9 +118,10 @@ private:
   BoolVarArray x;
 public:
   /// The actual problem
-  Sat(const SatOptions& opt) {
+  Sat(const SatOptions& opt)
+    : Script(opt) {
     parseDIMACS(opt.filename.c_str());
-    branch(*this, x, INT_VAR_NONE(), INT_VAL_MIN());
+    branch(*this, x, BOOL_VAR_AFC_MAX(), BOOL_VAL_MIN());
   }
 
   /// Constructor for cloning
