@@ -7,8 +7,8 @@
  *     Christian Schulte, 2005
  *
  *  Last modified:
- *     $Date: 2013-07-08 14:22:40 +0200 (Mon, 08 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13820 $
+ *     $Date: 2015-09-11 16:29:45 +0200 (Fri, 11 Sep 2015) $ by $Author: schulte $
+ *     $Revision: 14672 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -108,8 +108,9 @@ protected:
   IntVar c_total;
 public:
   /// Actual model
-  Warehouses(const Options&)
-    : supplier(*this, n_stores, 0, n_warehouses-1),
+  Warehouses(const Options& opt)
+    : IntMinimizeScript(opt),
+      supplier(*this, n_stores, 0, n_warehouses-1),
       open(*this, n_warehouses, 0, 1),
       c_store(*this, n_stores) {
 
@@ -128,7 +129,7 @@ public:
       IntSetArgs c(n_warehouses);
       for (int w=0; w<n_warehouses; w++)
         c[w] = IntSet(0,capacity[w]);
-      count(*this, supplier, c, ICL_DOM);
+      count(*this, supplier, c, IPL_DOM);
     }
 
     // Compute total cost
