@@ -11,8 +11,8 @@
  *     Vincent Barichard, 2012
  *
  *  Last modified:
- *     $Date: 2013-07-04 17:03:13 +0200 (Thu, 04 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13801 $
+ *     $Date: 2017-02-16 12:11:51 +0100 (Thu, 16 Feb 2017) $ by $Author: schulte $
+ *     $Revision: 15434 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -42,36 +42,36 @@
 namespace Gecode { namespace Float { namespace Branch {
 
   forceinline
-  ValCommitLqGq::ValCommitLqGq(Space& home, const ValBranch& vb)
+  ValCommitLqGq::ValCommitLqGq(Space& home, const ValBranch<Var>& vb)
     : ValCommit<FloatView,FloatVal>(home,vb) {}
   forceinline
   ValCommitLqGq::ValCommitLqGq(Space& home, bool shared, ValCommitLqGq& vc)
     : ValCommit<FloatView,FloatVal>(home,shared,vc) {}
   forceinline ModEvent
-  ValCommitLqGq::commit(Space& home, unsigned int a, FloatView x, int, 
+  ValCommitLqGq::commit(Space& home, unsigned int a, FloatView x, int,
                         FloatNumBranch nl) {
     // Should we try the smaller half first?
     if ((a == 0) == nl.l) {
-      if ((x.min() == nl.n) || (x.max() == nl.n)) 
+      if ((x.min() == nl.n) || (x.max() == nl.n))
         return x.eq(home,x.min());
-      else 
+      else
         return x.lq(home,nl.n);
     } else {
       if ((x.min() == nl.n) || (x.max() == nl.n))
         return x.eq(home,x.max());
-      else 
+      else
         return x.gq(home,nl.n);
     }
   }
-  forceinline NGL* 
+  forceinline NGL*
   ValCommitLqGq::ngl(Space&, unsigned int, FloatView, FloatNumBranch) const {
     return NULL;
   }
   forceinline void
-  ValCommitLqGq::print(const Space&, unsigned int a, FloatView, int i, 
+  ValCommitLqGq::print(const Space&, unsigned int a, FloatView, int i,
                        FloatNumBranch nl,
                        std::ostream& o) const {
-    o << "var[" << i << "] " 
+    o << "var[" << i << "] "
       << (((a == 0) == nl.l) ? "<=" : ">=") << "(" << nl.n << ")";
   }
 
