@@ -7,8 +7,8 @@
  *     Christian Schulte, 2012
  *
  *  Last modified:
- *     $Date: 2013-05-29 13:53:43 +0200 (Wed, 29 May 2013) $ by $Author: schulte $
- *     $Revision: 13672 $
+ *     $Date: 2017-02-16 12:11:51 +0100 (Thu, 16 Feb 2017) $ by $Author: schulte $
+ *     $Revision: 15434 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -39,7 +39,7 @@
 
 namespace Gecode { namespace Float { namespace Branch {
 
-  ValSelCommitBase<FloatView,FloatNumBranch>* 
+  ValSelCommitBase<FloatView,FloatNumBranch>*
   valselcommit(Space& home, const FloatValBranch& fvb) {
     switch (fvb.select()) {
     case FloatValBranch::SEL_SPLIT_MIN:
@@ -49,7 +49,7 @@ namespace Gecode { namespace Float { namespace Branch {
     case FloatValBranch::SEL_SPLIT_RND:
       return new (home) ValSelCommit<ValSelRnd,ValCommitLqGq>(home,fvb);
     case FloatValBranch::SEL_VAL_COMMIT:
-      if (fvb.commit() == NULL) {
+      if (!fvb.commit()) {
         return new (home)
           ValSelCommit<ValSelFunction<FloatView>,ValCommitLqGq>(home,fvb);
       } else {
@@ -61,7 +61,7 @@ namespace Gecode { namespace Float { namespace Branch {
     }
   }
 
-  ValSelCommitBase<FloatView,FloatNumBranch>* 
+  ValSelCommitBase<FloatView,FloatNumBranch>*
   valselcommit(Space& home, const FloatAssign& fa) {
     switch (fa.select()) {
     case FloatAssign::SEL_MIN:
@@ -71,7 +71,7 @@ namespace Gecode { namespace Float { namespace Branch {
     case FloatAssign::SEL_RND:
       return new (home) ValSelCommit<ValSelRnd,ValCommitLqGq>(home,fa);
     case FloatAssign::SEL_VAL_COMMIT:
-      if (fa.commit() == NULL) {
+      if (!fa.commit()) {
         return new (home)
           ValSelCommit<ValSelFunction<FloatView>,ValCommitLqGq>(home,fa);
       } else {
