@@ -9,8 +9,8 @@
  *     Vincent Barichard, 2012
  *
  *  Last modified:
- *     $Date: 2013-05-29 13:53:43 +0200 (Wed, 29 May 2013) $ by $Author: schulte $
- *     $Revision: 13672 $
+ *     $Date: 2017-02-16 12:11:51 +0100 (Thu, 16 Feb 2017) $ by $Author: schulte $
+ *     $Revision: 15434 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -54,7 +54,7 @@ namespace Gecode {
 namespace Gecode { namespace Float { namespace Branch {
 
   forceinline
-  ValSelLq::ValSelLq(Space& home, const ValBranch& vb) 
+  ValSelLq::ValSelLq(Space& home, const ValBranch<Var>& vb)
     : ValSel<FloatView,FloatNumBranch>(home,vb) {}
   forceinline
   ValSelLq::ValSelLq(Space& home, bool shared, ValSelLq& vs)
@@ -67,7 +67,7 @@ namespace Gecode { namespace Float { namespace Branch {
   }
 
   forceinline
-  ValSelGq::ValSelGq(Space& home, const ValBranch& vb) 
+  ValSelGq::ValSelGq(Space& home, const ValBranch<Var>& vb)
     : ValSel<FloatView,FloatNumBranch>(home,vb) {}
   forceinline
   ValSelGq::ValSelGq(Space& home, bool shared, ValSelGq& vs)
@@ -80,7 +80,7 @@ namespace Gecode { namespace Float { namespace Branch {
   }
 
   forceinline
-  ValSelRnd::ValSelRnd(Space& home, const ValBranch& vb) 
+  ValSelRnd::ValSelRnd(Space& home, const ValBranch<Var>& vb)
     : ValSel<FloatView,FloatNumBranch>(home,vb), r(vb.rnd()) {}
   forceinline
   ValSelRnd::ValSelRnd(Space& home, bool shared, ValSelRnd& vs)
