@@ -11,8 +11,8 @@
  *     Vincent Barichard, 2012
  *
  *  Last modified:
- *     $Date: 2014-10-03 15:34:37 +0200 (Fri, 03 Oct 2014) $ by $Author: schulte $
- *     $Revision: 14241 $
+ *     $Date: 2016-06-20 16:44:21 +0200 (Mon, 20 Jun 2016) $ by $Author: schulte $
+ *     $Revision: 15120 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -64,7 +64,7 @@ namespace Gecode {
   FloatVal::operator =(const FloatVal& v) {
     x = v.x; return *this;
   }
-    
+
   forceinline void
   FloatVal::assign(FloatNum const &l, FloatNum const &u) {
     x.assign(l,u);
@@ -89,7 +89,7 @@ namespace Gecode {
 
   forceinline bool
   FloatVal::tight(void) const {
-    return (gecode_boost::numeric::singleton(x) || 
+    return (gecode_boost::numeric::singleton(x) ||
             (nextafter(x.lower(),x.upper()) == x.upper()));
   }
   forceinline bool
@@ -104,10 +104,10 @@ namespace Gecode {
   FloatVal::zero_in(void) const {
     return gecode_boost::numeric::zero_in(x);
   }
-    
+
   forceinline FloatVal
   FloatVal::hull(FloatNum x, FloatNum y) {
-    FloatVal h(FloatVal::hull(x,y)); return h;
+    FloatVal h(x,y); return h;
   }
   forceinline FloatVal
   FloatVal::pi_half(void) {
@@ -124,7 +124,7 @@ namespace Gecode {
     FloatVal p(gecode_boost::numeric::interval_lib::pi_twice<FloatValImpType>());
     return p;
   }
-    
+
   forceinline FloatVal&
   FloatVal::operator +=(const FloatNum& n) {
     x += n; return *this;
@@ -226,112 +226,112 @@ namespace Gecode {
     return FloatVal(x/y.x);
   }
 
-  forceinline bool
+  inline bool
   operator <(const FloatVal& x, const FloatVal& y) {
     try {
       return x.x < y.x;
     } catch (gecode_boost::numeric::interval_lib::comparison_error&) {
       return false;
-    }         
+    }
   }
-  forceinline bool
+  inline bool
   operator <(const FloatVal& x, const FloatNum& y) {
     try {
       return x.x < y;
     } catch (gecode_boost::numeric::interval_lib::comparison_error&) {
       return false;
-    }         
+    }
   }
 
-  forceinline bool
+  inline bool
   operator <=(const FloatVal& x, const FloatVal& y) {
     try {
       return x.x <= y.x;
     } catch (gecode_boost::numeric::interval_lib::comparison_error&) {
       return false;
-    }         
+    }
   }
-  forceinline bool
+  inline bool
   operator <=(const FloatVal& x, const FloatNum& y) {
     try {
       return x.x <= y;
     } catch (gecode_boost::numeric::interval_lib::comparison_error&) {
       return false;
-    }         
+    }
   }
 
-  forceinline bool
+  inline bool
   operator >(const FloatVal& x, const FloatVal& y) {
     try {
       return x.x > y.x;
     } catch (gecode_boost::numeric::interval_lib::comparison_error&) {
       return false;
-    }         
+    }
   }
-  forceinline bool
+  inline bool
   operator >(const FloatVal& x, const FloatNum& y) {
     try {
       return x.x > y;
     } catch (gecode_boost::numeric::interval_lib::comparison_error&) {
       return false;
-    }         
+    }
   }
 
-  forceinline bool
+  inline bool
   operator >=(const FloatVal& x, const FloatVal& y) {
     try {
       return x.x >= y.x;
     } catch (gecode_boost::numeric::interval_lib::comparison_error&) {
       return false;
-    }         
+    }
   }
-  forceinline bool
+  inline bool
   operator >=(const FloatVal& x, const FloatNum& y) {
     try {
       return x.x >= y;
     } catch (gecode_boost::numeric::interval_lib::comparison_error&) {
       return false;
-    }         
+    }
   }
 
-  forceinline bool
+  inline bool
   operator ==(const FloatVal& x, const FloatVal& y) {
     try {
       return x.x == y.x;
     } catch (gecode_boost::numeric::interval_lib::comparison_error&) {
       return false;
-    }         
+    }
   }
-  forceinline bool
+  inline bool
   operator ==(const FloatVal& x, const FloatNum& y) {
     if (!gecode_boost::numeric::interval_lib::checking_strict<FloatNum>
         ::is_empty(x.x.lower(), x.x.upper())) {
       if ((x.x.lower() == y) && (x.x.upper() == y))
         return true;
       }
-    if (((x.x.lower() == y) && 
+    if (((x.x.lower() == y) &&
          (nextafter(x.x.lower(),x.x.upper()) == x.x.upper())) ||
-        ((x.x.upper() == y) && 
+        ((x.x.upper() == y) &&
          (nextafter(x.x.upper(),x.x.lower()) == x.x.lower())))
       return true;
     return false;
   }
 
-  forceinline bool
+  inline bool
   operator !=(const FloatVal& x, const FloatVal& y) {
     try {
       return x.x != y.x;
     } catch (gecode_boost::numeric::interval_lib::comparison_error&) {
       return false;
-    }         
+    }
   }
-  forceinline bool
+  inline bool
   operator !=(const FloatVal& x, const FloatNum& y) {
     try {
       return x.x != y;
     } catch (gecode_boost::numeric::interval_lib::comparison_error&) {
       return false;
-    }         
+    }
   }
 
   forceinline bool
@@ -521,7 +521,7 @@ namespace Gecode { namespace Float {
   }
   forceinline FloatVal
   hull(const FloatNum& x, const FloatNum& y) {
-    return FloatVal(hull(x,y));
+    return FloatVal(x,y);
   }
 
 }}
