@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2012-09-03 17:08:20 +0200 (Mon, 03 Sep 2012) $ by $Author: schulte $
- *     $Revision: 13038 $
+ *     $Date: 2017-03-23 15:08:48 +0100 (Thu, 23 Mar 2017) $ by $Author: schulte $
+ *     $Revision: 15616 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -40,10 +40,10 @@
 namespace Gecode {
 
   void
-  abs(Home home, IntVar x0, IntVar x1, IntConLevel icl) {
+  abs(Home home, IntVar x0, IntVar x1, IntPropLevel ipl) {
     using namespace Int;
-    if (home.failed()) return;
-    if (icl == ICL_DOM) {
+    GECODE_POST;
+    if (vbd(ipl) == IPL_DOM) {
       GECODE_ES_FAIL(Arithmetic::AbsDom<IntView>::post(home,x0,x1));
     } else {
       GECODE_ES_FAIL(Arithmetic::AbsBnd<IntView>::post(home,x0,x1));
@@ -53,10 +53,10 @@ namespace Gecode {
 
   void
   max(Home home, IntVar x0, IntVar x1, IntVar x2,
-      IntConLevel icl) {
+      IntPropLevel ipl) {
     using namespace Int;
-    if (home.failed()) return;
-    if (icl == ICL_DOM) {
+    GECODE_POST;
+    if (vbd(ipl) == IPL_DOM) {
       GECODE_ES_FAIL(Arithmetic::MaxDom<IntView>::post(home,x0,x1,x2));
     } else {
       GECODE_ES_FAIL(Arithmetic::MaxBnd<IntView>::post(home,x0,x1,x2));
@@ -65,13 +65,13 @@ namespace Gecode {
 
   void
   max(Home home, const IntVarArgs& x, IntVar y,
-      IntConLevel icl) {
+      IntPropLevel ipl) {
     using namespace Int;
     if (x.size() == 0)
       throw TooFewArguments("Int::max");
-    if (home.failed()) return;
+    GECODE_POST;
     ViewArray<IntView> xv(home,x);
-    if (icl == ICL_DOM) {
+    if (vbd(ipl) == IPL_DOM) {
       GECODE_ES_FAIL(Arithmetic::NaryMaxDom<IntView>::post(home,xv,y));
     } else {
       GECODE_ES_FAIL(Arithmetic::NaryMaxBnd<IntView>::post(home,xv,y));
@@ -80,11 +80,11 @@ namespace Gecode {
 
   void
   min(Home home, IntVar x0, IntVar x1, IntVar x2,
-      IntConLevel icl) {
+      IntPropLevel ipl) {
     using namespace Int;
-    if (home.failed()) return;
+    GECODE_POST;
     MinusView m0(x0); MinusView m1(x1); MinusView m2(x2);
-    if (icl == ICL_DOM) {
+    if (vbd(ipl) == IPL_DOM) {
       GECODE_ES_FAIL(Arithmetic::MaxDom<MinusView>::post(home,m0,m1,m2));
     } else {
       GECODE_ES_FAIL(Arithmetic::MaxBnd<MinusView>::post(home,m0,m1,m2));
@@ -93,16 +93,16 @@ namespace Gecode {
 
   void
   min(Home home, const IntVarArgs& x, IntVar y,
-      IntConLevel icl) {
+      IntPropLevel ipl) {
     using namespace Int;
     if (x.size() == 0)
       throw TooFewArguments("Int::min");
-    if (home.failed()) return;
+    GECODE_POST;
     ViewArray<MinusView> m(home,x.size());
     for (int i=x.size(); i--; )
       m[i] = MinusView(x[i]);
     MinusView my(y);
-    if (icl == ICL_DOM) {
+    if (vbd(ipl) == IPL_DOM) {
       GECODE_ES_FAIL(Arithmetic::NaryMaxDom<MinusView>::post(home,m,my));
     } else {
       GECODE_ES_FAIL(Arithmetic::NaryMaxBnd<MinusView>::post(home,m,my));
@@ -111,11 +111,118 @@ namespace Gecode {
 
 
   void
-  mult(Home home, IntVar x0, IntVar x1, IntVar x2,
-       IntConLevel icl) {
+  argmax(Home home, const IntVarArgs& x, IntVar y, bool tiebreak,
+         IntPropLevel) {
     using namespace Int;
-    if (home.failed()) return;
-    if (icl == ICL_DOM) {
+    if (x.size() == 0)
+      throw TooFewArguments("Int::argmax");
+    if (x.same(home,y))
+      throw ArgumentSame("Int::argmax");
+    GECODE_POST;
+    // Constrain y properly
+    IntView yv(y);
+    GECODE_ME_FAIL(yv.gq(home,0));
+    GECODE_ME_FAIL(yv.le(home,x.size()));
+    // Construct index view array
+    IdxViewArray<IntView> ix(home,x.size());
+    for (int i=x.size(); i--; ) {
+      ix[i].idx=i; ix[i].view=x[i];
+    }
+    if (tiebreak)
+        GECODE_ES_FAIL((Arithmetic::ArgMax<IntView,IntView,true>
+                        ::post(home,ix,yv)));
+    else
+        GECODE_ES_FAIL((Arithmetic::ArgMax<IntView,IntView,false>
+                        ::post(home,ix,yv)));
+  }
+
+  void
+  argmax(Home home, const IntVarArgs& x, int o, IntVar y, bool tiebreak,
+         IntPropLevel) {
+    using namespace Int;
+    Limits::nonnegative(o,"Int::argmax");
+    if (x.size() == 0)
+      throw TooFewArguments("Int::argmax");
+    if (x.same(home,y))
+      throw ArgumentSame("Int::argmax");
+    GECODE_POST;
+    // Constrain y properly
+    OffsetView yv(y,-o);
+    GECODE_ME_FAIL(yv.gq(home,0));
+    GECODE_ME_FAIL(yv.le(home,x.size()));
+    // Construct index view array
+    IdxViewArray<IntView> ix(home,x.size());
+    for (int i=x.size(); i--; ) {
+      ix[i].idx=i; ix[i].view=x[i];
+    }
+    if (tiebreak)
+        GECODE_ES_FAIL((Arithmetic::ArgMax<IntView,OffsetView,true>
+                        ::post(home,ix,yv)));
+    else
+        GECODE_ES_FAIL((Arithmetic::ArgMax<IntView,OffsetView,false>
+                        ::post(home,ix,yv)));
+  }
+
+  void
+  argmin(Home home, const IntVarArgs& x, IntVar y, bool tiebreak,
+         IntPropLevel) {
+    using namespace Int;
+    if (x.size() == 0)
+      throw TooFewArguments("Int::argmin");
+    if (x.same(home,y))
+      throw ArgumentSame("Int::argmin");
+    GECODE_POST;
+    // Constrain y properly
+    IntView yv(y);
+    GECODE_ME_FAIL(yv.gq(home,0));
+    GECODE_ME_FAIL(yv.le(home,x.size()));
+    // Construct index view array
+    IdxViewArray<MinusView> ix(home,x.size());
+    for (int i=x.size(); i--; ) {
+      ix[i].idx=i; ix[i].view=MinusView(x[i]);
+    }
+    if (tiebreak)
+        GECODE_ES_FAIL((Arithmetic::ArgMax<MinusView,IntView,true>
+                        ::post(home,ix,yv)));
+    else
+        GECODE_ES_FAIL((Arithmetic::ArgMax<MinusView,IntView,false>
+                        ::post(home,ix,yv)));
+  }
+
+  void
+  argmin(Home home, const IntVarArgs& x, int o, IntVar y, bool tiebreak,
+         IntPropLevel) {
+    using namespace Int;
+    Limits::nonnegative(o,"Int::argmin");
+    if (x.size() == 0)
+      throw TooFewArguments("Int::argmin");
+    if (x.same(home,y))
+      throw ArgumentSame("Int::argmin");
+    GECODE_POST;
+    // Constrain y properly
+    OffsetView yv(y,-o);
+    GECODE_ME_FAIL(yv.gq(home,0));
+    GECODE_ME_FAIL(yv.le(home,x.size()));
+    // Construct index view array
+    IdxViewArray<MinusView> ix(home,x.size());
+    for (int i=x.size(); i--; ) {
+      ix[i].idx=i; ix[i].view=MinusView(x[i]);
+    }
+    if (tiebreak)
+        GECODE_ES_FAIL((Arithmetic::ArgMax<MinusView,OffsetView,true>
+                        ::post(home,ix,yv)));
+    else
+        GECODE_ES_FAIL((Arithmetic::ArgMax<MinusView,OffsetView,false>
+                        ::post(home,ix,yv)));
+  }
+
+
+  void
+  mult(Home home, IntVar x0, IntVar x1, IntVar x2,
+       IntPropLevel ipl) {
+    using namespace Int;
+    GECODE_POST;
+    if (vbd(ipl) == IPL_DOM) {
       GECODE_ES_FAIL(Arithmetic::MultDom::post(home,x0,x1,x2));
     } else {
       GECODE_ES_FAIL(Arithmetic::MultBnd::post(home,x0,x1,x2));
@@ -125,9 +232,9 @@ namespace Gecode {
 
   void
   divmod(Home home, IntVar x0, IntVar x1, IntVar x2, IntVar x3,
-         IntConLevel) {
+         IntPropLevel) {
     using namespace Int;
-    if (home.failed()) return;
+    GECODE_POST;
 
     IntVar prod(home, Int::Limits::min, Int::Limits::max);
     GECODE_ES_FAIL(Arithmetic::MultBnd::post(home,x1,x2,prod));
@@ -140,7 +247,7 @@ namespace Gecode {
     GECODE_ME_FAIL(x0v.gq(home,min));
     GECODE_ME_FAIL(x0v.lq(home,max));
     t[2].a=-1; t[2].x=x0;
-    Linear::post(home,t,3,IRT_EQ,0);
+    Linear::post(home,t,3,IRT_EQ,0,IPL_BND);
     if (home.failed()) return;
     IntView x1v(x1);
     GECODE_ES_FAIL(
@@ -149,28 +256,28 @@ namespace Gecode {
 
   void
   div(Home home, IntVar x0, IntVar x1, IntVar x2,
-      IntConLevel) {
+      IntPropLevel) {
     using namespace Int;
-    if (home.failed()) return;
+    GECODE_POST;
     GECODE_ES_FAIL(
       (Arithmetic::DivBnd<IntView>::post(home,x0,x1,x2)));
   }
 
   void
   mod(Home home, IntVar x0, IntVar x1, IntVar x2,
-      IntConLevel icl) {
+      IntPropLevel ipl) {
     using namespace Int;
-    if (home.failed()) return;
+    GECODE_POST;
     IntVar _div(home, Int::Limits::min, Int::Limits::max);
-    divmod(home, x0, x1, _div, x2, icl);
+    divmod(home, x0, x1, _div, x2, ipl);
   }
 
   void
-  sqr(Home home, IntVar x0, IntVar x1, IntConLevel icl) {
+  sqr(Home home, IntVar x0, IntVar x1, IntPropLevel ipl) {
     using namespace Int;
-    if (home.failed()) return;
+    GECODE_POST;
     Arithmetic::SqrOps ops;
-    if (icl == ICL_DOM) {
+    if (vbd(ipl) == IPL_DOM) {
       GECODE_ES_FAIL(Arithmetic::PowDom<Arithmetic::SqrOps>
                      ::post(home,x0,x1,ops));
     } else {
@@ -180,11 +287,11 @@ namespace Gecode {
   }
 
   void
-  sqrt(Home home, IntVar x0, IntVar x1, IntConLevel icl) {
+  sqrt(Home home, IntVar x0, IntVar x1, IntPropLevel ipl) {
     using namespace Int;
-    if (home.failed()) return;
+    GECODE_POST;
     Arithmetic::SqrOps ops;
-    if (icl == ICL_DOM) {
+    if (vbd(ipl) == IPL_DOM) {
       GECODE_ES_FAIL(Arithmetic::NrootDom<Arithmetic::SqrOps>
                      ::post(home,x0,x1,ops));
     } else {
@@ -194,16 +301,16 @@ namespace Gecode {
   }
 
   void
-  pow(Home home, IntVar x0, int n, IntVar x1, IntConLevel icl) {
+  pow(Home home, IntVar x0, int n, IntVar x1, IntPropLevel ipl) {
     using namespace Int;
     Limits::nonnegative(n,"Int::pow");
-    if (home.failed()) return;
+    GECODE_POST;
     if (n == 2) {
-      sqr(home, x0, x1, icl);
+      sqr(home, x0, x1, ipl);
       return;
     }
     Arithmetic::PowOps ops(n);
-    if (icl == ICL_DOM) {
+    if (vbd(ipl) == IPL_DOM) {
       GECODE_ES_FAIL(Arithmetic::PowDom<Arithmetic::PowOps>
                      ::post(home,x0,x1,ops));
     } else {
@@ -213,16 +320,16 @@ namespace Gecode {
   }
 
   void
-  nroot(Home home, IntVar x0, int n, IntVar x1, IntConLevel icl) {
+  nroot(Home home, IntVar x0, int n, IntVar x1, IntPropLevel ipl) {
     using namespace Int;
     Limits::positive(n,"Int::nroot");
-    if (home.failed()) return;
+    GECODE_POST;
     if (n == 2) {
-      sqrt(home, x0, x1, icl);
+      sqrt(home, x0, x1, ipl);
       return;
     }
     Arithmetic::PowOps ops(n);
-    if (icl == ICL_DOM) {
+    if (vbd(ipl) == IPL_DOM) {
       GECODE_ES_FAIL(Arithmetic::NrootDom<Arithmetic::PowOps>
                      ::post(home,x0,x1,ops));
     } else {
