@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2012-09-10 11:31:52 +0200 (Mon, 10 Sep 2012) $ by $Author: schulte $
- *     $Revision: 13071 $
+ *     $Date: 2016-06-29 17:28:17 +0200 (Wed, 29 Jun 2016) $ by $Author: schulte $
+ *     $Revision: 15137 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -814,6 +814,19 @@ namespace Gecode { namespace Int { namespace Bool {
       return ES_NOFIX;
   }
 
+  template<class VX, class VY>
+  void
+  NaryOr<VX,VY>::reschedule(Space& home) {
+    y.reschedule(home,*this,PC_BOOL_VAL);
+    if (n_zero == x.size())
+      VX::schedule(home,*this,ME_BOOL_VAL);
+    for (int i=x.size(); i--; )
+      if (x[i].one()) {
+        VX::schedule(home,*this,ME_BOOL_VAL);
+        break;
+      }
+  }
+
   template<class VX, class VY>
   forceinline size_t
   NaryOr<VX,VY>::dispose(Space& home) {
@@ -838,7 +851,7 @@ namespace Gecode { namespace Int { namespace Bool {
       // All views are zero
       GECODE_ME_CHECK(y.zero_none(home));
     } else {
-      // There is exactly one view which is one
+      // There is at least one view which is one
       GECODE_ME_CHECK(y.one_none(home));
     }
     return home.ES_SUBSUMED(*this);
