@@ -7,8 +7,8 @@
  *     Christian Schulte, 2012
  *
  *  Last modified:
- *     $Date: 2013-07-04 17:03:13 +0200 (Thu, 04 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13801 $
+ *     $Date: 2017-02-16 12:11:51 +0100 (Thu, 16 Feb 2017) $ by $Author: schulte $
+ *     $Revision: 15434 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -39,7 +39,7 @@ namespace Gecode { namespace Int { namespace Branch {
 
   template<class View>
   forceinline
-  ValCommitEq<View>::ValCommitEq(Space& home, const ValBranch& vb)
+  ValCommitEq<View>::ValCommitEq(Space& home, const ValBranch<Var>& vb)
     : ValCommit<View,int>(home,vb) {}
   template<class View>
   forceinline
@@ -60,15 +60,15 @@ namespace Gecode { namespace Int { namespace Branch {
   }
   template<class View>
   forceinline void
-  ValCommitEq<View>::print(const Space&, unsigned int a, View, int i, 
+  ValCommitEq<View>::print(const Space&, unsigned int a, View, int i,
                            int n, std::ostream& o) const {
-    o << "var[" << i << "] " 
+    o << "var[" << i << "] "
       << ((a == 0) ? "=" : "!=") << " " << n;
   }
 
   template<class View>
   forceinline
-  ValCommitLq<View>::ValCommitLq(Space& home, const ValBranch& vb)
+  ValCommitLq<View>::ValCommitLq(Space& home, const ValBranch<Var>& vb)
     : ValCommit<View,int>(home,vb) {}
   template<class View>
   forceinline
@@ -91,13 +91,13 @@ namespace Gecode { namespace Int { namespace Branch {
   forceinline void
   ValCommitLq<View>::print(const Space&, unsigned int a, View, int i,
                            int n, std::ostream& o) const {
-    o << "var[" << i << "] " 
+    o << "var[" << i << "] "
       << ((a == 0) ? "<=" : ">") << " " << n;
   }
 
   template<class View>
   forceinline
-  ValCommitGq<View>::ValCommitGq(Space& home, const ValBranch& vb)
+  ValCommitGq<View>::ValCommitGq(Space& home, const ValBranch<Var>& vb)
     : ValCommit<View,int>(home,vb) {}
   template<class View>
   forceinline
@@ -118,15 +118,15 @@ namespace Gecode { namespace Int { namespace Branch {
   }
   template<class View>
   forceinline void
-  ValCommitGq<View>::print(const Space&, unsigned int a, View, int i, 
+  ValCommitGq<View>::print(const Space&, unsigned int a, View, int i,
                            int n, std::ostream& o) const {
-    o << "var[" << i << "] " 
+    o << "var[" << i << "] "
       << ((a == 0) ? ">=" : "<") << " " << n;
   }
 
   template<class View>
   forceinline
-  ValCommitGr<View>::ValCommitGr(Space& home, const ValBranch& vb)
+  ValCommitGr<View>::ValCommitGr(Space& home, const ValBranch<Var>& vb)
     : ValCommit<View,int>(home,vb) {}
   template<class View>
   forceinline
@@ -147,9 +147,9 @@ namespace Gecode { namespace Int { namespace Branch {
   }
   template<class View>
   forceinline void
-  ValCommitGr<View>::print(const Space&, unsigned int a, View, int i, 
+  ValCommitGr<View>::print(const Space&, unsigned int a, View, int i,
                            int n, std::ostream& o) const {
-    o << "var[" << i << "] " 
+    o << "var[" << i << "] "
       << ((a == 0) ? ">" : "<=") << " " << n;
   }
 
