@@ -7,8 +7,8 @@
  *     Christian Schulte, 2007
  *
  *  Last modified:
- *     $Date: 2011-07-07 11:23:22 +0200 (Thu, 07 Jul 2011) $ by $Author: schulte $
- *     $Revision: 12155 $
+ *     $Date: 2016-06-29 17:28:17 +0200 (Wed, 29 Jun 2016) $ by $Author: schulte $
+ *     $Revision: 15137 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -82,14 +82,6 @@ namespace Gecode { namespace Int { namespace Channel {
   }
 
 
-  forceinline
-  LinkMulti::LinkMulti(Space& home, bool share, LinkMulti& p)
-    : MixNaryOnePropagator<BoolView,PC_BOOL_NONE,IntView,PC_INT_DOM>
-  (home,share,p), status(S_NONE), o(p.o) {
-    assert(p.status == S_NONE);
-    c.update(home,share,p.c);
-  }
-
   Actor*
   LinkMulti::copy(Space& home, bool share) {
     return new (home) LinkMulti(home,share,*this);
@@ -113,6 +105,13 @@ namespace Gecode { namespace Int { namespace Channel {
       return PropCost::linear(PropCost::LO, x.size());
   }
 
+  void
+  LinkMulti::reschedule(Space& home) {
+    if (status == S_ONE)
+      BoolView::schedule(home,*this,ME_BOOL_VAL);
+    y.reschedule(home,*this,PC_INT_DOM);
+  }
+
   ExecStatus
   LinkMulti::advise(Space&, Advisor&, const Delta& d) {
     if (status == S_RUN)
