@@ -7,8 +7,8 @@
  *     Christian Schulte, 2003
  *
  *  Last modified:
- *     $Date: 2011-09-20 13:58:39 +0200 (Tue, 20 Sep 2011) $ by $Author: schulte $
- *     $Revision: 12404 $
+ *     $Date: 2016-04-19 17:19:45 +0200 (Tue, 19 Apr 2016) $ by $Author: schulte $
+ *     $Revision: 14967 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -40,16 +40,16 @@ namespace Gecode { namespace Int { namespace Count {
   template<class VX, class VY, class VZ, bool shr, bool dom>
   forceinline
   EqView<VX,VY,VZ,shr,dom>::EqView(Home home,
-                               ViewArray<VX>& x, VY y, VZ z, int c)
+                                   ViewArray<VX>& x, VY y, VZ z, int c)
     : ViewBase<VX,VY,VZ>(home,x,y,z,c) {}
 
   template<class VX, class VY, class VZ, bool shr, bool dom>
   ExecStatus
   EqView<VX,VY,VZ,shr,dom>::post(Home home,
-                             ViewArray<VX>& x, VY y, VZ z, int c) {
+                                 ViewArray<VX>& x, VY y, VZ z, int c) {
     GECODE_ME_CHECK(z.gq(home,-c));
     GECODE_ME_CHECK(z.lq(home,x.size()-c));
-    if ((vtd(y) != VTD_VARVIEW) && z.assigned())
+    if (isval(y) && z.assigned())
       return EqInt<VX,VY>::post(home,x,y,z.val()+c);
     if (sharing(x,y,z))
       (void) new (home) EqView<VX,VY,VZ,true,dom>(home,x,y,z,c);
@@ -61,7 +61,7 @@ namespace Gecode { namespace Int { namespace Count {
   template<class VX, class VY, class VZ, bool shr, bool dom>
   forceinline
   EqView<VX,VY,VZ,shr,dom>::EqView(Space& home, bool share,
-                               EqView<VX,VY,VZ,shr,dom>& p)
+                                   EqView<VX,VY,VZ,shr,dom>& p)
     : ViewBase<VX,VY,VZ>(home,share,p) {}
 
   template<class VX, class VY, class VZ, bool shr, bool dom>
@@ -87,16 +87,16 @@ namespace Gecode { namespace Int { namespace Count {
         GECODE_ES_CHECK(post_true(home,x,y));
         return home.ES_SUBSUMED(*this);
       }
-      if (!dom || (vtd(y) != VTD_VARVIEW)) {
+      if (!dom || isval(y)) {
         VY yc(y);
         GECODE_REWRITE(*this,(EqInt<VX,VY>
-                              ::post(home(*this),x,yc,z.val()+c)));    
+                              ::post(home(*this),x,yc,z.val()+c)));
       }
     }
 
 
-    if (dom && (vtd(y) == VTD_VARVIEW) && (z.min() > 0)) {
-      /* 
+    if (dom && !isval(y) && (z.min() > 0)) {
+      /*
        * Only if the propagator is at fixpoint here, continue
        * when things are shared: the reason is that prune
        * requires that the views in x overlap with y!
@@ -108,7 +108,7 @@ namespace Gecode { namespace Int { namespace Count {
 
       return ES_NOFIX;
     }
-    
+
     return shr ? ES_NOFIX : ES_FIX;
   }
 
