@@ -7,8 +7,8 @@
  *     Christian Schulte, 2009
  *
  *  Last modified:
- *     $Date: 2010-03-03 17:40:32 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10365 $
+ *     $Date: 2017-02-16 12:11:51 +0100 (Thu, 16 Feb 2017) $ by $Author: schulte $
+ *     $Revision: 15434 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -41,43 +41,52 @@
 namespace Gecode {
 
   void
-  wait(Home home, IntVar x, void (*c)(Space& home),
-       IntConLevel) {
-    if (home.failed()) return;
+  wait(Home home, IntVar x, std::function<void(Space& home)> c,
+       IntPropLevel) {
+    GECODE_POST;
     GECODE_ES_FAIL(Kernel::UnaryWait<Int::IntView>::post(home,x,c));
   }
 
   void
-  wait(Home home, BoolVar x, void (*c)(Space& home),
-       IntConLevel) {
-    if (home.failed()) return;
+  wait(Home home, BoolVar x, std::function<void(Space& home)> c,
+       IntPropLevel) {
+    GECODE_POST;
     GECODE_ES_FAIL(Kernel::UnaryWait<Int::BoolView>::post(home,x,c));
   }
 
   void
-  wait(Home home, const IntVarArgs& x, void (*c)(Space& home),
-       IntConLevel) {
-    if (home.failed()) return;
+  wait(Home home, const IntVarArgs& x, std::function<void(Space& home)> c,
+       IntPropLevel) {
+    GECODE_POST;
     ViewArray<Int::IntView> xv(home,x);
     GECODE_ES_FAIL(Kernel::NaryWait<Int::IntView>::post(home,xv,c));
   }
 
   void
-  wait(Home home, const BoolVarArgs& x, void (*c)(Space& home),
-       IntConLevel) {
-    if (home.failed()) return;
+  wait(Home home, const BoolVarArgs& x, std::function<void(Space& home)> c,
+       IntPropLevel) {
+    GECODE_POST;
     ViewArray<Int::BoolView> xv(home,x);
     GECODE_ES_FAIL(Kernel::NaryWait<Int::BoolView>::post(home,xv,c));
   }
 
+
   void
   when(Home home, BoolVar x,
-       void (*t)(Space& home), void (*e)(Space& home),
-       IntConLevel) {
-    if (home.failed()) return;
+       std::function<void(Space& home)> t,
+       std::function<void(Space& home)> e,
+       IntPropLevel) {
+    GECODE_POST;
     GECODE_ES_FAIL(Int::Exec::When::post(home,x,t,e));
   }
 
+  void
+  when(Home home, BoolVar x,
+       std::function<void(Space& home)> t,
+       IntPropLevel) {
+    when(home, x, t, [](Space&) {});
+  }
+
 }
 
 // STATISTICS: int-post
