@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2012-09-07 17:31:22 +0200 (Fri, 07 Sep 2012) $ by $Author: schulte $
- *     $Revision: 13068 $
+ *     $Date: 2016-05-23 22:18:23 +0200 (Mon, 23 May 2016) $ by $Author: schulte $
+ *     $Revision: 15073 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -43,49 +43,44 @@ namespace Gecode {
 
   void
   extensional(Home home, const IntVarArgs& x, DFA dfa,
-              IntConLevel) {
+              IntPropLevel) {
     using namespace Int;
     if (x.same(home))
       throw ArgumentSame("Int::extensional");
-    if (home.failed()) return;
+    GECODE_POST;
     GECODE_ES_FAIL(Extensional::post_lgp(home,x,dfa));
   }
 
   void
   extensional(Home home, const BoolVarArgs& x, DFA dfa,
-              IntConLevel) {
+              IntPropLevel) {
     using namespace Int;
     if (x.same(home))
       throw ArgumentSame("Int::extensional");
-    if (home.failed()) return;
+    GECODE_POST;
     GECODE_ES_FAIL(Extensional::post_lgp(home,x,dfa));
   }
 
   void
   extensional(Home home, const IntVarArgs& x, const TupleSet& t,
-              ExtensionalPropKind epk, IntConLevel) {
+              IntPropLevel ipl) {
     using namespace Int;
     if (!t.finalized())
       throw NotYetFinalized("Int::extensional");
+    if (t.arity() != x.size())
+      throw ArgumentSizeMismatch("Int::extensional");
+    GECODE_POST;
+
     if (t.tuples()==0) {
       if (x.size()!=0) {
         home.fail();
       }
       return;
     }
-    
-    if (t.arity() != x.size())
-      throw ArgumentSizeMismatch("Int::extensional");
-    if (home.failed()) return;
 
     // Construct view array
     ViewArray<IntView> xv(home,x);
-    switch (epk) {
-    case EPK_SPEED:
-      GECODE_ES_FAIL((Extensional::Incremental<IntView>
-                           ::post(home,xv,t)));
-      break;
-    default:
+    if (ipl & IPL_MEMORY) {
       if (x.same(home)) {
         GECODE_ES_FAIL((Extensional::Basic<IntView,true>
                              ::post(home,xv,t)));
@@ -93,16 +88,21 @@ namespace Gecode {
         GECODE_ES_FAIL((Extensional::Basic<IntView,false>
                              ::post(home,xv,t)));
       }
-      break;
+    } else {
+      GECODE_ES_FAIL((Extensional::Incremental<IntView>
+                           ::post(home,xv,t)));
     }
   }
 
   void
   extensional(Home home, const BoolVarArgs& x, const TupleSet& t,
-              ExtensionalPropKind epk, IntConLevel) {
+              IntPropLevel ipl) {
     using namespace Int;
     if (!t.finalized())
       throw NotYetFinalized("Int::extensional");
+    if (t.arity() != x.size())
+      throw ArgumentSizeMismatch("Int::extensional");
+    GECODE_POST;
 
     if (t.tuples()==0) {
       if (x.size()!=0) {
@@ -111,18 +111,9 @@ namespace Gecode {
       return;
     }
 
-    if (t.arity() != x.size())
-      throw ArgumentSizeMismatch("Int::extensional");
-    if (home.failed()) return;
-
     // Construct view array
     ViewArray<BoolView> xv(home,x);
-    switch (epk) {
-    case EPK_SPEED:
-      GECODE_ES_FAIL((Extensional::Incremental<BoolView>
-                           ::post(home,xv,t)));
-      break;
-    default:
+    if (ipl & IPL_MEMORY) {
       if (x.same(home)) {
         GECODE_ES_FAIL((Extensional::Basic<BoolView,true>
                              ::post(home,xv,t)));
@@ -130,7 +121,9 @@ namespace Gecode {
         GECODE_ES_FAIL((Extensional::Basic<BoolView,false>
                              ::post(home,xv,t)));
       }
-      break;
+    } else {
+      GECODE_ES_FAIL((Extensional::Incremental<BoolView>
+                           ::post(home,xv,t)));
     }
   }
 
