@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2012-09-07 17:31:22 +0200 (Fri, 07 Sep 2012) $ by $Author: schulte $
- *     $Revision: 13068 $
+ *     $Date: 2016-06-29 17:28:17 +0200 (Wed, 29 Jun 2016) $ by $Author: schulte $
+ *     $Revision: 15137 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -80,40 +80,40 @@ namespace Gecode { namespace Int { namespace Extensional {
   template<class View, class Val, class Degree, class StateIdx>
   forceinline void
   LayeredGraph<View,Val,Degree,StateIdx>::State::init(void) {
-    i_deg=o_deg=0; 
+    i_deg=o_deg=0;
   }
 
-  
+
   template<class View, class Val, class Degree, class StateIdx>
-  forceinline typename LayeredGraph<View,Val,Degree,StateIdx>::State& 
+  forceinline typename LayeredGraph<View,Val,Degree,StateIdx>::State&
   LayeredGraph<View,Val,Degree,StateIdx>::i_state(int i, StateIdx is) {
     return layers[i].states[is];
   }
   template<class View, class Val, class Degree, class StateIdx>
-  forceinline typename LayeredGraph<View,Val,Degree,StateIdx>::State& 
+  forceinline typename LayeredGraph<View,Val,Degree,StateIdx>::State&
   LayeredGraph<View,Val,Degree,StateIdx>::i_state
   (int i, const typename LayeredGraph<View,Val,Degree,StateIdx>::Edge& e) {
     return i_state(i,e.i_state);
   }
   template<class View, class Val, class Degree, class StateIdx>
-  forceinline bool 
+  forceinline bool
   LayeredGraph<View,Val,Degree,StateIdx>::i_dec
   (int i, const typename LayeredGraph<View,Val,Degree,StateIdx>::Edge& e) {
     return --i_state(i,e).o_deg == 0;
   }
   template<class View, class Val, class Degree, class StateIdx>
-  forceinline typename LayeredGraph<View,Val,Degree,StateIdx>::State& 
+  forceinline typename LayeredGraph<View,Val,Degree,StateIdx>::State&
   LayeredGraph<View,Val,Degree,StateIdx>::o_state(int i, StateIdx os) {
     return layers[i+1].states[os];
   }
   template<class View, class Val, class Degree, class StateIdx>
-  forceinline typename LayeredGraph<View,Val,Degree,StateIdx>::State& 
+  forceinline typename LayeredGraph<View,Val,Degree,StateIdx>::State&
   LayeredGraph<View,Val,Degree,StateIdx>::o_state
   (int i, const typename LayeredGraph<View,Val,Degree,StateIdx>::Edge& e) {
     return o_state(i,e.o_state);
   }
   template<class View, class Val, class Degree, class StateIdx>
-  forceinline bool 
+  forceinline bool
   LayeredGraph<View,Val,Degree,StateIdx>::o_dec
   (int i, const typename LayeredGraph<View,Val,Degree,StateIdx>::Edge& e) {
     return --o_state(i,e).i_deg == 0;
@@ -235,9 +235,9 @@ namespace Gecode { namespace Int { namespace Extensional {
   template<class Var>
   forceinline
   LayeredGraph<View,Val,Degree,StateIdx>::LayeredGraph(Home home,
-                                                       const VarArgArray<Var>& x, 
+                                                       const VarArgArray<Var>& x,
                                                        const DFA& dfa)
-    : Propagator(home), c(home), n(x.size()), 
+    : Propagator(home), c(home), n(x.size()),
       max_states(static_cast<StateIdx>(dfa.n_states())) {
     assert(n > 0);
   }
@@ -268,7 +268,7 @@ namespace Gecode { namespace Int { namespace Extensional {
   template<class Var>
   forceinline ExecStatus
   LayeredGraph<View,Val,Degree,StateIdx>::initialize(Space& home,
-                                                     const VarArgArray<Var>& x, 
+                                                     const VarArgArray<Var>& x,
                                                      const DFA& dfa) {
 
     Region r(home);
@@ -363,7 +363,7 @@ namespace Gecode { namespace Int { namespace Extensional {
       for (StateIdx j=max_states; j--; )
         d += static_cast<unsigned int>(layers[n].states[j].i_deg);
       // Check whether all final states can be joined to a single state
-      if (d > 
+      if (d >
           static_cast<unsigned int>
           (Gecode::Support::IntTypeTraits<Degree>::max)) {
         // Initialize map for in-states
@@ -381,7 +381,7 @@ namespace Gecode { namespace Int { namespace Extensional {
         layers[n].states[0].o_deg = 1;
       }
       layers[n].n_states = i_n;
-      
+
       // Total number of states
       n_states = i_n;
       // Total number of edges
@@ -403,11 +403,11 @@ namespace Gecode { namespace Int { namespace Extensional {
 
         // Update states in edges
         for (ValSize j=layers[i].size; j--; ) {
-          Support& s = layers[i].support[j];
-          n_edges += s.n_edges;
-          for (Degree d=s.n_edges; d--; ) {
-            s.edges[d].i_state = i_map[s.edges[d].i_state];
-            s.edges[d].o_state = o_map[s.edges[d].o_state];
+          Support& ls = layers[i].support[j];
+          n_edges += ls.n_edges;
+          for (Degree deg=ls.n_edges; deg--; ) {
+            ls.edges[deg].i_state = i_map[ls.edges[deg].i_state];
+            ls.edges[deg].o_state = o_map[ls.edges[deg].o_state];
           }
         }
       }
@@ -424,7 +424,7 @@ namespace Gecode { namespace Int { namespace Extensional {
         layers[i].states = a_states;
         a_states += layers[i].n_states;
       }
-      
+
       // Update maximal number of states
       max_states = max_s;
     }
@@ -453,14 +453,14 @@ namespace Gecode { namespace Int { namespace Extensional {
         states += layers[i].n_states;
         for (ValSize j=layers[i].size; j--; ) {
           Support& s = layers[i].support[j];
-          for (Degree d=s.n_edges; d--; ) {
-            i_state(i,s.edges[d]).o_deg++;
-            o_state(i,s.edges[d]).i_deg++;
+          for (Degree deg=s.n_edges; deg--; ) {
+            i_state(i,s.edges[deg]).o_deg++;
+            o_state(i,s.edges[deg]).i_deg++;
           }
         }
       }
     }
-    
+
     Index& a = static_cast<Index&>(_a);
     const int i = a.i;
 
@@ -484,10 +484,10 @@ namespace Gecode { namespace Int { namespace Extensional {
         Support& s = layers[i].support[j];
         n_edges -= s.n_edges;
         // Supported value not any longer in view
-        for (Degree d=s.n_edges; d--; ) {
+        for (Degree deg=s.n_edges; deg--; ) {
           // Adapt states
-          o_mod |= i_dec(i,s.edges[d]);
-          i_mod |= o_dec(i,s.edges[d]);
+          o_mod |= i_dec(i,s.edges[deg]);
+          i_mod |= o_dec(i,s.edges[deg]);
         }
       }
       assert(layers[i].support[j].val == n);
@@ -495,12 +495,12 @@ namespace Gecode { namespace Int { namespace Extensional {
       ValSize s=layers[i].size;
       layers[i].size = 1;
       for (; j<s; j++) {
-        Support& s = layers[i].support[j];
-        n_edges -= s.n_edges;
-        for (Degree d=s.n_edges; d--; ) {
+        Support& ls = layers[i].support[j];
+        n_edges -= ls.n_edges;
+        for (Degree deg=ls.n_edges; deg--; ) {
           // Adapt states
-          o_mod |= i_dec(i,s.edges[d]);
-          i_mod |= o_dec(i,s.edges[d]);
+          o_mod |= i_dec(i,ls.edges[deg]);
+          i_mod |= o_dec(i,ls.edges[deg]);
         }
       }
     } else if (layers[i].x.any(d)) {
@@ -508,20 +508,20 @@ namespace Gecode { namespace Int { namespace Extensional {
       ValSize k=0;
       ValSize s=layers[i].size;
       for (ViewRanges<View> rx(layers[i].x); rx() && (j<s);) {
-        Support& s = layers[i].support[j];
-        if (s.val < static_cast<Val>(rx.min())) {
+        Support& ls = layers[i].support[j];
+        if (ls.val < static_cast<Val>(rx.min())) {
           // Supported value not any longer in view
-          n_edges -= s.n_edges;
-          for (Degree d=s.n_edges; d--; ) {
+          n_edges -= ls.n_edges;
+          for (Degree deg=ls.n_edges; deg--; ) {
             // Adapt states
-            o_mod |= i_dec(i,s.edges[d]);
-            i_mod |= o_dec(i,s.edges[d]);
+            o_mod |= i_dec(i,ls.edges[deg]);
+            i_mod |= o_dec(i,ls.edges[deg]);
           }
           ++j;
-        } else if (s.val > static_cast<Val>(rx.max())) {
+        } else if (ls.val > static_cast<Val>(rx.max())) {
           ++rx;
         } else {
-          layers[i].support[k++]=s;
+          layers[i].support[k++]=ls;
           ++j;
         }
       }
@@ -529,12 +529,12 @@ namespace Gecode { namespace Int { namespace Extensional {
       layers[i].size = k;
       // Remove remaining values
       for (; j<s; j++) {
-        Support& s=layers[i].support[j];
-        n_edges -= s.n_edges;
-        for (Degree d=s.n_edges; d--; ) {
+        Support& ls=layers[i].support[j];
+        n_edges -= ls.n_edges;
+        for (Degree deg=ls.n_edges; deg--; ) {
           // Adapt states
-          o_mod |= i_dec(i,s.edges[d]);
-          i_mod |= o_dec(i,s.edges[d]);
+          o_mod |= i_dec(i,ls.edges[deg]);
+          i_mod |= o_dec(i,ls.edges[deg]);
         }
       }
     } else {
@@ -547,18 +547,18 @@ namespace Gecode { namespace Int { namespace Extensional {
       ValSize s=layers[i].size;
       // Remove pruned values
       for (; (j<s) && (layers[i].support[j].val <= max); j++) {
-        Support& s=layers[i].support[j];
-        n_edges -= s.n_edges;
-        for (Degree d=s.n_edges; d--; ) {
+        Support& ls=layers[i].support[j];
+        n_edges -= ls.n_edges;
+        for (Degree deg=ls.n_edges; deg--; ) {
           // Adapt states
-          o_mod |= i_dec(i,s.edges[d]);
-          i_mod |= o_dec(i,s.edges[d]);
+          o_mod |= i_dec(i,ls.edges[deg]);
+          i_mod |= o_dec(i,ls.edges[deg]);
         }
       }
       // Keep remaining values
       while (j<s)
         layers[i].support[k++]=layers[i].support[j++];
-      layers[i].size =k;
+      layers[i].size=k;
       assert(k > 0);
     }
 
@@ -591,6 +591,12 @@ namespace Gecode { namespace Int { namespace Extensional {
     return sizeof(*this);
   }
 
+  template<class View, class Val, class Degree, class StateIdx>
+  void
+  LayeredGraph<View,Val,Degree,StateIdx>::reschedule(Space& home) {
+    View::schedule(home,*this,c.empty() ? ME_INT_VAL : ME_INT_DOM);
+  }
+
   template<class View, class Val, class Degree, class StateIdx>
   ExecStatus
   LayeredGraph<View,Val,Degree,StateIdx>::propagate(Space& home,
@@ -601,7 +607,7 @@ namespace Gecode { namespace Int { namespace Extensional {
       bool o_mod = false;
       ValSize j=0;
       ValSize k=0;
-      ValSize s=layers[i].size;
+      ValSize ls=layers[i].size;
       do {
         Support& s=layers[i].support[j];
         n_edges -= s.n_edges;
@@ -621,7 +627,7 @@ namespace Gecode { namespace Int { namespace Extensional {
         } else {
           layers[i].support[k++]=s;
         }
-      } while (++j<s);
+      } while (++j<ls);
       assert(k > 0);
       // Update modification information
       if (o_mod && (i > 0))
@@ -635,7 +641,7 @@ namespace Gecode { namespace Int { namespace Extensional {
       bool o_mod = false;
       ValSize j=0;
       ValSize k=0;
-      ValSize s=layers[i].size;
+      ValSize ls=layers[i].size;
       do {
         Support& s=layers[i].support[j];
         n_edges -= s.n_edges;
@@ -655,7 +661,7 @@ namespace Gecode { namespace Int { namespace Extensional {
         } else {
           layers[i].support[k++]=s;
         }
-      } while (++j<s);
+      } while (++j<ls);
       assert(k > 0);
       // Update modification information
       if (o_mod && (i > 0))
@@ -678,7 +684,7 @@ namespace Gecode { namespace Int { namespace Extensional {
   template<class View, class Val, class Degree, class StateIdx>
   template<class Var>
   ExecStatus
-  LayeredGraph<View,Val,Degree,StateIdx>::post(Home home, 
+  LayeredGraph<View,Val,Degree,StateIdx>::post(Home home,
                                                const VarArgArray<Var>& x,
                                                const DFA& dfa) {
     if (x.size() == 0) {
@@ -703,7 +709,7 @@ namespace Gecode { namespace Int { namespace Extensional {
   LayeredGraph<View,Val,Degree,StateIdx>
   ::LayeredGraph(Space& home, bool share,
                  LayeredGraph<View,Val,Degree,StateIdx>& p)
-    : Propagator(home,share,p), 
+    : Propagator(home,share,p),
       n(p.n), layers(home.alloc<Layer>(n+1)),
       max_states(p.max_states), n_states(p.n_states), n_edges(p.n_edges) {
     c.update(home,share,p.c);
@@ -722,7 +728,7 @@ namespace Gecode { namespace Int { namespace Extensional {
         layers[i].support[j].val = p.layers[i].support[j].val;
         layers[i].support[j].n_edges = p.layers[i].support[j].n_edges;
         assert(layers[i].support[j].n_edges > 0);
-        layers[i].support[j].edges = 
+        layers[i].support[j].edges =
           Heap::copy(edges,p.layers[i].support[j].edges,
                      layers[i].support[j].n_edges);
         edges += layers[i].support[j].n_edges;
@@ -854,7 +860,7 @@ namespace Gecode { namespace Int { namespace Extensional {
       Gecode::Support::u_type(static_cast<unsigned int>(dfa.n_states()));
     Gecode::Support::IntType t_degree =
       Gecode::Support::u_type(dfa.max_degree());
-    Gecode::Support::IntType t_val = 
+    Gecode::Support::IntType t_val =
       std::max(Support::s_type(dfa.symbol_min()),
                Support::s_type(dfa.symbol_max()));
     switch (t_val) {
