@@ -13,8 +13,8 @@
  *     Guido Tack, 2009
  *
  *  Last modified:
- *     $Date: 2012-09-07 17:31:22 +0200 (Fri, 07 Sep 2012) $ by $Author: schulte $
- *     $Revision: 13068 $
+ *     $Date: 2017-03-08 11:58:56 +0100 (Wed, 08 Mar 2017) $ by $Author: schulte $
+ *     $Revision: 15562 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -45,7 +45,7 @@ namespace Gecode { namespace Int { namespace GCC {
 
   /**
    * \defgroup GCCBndSup Support for GCC bounds propagation
-   * 
+   *
    * \ingroup FuncIntProp
    */
 
@@ -75,7 +75,7 @@ namespace Gecode { namespace Int { namespace GCC {
 
   template<class Card>
   ExecStatus
-  prop_card(Space& home, 
+  prop_card(Space& home,
             ViewArray<IntView>& x, ViewArray<Card>& k) {
     int n = x.size();
     int m = k.size();
@@ -256,7 +256,7 @@ namespace Gecode { namespace Int { namespace GCC {
     /// Mark datstructure as requiring reinitialization
     void reinit(void);
     /// Test whether already initialized
-    bool initialized(void) const;
+    operator bool(void) const;
     //@}
     /// \name Access
     //@{
@@ -298,8 +298,8 @@ namespace Gecode { namespace Int { namespace GCC {
   PartialSum<Card>::PartialSum(void) : sum(NULL), size(-1) {}
 
   template<class Card>
-  forceinline bool
-  PartialSum<Card>::initialized(void) const {
+  forceinline
+  PartialSum<Card>::operator bool(void) const {
     return size != -1;
   }
   template<class Card>
