@@ -13,8 +13,8 @@
  *     Guido Tack, 2009
  *
  *  Last modified:
- *     $Date: 2012-09-07 17:31:22 +0200 (Fri, 07 Sep 2012) $ by $Author: schulte $
- *     $Revision: 13068 $
+ *     $Date: 2016-04-19 17:19:45 +0200 (Tue, 19 Apr 2016) $ by $Author: schulte $
+ *     $Revision: 14967 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -108,7 +108,7 @@ namespace Gecode { namespace Int { namespace GCC {
         int n_k = 0;
         for (int i=0; i<k.size(); i++)
           if (k[i].max() == 0) {
-            z[n_z++] = k[i].card();            
+            z[n_z++] = k[i].card();
           } else {
             k[n_k++] = k[i];
           }
@@ -126,7 +126,7 @@ namespace Gecode { namespace Int { namespace GCC {
       for (int i = k.size(); i--; ) {
         t[i].a=1; t[i].x=k[i].base();
       }
-      Linear::post(home,t,k.size(),IRT_EQ,x.size(),ICL_BND);
+      Linear::post(home,t,k.size(),IRT_EQ,x.size(),IPL_BND);
     }
 
     return ES_OK;
