@@ -13,8 +13,8 @@
  *     Guido Tack, 2009
  *
  *  Last modified:
- *     $Date: 2012-09-07 17:31:22 +0200 (Fri, 07 Sep 2012) $ by $Author: schulte $
- *     $Revision: 13068 $
+ *     $Date: 2016-06-29 17:28:17 +0200 (Wed, 29 Jun 2016) $ by $Author: schulte $
+ *     $Revision: 15137 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -44,7 +44,7 @@ namespace Gecode { namespace Int { namespace GCC {
 
   template<class Card>
   forceinline
-  Val<Card>::Val(Home home, 
+  Val<Card>::Val(Home home,
                  ViewArray<IntView>& x0, ViewArray<Card>& k0)
     : Propagator(home), x(x0), k(k0){
     x.subscribe(home, *this, PC_INT_VAL);
@@ -84,12 +84,19 @@ namespace Gecode { namespace Int { namespace GCC {
     return PropCost::linear(PropCost::HI,x.size());
   }
 
+  template<class Card>
+  void
+  Val<Card>::reschedule(Space& home) {
+    x.reschedule(home, *this, PC_INT_VAL);
+    k.reschedule(home, *this, PC_INT_VAL);
+  }
+
   template<class Card>
   ExecStatus
-  prop_val(Space& home, Propagator& p, 
+  prop_val(Space& home, Propagator& p,
            ViewArray<IntView>& x, ViewArray<Card>& k) {
     assert(x.size() > 0);
-    
+
     Region r(home);
     // count[i] denotes how often value k[i].card() occurs in x
     int* count = r.alloc<int>(k.size());
@@ -186,7 +193,7 @@ namespace Gecode { namespace Int { namespace GCC {
         if (ci > k[i].max()) {
           return ES_FAILED;
         }
-        
+
         // in case of variable cardinalities
         if (Card::propagate) {
           GECODE_ME_CHECK(k[i].gq(home, ci));
@@ -217,14 +224,14 @@ namespace Gecode { namespace Int { namespace GCC {
     // remove values
     {
       // Values to prune
-      int* p = r.alloc<int>(k.size());
+      int* pr = r.alloc<int>(k.size());
       // Number of values to prune
-      int n_p = 0;
+      int n_pr = 0;
       for (Iter::Values::BitSet<Support::BitSet<Region> > i(rem); i(); ++i)
-        p[n_p++] = k[i.val()].card();
-      Support::quicksort(p,n_p);
+        pr[n_pr++] = k[i.val()].card();
+      Support::quicksort(pr,n_pr);
       for (int i = x.size(); i--;) {
-        Iter::Values::Array pi(p,n_p);
+        Iter::Values::Array pi(pr,n_pr);
         GECODE_ME_CHECK(x[i].minus_v(home, pi, false));
       }
     }
@@ -243,7 +250,7 @@ namespace Gecode { namespace Int { namespace GCC {
           all_assigned = false;
         }
       }
-      
+
       if (all_assigned) {
         for (int i = k.size(); i--; )
           GECODE_ME_CHECK((k[i].eq(home, count[i] + k[i].counter())));
@@ -264,7 +271,7 @@ namespace Gecode { namespace Int { namespace GCC {
           reqmin += k[i].min() - k[i].counter();
         GECODE_ME_CHECK((k[i].lq(home, x.size()+k[i].counter())));
       }
-    
+
       if ((x.size() < reqmin) || (allmax < x.size())) {
         return ES_FAILED;
       }
@@ -287,7 +294,7 @@ namespace Gecode { namespace Int { namespace GCC {
 
     if (isDistinct<Card>(home,x,k))
       return Distinct::Val<IntView>::post(home,x);
-   
+
     (void) new (home) Val<Card>(home,x,k);
     return ES_OK;
   }
