@@ -7,8 +7,8 @@
  *     Christopher Mears, 2012
  *
  *  Last modified:
- *     $Date: 2013-05-15 20:32:39 +0200 (Wed, 15 May 2013) $ by $Author: schulte $
- *     $Revision: 13639 $
+ *     $Date: 2017-04-01 20:27:10 +0200 (Sat, 01 Apr 2017) $ by $Author: schulte $
+ *     $Revision: 15623 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -62,7 +62,7 @@ namespace Gecode { namespace Int { namespace LDSB {
 
 namespace Gecode {
   using namespace Int::LDSB;
-  
+
   SymmetryHandle VariableSymmetry(const IntVarArgs& vars) {
     ArgArray<VarImpBase*> a(vars.size());
     for (int i = 0 ; i < vars.size() ; i++)
@@ -143,13 +143,13 @@ namespace Gecode { namespace Int { namespace LDSB {
   SymmetryImp<IntView>*
   createIntSym(Space& home, const SymmetryHandle& s,
                VariableMap variableMap) {
-    VariableSymmetryObject* varref    = 
+    VariableSymmetryObject* varref    =
       dynamic_cast<VariableSymmetryObject*>(s.ref);
-    ValueSymmetryObject* valref    =  
+    ValueSymmetryObject* valref    =
       dynamic_cast<ValueSymmetryObject*>(s.ref);
-    VariableSequenceSymmetryObject* varseqref = 
+    VariableSequenceSymmetryObject* varseqref =
       dynamic_cast<VariableSequenceSymmetryObject*>(s.ref);
-    ValueSequenceSymmetryObject* valseqref =  
+    ValueSequenceSymmetryObject* valseqref =
       dynamic_cast<ValueSequenceSymmetryObject*>(s.ref);
     if (varref) {
       int n = varref->nxs;
@@ -176,13 +176,13 @@ namespace Gecode { namespace Int { namespace LDSB {
       int n = varseqref->nxs;
       int* indices = home.alloc<int>(n);
       for (int i = 0 ; i < n ; i++) {
-        VariableMap::const_iterator index = 
+        VariableMap::const_iterator index =
           variableMap.find(varseqref->xs[i]);
         if (index == variableMap.end())
           throw LDSBUnbranchedVariable("VariableSequenceSymmetryObject::createInt");
         indices[i] = index->second;
       }
-      return new (home) VariableSequenceSymmetryImp<IntView>(home, indices, n, 
+      return new (home) VariableSequenceSymmetryImp<IntView>(home, indices, n,
         varseqref->seq_size);
     }
     if (valseqref) {
@@ -190,7 +190,7 @@ namespace Gecode { namespace Int { namespace LDSB {
       int *vs = home.alloc<int>(n);
       for (unsigned int i = 0 ; i < n ; i++)
         vs[i] = valseqref->values[i];
-      return new (home) ValueSequenceSymmetryImp<IntView>(home, vs, n, 
+      return new (home) ValueSequenceSymmetryImp<IntView>(home, vs, n,
         valseqref->seq_size);
     }
     GECODE_NEVER;
@@ -200,13 +200,13 @@ namespace Gecode { namespace Int { namespace LDSB {
   /// Create a boolean symmetry implementation from a symmetry handle
   SymmetryImp<BoolView>* createBoolSym(Space& home, const SymmetryHandle& s,
                                        VariableMap variableMap) {
-    VariableSymmetryObject* varref    = 
+    VariableSymmetryObject* varref    =
       dynamic_cast<VariableSymmetryObject*>(s.ref);
-    ValueSymmetryObject* valref    = 
+    ValueSymmetryObject* valref    =
       dynamic_cast<ValueSymmetryObject*>(s.ref);
-    VariableSequenceSymmetryObject* varseqref = 
+    VariableSequenceSymmetryObject* varseqref =
       dynamic_cast<VariableSequenceSymmetryObject*>(s.ref);
-    ValueSequenceSymmetryObject* valseqref =  
+    ValueSequenceSymmetryObject* valseqref =
       dynamic_cast<ValueSequenceSymmetryObject*>(s.ref);
     if (varref) {
       int n = varref->nxs;
@@ -233,13 +233,13 @@ namespace Gecode { namespace Int { namespace LDSB {
       int n = varseqref->nxs;
       int* indices = home.alloc<int>(n);
       for (int i = 0 ; i < n ; i++) {
-        VariableMap::const_iterator index = 
+        VariableMap::const_iterator index =
           variableMap.find(varseqref->xs[i]);
         if (index == variableMap.end())
           throw LDSBUnbranchedVariable("VariableSequenceSymmetryObject::createBool");
         indices[i] = index->second;
       }
-      return new (home) VariableSequenceSymmetryImp<BoolView>(home, indices, 
+      return new (home) VariableSequenceSymmetryImp<BoolView>(home, indices,
         n, varseqref->seq_size);
     }
     if (valseqref) {
@@ -247,7 +247,7 @@ namespace Gecode { namespace Int { namespace LDSB {
       int *vs = home.alloc<int>(n);
       for (unsigned int i = 0 ; i < n ; i++)
         vs[i] = valseqref->values[i];
-      return new (home) ValueSequenceSymmetryImp<BoolView>(home, vs, n, 
+      return new (home) ValueSequenceSymmetryImp<BoolView>(home, vs, n,
         valseqref->seq_size);
     }
     GECODE_NEVER;
@@ -259,17 +259,18 @@ namespace Gecode {
 
   using namespace Int::LDSB;
 
-  BrancherHandle
+  void
   branch(Home home, const IntVarArgs& x,
          IntVarBranch vars, IntValBranch vals,
-         const Symmetries& syms, 
-         IntBranchFilter bf, IntVarValPrint vvp) {
+         const Symmetries& syms,
+         IntBranchFilter bf,
+         IntVarValPrint vvp) {
     using namespace Int;
-    if (home.failed()) return BrancherHandle();
+    if (home.failed()) return;
     vars.expand(home,x);
     ViewArray<IntView> xv(home,x);
-    ViewSel<IntView>* vs[1] = { 
-      Branch::viewselint(home,vars) 
+    ViewSel<IntView>* vs[1] = {
+      Branch::viewsel(home,vars)
     };
     switch (vals.select()) {
     case IntValBranch::SEL_SPLIT_MIN:
@@ -281,9 +282,9 @@ namespace Gecode {
       throw LDSBBadValueSelection("Int::LDSB::branch");
       break;
     case IntValBranch::SEL_VAL_COMMIT:
-      if (vals.commit() != NULL)
+      if (vals.commit())
         throw LDSBBadValueSelection("Int::LDSB::branch");
-      // If vals.commit() returns NULL, it means it will commit with
+      // If vals.commit() is valid, it means it will commit with
       // binary branching, which is OK for LDSB, so we fall through.
     default:
       // Construct mapping from each variable in the array to its index
@@ -301,19 +302,20 @@ namespace Gecode {
         array[i] = createIntSym(home, syms[i], variableMap);
       }
 
-      return LDSBBrancher<IntView,1,int,2>::post
-        (home,xv,vs,Branch::valselcommitint(home,x.size(),vals),
+      postldsbbrancher<IntView,1,int,2>
+        (home,xv,vs,Branch::valselcommit(home,vals),
          array,n,bf,vvp);
     }
   }
 
-  BrancherHandle
+  void
   branch(Home home, const IntVarArgs& x,
          TieBreak<IntVarBranch> vars, IntValBranch vals,
-         const Symmetries& syms, 
-         IntBranchFilter bf, IntVarValPrint vvp) {
+         const Symmetries& syms,
+         IntBranchFilter bf,
+         IntVarValPrint vvp) {
     using namespace Int;
-    if (home.failed()) return BrancherHandle();
+    if (home.failed()) return;
     vars.a.expand(home,x);
     if ((vars.a.select() == IntVarBranch::SEL_NONE) ||
         (vars.a.select() == IntVarBranch::SEL_RND))
@@ -328,7 +330,7 @@ namespace Gecode {
       vars.d = INT_VAR_NONE();
     vars.d.expand(home,x);
     if (vars.b.select() == IntVarBranch::SEL_NONE) {
-      return branch(home,x,vars.a,vals,syms,bf,vvp);
+      branch(home,x,vars.a,vals,syms,bf,vvp);
     } else {
       // Construct mapping from each variable in the array to its index
       // in the array.
@@ -348,7 +350,7 @@ namespace Gecode {
       ViewArray<IntView> xv(home,x);
       if (vars.c.select() == IntVarBranch::SEL_NONE) {
         ViewSel<IntView>* vs[2] = {
-          Branch::viewselint(home,vars.a),Branch::viewselint(home,vars.b)
+          Branch::viewsel(home,vars.a),Branch::viewsel(home,vars.b)
         };
         switch (vals.select()) {
         case IntValBranch::SEL_SPLIT_MIN:
@@ -360,19 +362,19 @@ namespace Gecode {
           throw LDSBBadValueSelection("Int::LDSB::branch");
           break;
         case IntValBranch::SEL_VAL_COMMIT:
-          if (vals.commit() != NULL)
+          if (vals.commit())
             throw LDSBBadValueSelection("Int::LDSB::branch");
-          // If vals.commit() returns NULL, it means it will commit with
+          // If vals.commit() is valid, it means it will commit with
           // binary branching, which is OK for LDSB, so we fall through.
         default:
-          return LDSBBrancher<IntView,2,int,2>
-            ::post(home,xv,vs,Branch::valselcommitint(home,x.size(),vals),
-                   array,n,bf,vvp);
+          postldsbbrancher<IntView,2,int,2>
+            (home,xv,vs,Branch::valselcommit(home,vals),
+             array,n,bf,vvp);
         }
       } else if (vars.d.select() == IntVarBranch::SEL_NONE) {
         ViewSel<IntView>* vs[3] = {
-          Branch::viewselint(home,vars.a),Branch::viewselint(home,vars.b),
-          Branch::viewselint(home,vars.c)
+          Branch::viewsel(home,vars.a),Branch::viewsel(home,vars.b),
+          Branch::viewsel(home,vars.c)
         };
         switch (vals.select()) {
         case IntValBranch::SEL_SPLIT_MIN:
@@ -384,19 +386,19 @@ namespace Gecode {
           throw LDSBBadValueSelection("Int::LDSB::branch");
           break;
         case IntValBranch::SEL_VAL_COMMIT:
-          if (vals.commit() != NULL)
+          if (vals.commit())
             throw LDSBBadValueSelection("Int::LDSB::branch");
-          // If vals.commit() returns NULL, it means it will commit with
+          // If vals.commit() is valid, it means it will commit with
           // binary branching, which is OK for LDSB, so we fall through.
         default:
-          return LDSBBrancher<IntView,3,int,2>
-            ::post(home,xv,vs,Branch::valselcommitint(home,x.size(),vals),
-                   array,n,bf,vvp);
+          postldsbbrancher<IntView,3,int,2>
+            (home,xv,vs,Branch::valselcommit(home,vals),
+             array,n,bf,vvp);
         }
       } else {
         ViewSel<IntView>* vs[4] = {
-          Branch::viewselint(home,vars.a),Branch::viewselint(home,vars.b),
-          Branch::viewselint(home,vars.c),Branch::viewselint(home,vars.d)
+          Branch::viewsel(home,vars.a),Branch::viewsel(home,vars.b),
+          Branch::viewsel(home,vars.c),Branch::viewsel(home,vars.d)
         };
         switch (vals.select()) {
         case IntValBranch::SEL_SPLIT_MIN:
@@ -408,32 +410,31 @@ namespace Gecode {
           throw LDSBBadValueSelection("Int::LDSB::branch");
           break;
         case IntValBranch::SEL_VAL_COMMIT:
-          if (vals.commit() != NULL)
+          if (vals.commit())
             throw LDSBBadValueSelection("Int::LDSB::branch");
-          // If vals.commit() returns NULL, it means it will commit with
+          // If vals.commit() is valid, it means it will commit with
           // binary branching, which is OK for LDSB, so we fall through.
         default:
-          return LDSBBrancher<IntView,4,int,2>
-            ::post(home,xv,vs,Branch::valselcommitint(home,x.size(),vals),
-                   array,n,bf,vvp);
+          postldsbbrancher<IntView,4,int,2>
+            (home,xv,vs,Branch::valselcommit(home,vals),
+             array,n,bf,vvp);
         }
       }
     }
-    GECODE_NEVER;
-    return BrancherHandle();
   }
 
-  BrancherHandle
+  void
   branch(Home home, const BoolVarArgs& x,
-         IntVarBranch vars, IntValBranch vals,
-         const Symmetries& syms, 
-         BoolBranchFilter bf, BoolVarValPrint vvp) {
+         BoolVarBranch vars, BoolValBranch vals,
+         const Symmetries& syms,
+         BoolBranchFilter bf,
+         BoolVarValPrint vvp) {
     using namespace Int;
-    if (home.failed()) return BrancherHandle();
+    if (home.failed()) return;
     vars.expand(home,x);
     ViewArray<BoolView> xv(home,x);
-    ViewSel<BoolView>* vs[1] = { 
-      Branch::viewselbool(home,vars) 
+    ViewSel<BoolView>* vs[1] = {
+      Branch::viewsel(home,vars)
     };
 
     // Construct mapping from each variable in the array to its index
@@ -456,50 +457,41 @@ namespace Gecode {
     // Booleans.  Nonetheless, we explicitly forbid them for
     // consistency with the integer version.
     switch (vals.select()) {
-    case IntValBranch::SEL_SPLIT_MIN:
-    case IntValBranch::SEL_SPLIT_MAX:
-    case IntValBranch::SEL_RANGE_MIN:
-    case IntValBranch::SEL_RANGE_MAX:
-    case IntValBranch::SEL_VALUES_MIN:
-    case IntValBranch::SEL_VALUES_MAX:
-      throw LDSBBadValueSelection("Int::LDSB::branch");
-      break;
-    case IntValBranch::SEL_VAL_COMMIT:
-      if (vals.commit() != NULL)
+    case BoolValBranch::SEL_VAL_COMMIT:
+      if (vals.commit())
         throw LDSBBadValueSelection("Int::LDSB::branch");
-      // If vals.commit() returns NULL, it means it will commit with
+      // If vals.commit() is valid, it means it will commit with
       // binary branching, which is OK for LDSB, so we fall through.
     default:
-      return LDSBBrancher<BoolView,1,int,2>::post
-        (home,xv,vs,Branch::valselcommitbool(home,x.size(),vals),array,n,bf,vvp);
+      postldsbbrancher<BoolView,1,int,2>
+        (home,xv,vs,Branch::valselcommit(home,vals),array,n,bf,vvp);
     }
-    GECODE_NEVER;
-    return BrancherHandle();
   }
 
 
-  BrancherHandle
+  void
   branch(Home home, const BoolVarArgs& x,
-         TieBreak<IntVarBranch> vars, IntValBranch vals,
-         const Symmetries& syms, 
-         BoolBranchFilter bf, BoolVarValPrint vvp) {
+         TieBreak<BoolVarBranch> vars, BoolValBranch vals,
+         const Symmetries& syms,
+         BoolBranchFilter bf,
+         BoolVarValPrint vvp) {
     using namespace Int;
-    if (home.failed()) return BrancherHandle();
+    if (home.failed()) return;
     vars.a.expand(home,x);
-    if ((vars.a.select() == IntVarBranch::SEL_NONE) ||
-        (vars.a.select() == IntVarBranch::SEL_RND))
-      vars.b = INT_VAR_NONE();
+    if ((vars.a.select() == BoolVarBranch::SEL_NONE) ||
+        (vars.a.select() == BoolVarBranch::SEL_RND))
+      vars.b = BOOL_VAR_NONE();
     vars.b.expand(home,x);
-    if ((vars.b.select() == IntVarBranch::SEL_NONE) ||
-        (vars.b.select() == IntVarBranch::SEL_RND))
-      vars.c = INT_VAR_NONE();
+    if ((vars.b.select() == BoolVarBranch::SEL_NONE) ||
+        (vars.b.select() == BoolVarBranch::SEL_RND))
+      vars.c = BOOL_VAR_NONE();
     vars.c.expand(home,x);
-    if ((vars.c.select() == IntVarBranch::SEL_NONE) ||
-        (vars.c.select() == IntVarBranch::SEL_RND))
-      vars.d = INT_VAR_NONE();
+    if ((vars.c.select() == BoolVarBranch::SEL_NONE) ||
+        (vars.c.select() == BoolVarBranch::SEL_RND))
+      vars.d = BOOL_VAR_NONE();
     vars.d.expand(home,x);
-    if (vars.b.select() == IntVarBranch::SEL_NONE) {
-      return branch(home,x,vars.a,vals,syms,bf,vvp);
+    if (vars.b.select() == BoolVarBranch::SEL_NONE) {
+      branch(home,x,vars.a,vals,syms,bf,vvp);
     } else {
       // Construct mapping from each variable in the array to its index
       // in the array.
@@ -521,18 +513,10 @@ namespace Gecode {
       // Booleans.  Nonetheless, we explicitly forbid them for
       // consistency with the integer version.
       switch (vals.select()) {
-      case IntValBranch::SEL_SPLIT_MIN:
-      case IntValBranch::SEL_SPLIT_MAX:
-      case IntValBranch::SEL_RANGE_MIN:
-      case IntValBranch::SEL_RANGE_MAX:
-      case IntValBranch::SEL_VALUES_MIN:
-      case IntValBranch::SEL_VALUES_MAX:
-        throw LDSBBadValueSelection("Int::LDSB::branch");
-        break;
-      case IntValBranch::SEL_VAL_COMMIT:
-        if (vals.commit() != NULL)
+      case BoolValBranch::SEL_VAL_COMMIT:
+        if (vals.commit())
           throw LDSBBadValueSelection("Int::LDSB::branch");
-        // If vals.commit() returns NULL, it means it will commit with
+        // If vals.commit() is valid, it means it will commit with
         // binary branching, which is OK for LDSB, so we fall through.
       default:
         ;
@@ -540,32 +524,27 @@ namespace Gecode {
       }
 
       ViewArray<BoolView> xv(home,x);
-      ValSelCommitBase<BoolView,int>* 
-        vsc = Branch::valselcommitbool(home,x.size(),vals); 
-      if (vars.c.select() == IntVarBranch::SEL_NONE) {
-        ViewSel<BoolView>* vs[2] = { 
-          Branch::viewselbool(home,vars.a),Branch::viewselbool(home,vars.b)
+      ValSelCommitBase<BoolView,int>*
+        vsc = Branch::valselcommit(home,vals);
+      if (vars.c.select() == BoolVarBranch::SEL_NONE) {
+        ViewSel<BoolView>* vs[2] = {
+          Branch::viewsel(home,vars.a),Branch::viewsel(home,vars.b)
         };
-        return 
-          LDSBBrancher<BoolView,2,int,2>::post(home,xv,vs,vsc,array,n,bf,vvp);
-      } else if (vars.d.select() == IntVarBranch::SEL_NONE) {
-        ViewSel<BoolView>* vs[3] = { 
-          Branch::viewselbool(home,vars.a),Branch::viewselbool(home,vars.b),
-          Branch::viewselbool(home,vars.c)
+        postldsbbrancher<BoolView,2,int,2>(home,xv,vs,vsc,array,n,bf,vvp);
+      } else if (vars.d.select() == BoolVarBranch::SEL_NONE) {
+        ViewSel<BoolView>* vs[3] = {
+          Branch::viewsel(home,vars.a),Branch::viewsel(home,vars.b),
+          Branch::viewsel(home,vars.c)
         };
-        return 
-          LDSBBrancher<BoolView,3,int,2>::post(home,xv,vs,vsc,array,n,bf,vvp);
+        postldsbbrancher<BoolView,3,int,2>(home,xv,vs,vsc,array,n,bf,vvp);
       } else {
-        ViewSel<BoolView>* vs[4] = { 
-          Branch::viewselbool(home,vars.a),Branch::viewselbool(home,vars.b),
-          Branch::viewselbool(home,vars.c),Branch::viewselbool(home,vars.d)
+        ViewSel<BoolView>* vs[4] = {
+          Branch::viewsel(home,vars.a),Branch::viewsel(home,vars.b),
+          Branch::viewsel(home,vars.c),Branch::viewsel(home,vars.d)
         };
-        return 
-          LDSBBrancher<BoolView,4,int,2>::post(home,xv,vs,vsc,array,n,bf,vvp);
+        postldsbbrancher<BoolView,4,int,2>(home,xv,vs,vsc,array,n,bf,vvp);
       }
     }
-    GECODE_NEVER;
-    return BrancherHandle();
   }
 
 }
