@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2010-03-04 03:40:32 +1100 (Thu, 04 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10365 $
+ *     $Date: 2016-05-23 22:18:23 +0200 (Mon, 23 May 2016) $ by $Author: schulte $
+ *     $Revision: 15073 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -43,65 +43,65 @@ namespace Gecode {
 
   void
   linear(Home home,
-         const IntVarArgs& x, IntRelType r, int c,
-         IntConLevel icl) {
-    if (home.failed()) return;
+         const IntVarArgs& x, IntRelType irt, int c,
+         IntPropLevel ipl) {
+    GECODE_POST;
     Region re(home);
     Linear::Term<IntView>* t = re.alloc<Linear::Term<IntView> >(x.size());
     for (int i = x.size(); i--; ) {
       t[i].a=1; t[i].x=x[i];
     }
-    Linear::post(home,t,x.size(),r,c,icl);
+    Linear::post(home,t,x.size(),irt,c,ipl);
   }
 
   void
   linear(Home home,
-         const IntVarArgs& x, IntRelType r, int c, BoolVar b,
-         IntConLevel) {
-    if (home.failed()) return;
+         const IntVarArgs& x, IntRelType irt, int c, Reify r,
+         IntPropLevel) {
+    GECODE_POST;
     Region re(home);
     Linear::Term<IntView>* t = re.alloc<Linear::Term<IntView> >(x.size());
     for (int i = x.size(); i--; ) {
       t[i].a=1; t[i].x=x[i];
     }
-    Linear::post(home,t,x.size(),r,c,b);
+    Linear::post(home,t,x.size(),irt,c,r);
   }
 
   void
   linear(Home home,
-         const IntArgs& a, const IntVarArgs& x, IntRelType r, int c,
-         IntConLevel icl) {
+         const IntArgs& a, const IntVarArgs& x, IntRelType irt, int c,
+         IntPropLevel ipl) {
     if (a.size() != x.size())
       throw ArgumentSizeMismatch("Int::linear");
-    if (home.failed()) return;
+    GECODE_POST;
     Region re(home);
     Linear::Term<IntView>* t = re.alloc<Linear::Term<IntView> >(x.size());
     for (int i = x.size(); i--; ) {
       t[i].a=a[i]; t[i].x=x[i];
     }
-    Linear::post(home,t,x.size(),r,c,icl);
+    Linear::post(home,t,x.size(),irt,c,ipl);
   }
 
   void
   linear(Home home,
-         const IntArgs& a, const IntVarArgs& x, IntRelType r, int c, BoolVar b,
-         IntConLevel) {
+         const IntArgs& a, const IntVarArgs& x, IntRelType irt, int c,
+         Reify r, IntPropLevel) {
     if (a.size() != x.size())
       throw ArgumentSizeMismatch("Int::linear");
-    if (home.failed()) return;
+    GECODE_POST;
     Region re(home);
     Linear::Term<IntView>* t = re.alloc<Linear::Term<IntView> >(x.size());
     for (int i = x.size(); i--; ) {
       t[i].a=a[i]; t[i].x=x[i];
     }
-    Linear::post(home,t,x.size(),r,c,b);
+    Linear::post(home,t,x.size(),irt,c,r);
   }
 
   void
   linear(Home home,
-         const IntVarArgs& x, IntRelType r, IntVar y,
-         IntConLevel icl) {
-    if (home.failed()) return;
+         const IntVarArgs& x, IntRelType irt, IntVar y,
+         IntPropLevel ipl) {
+    GECODE_POST;
     Region re(home);
     Linear::Term<IntView>* t = re.alloc<Linear::Term<IntView> >(x.size()+1);
     for (int i = x.size(); i--; ) {
@@ -110,7 +110,7 @@ namespace Gecode {
     int min, max;
     estimate(t,x.size(),0,min,max);
     IntView v(y);
-    switch (r) {
+    switch (irt) {
     case IRT_EQ:
       GECODE_ME_FAIL(v.gq(home,min)); GECODE_ME_FAIL(v.lq(home,max));
       break;
@@ -124,30 +124,30 @@ namespace Gecode {
     }
     if (home.failed()) return;
     t[x.size()].a=-1; t[x.size()].x=y;
-    Linear::post(home,t,x.size()+1,r,0,icl);
+    Linear::post(home,t,x.size()+1,irt,0,ipl);
   }
 
   void
   linear(Home home,
-         const IntVarArgs& x, IntRelType r, IntVar y, BoolVar b,
-         IntConLevel) {
-    if (home.failed()) return;
+         const IntVarArgs& x, IntRelType irt, IntVar y, Reify r,
+         IntPropLevel) {
+    GECODE_POST;
     Region re(home);
     Linear::Term<IntView>* t = re.alloc<Linear::Term<IntView> >(x.size()+1);
     for (int i = x.size(); i--; ) {
       t[i].a=1; t[i].x=x[i];
     }
     t[x.size()].a=-1; t[x.size()].x=y;
-    Linear::post(home,t,x.size()+1,r,0,b);
+    Linear::post(home,t,x.size()+1,irt,0,r);
   }
 
   void
   linear(Home home,
-         const IntArgs& a, const IntVarArgs& x, IntRelType r, IntVar y,
-         IntConLevel icl) {
+         const IntArgs& a, const IntVarArgs& x, IntRelType irt, IntVar y,
+         IntPropLevel ipl) {
     if (a.size() != x.size())
       throw ArgumentSizeMismatch("Int::linear");
-    if (home.failed()) return;
+    GECODE_POST;
     Region re(home);
     Linear::Term<IntView>* t = re.alloc<Linear::Term<IntView> >(x.size()+1);
     for (int i = x.size(); i--; ) {
@@ -156,7 +156,7 @@ namespace Gecode {
     int min, max;
     estimate(t,x.size(),0,min,max);
     IntView v(y);
-    switch (r) {
+    switch (irt) {
     case IRT_EQ:
       GECODE_ME_FAIL(v.gq(home,min)); GECODE_ME_FAIL(v.lq(home,max));
       break;
@@ -170,23 +170,23 @@ namespace Gecode {
     }
     if (home.failed()) return;
     t[x.size()].a=-1; t[x.size()].x=y;
-    Linear::post(home,t,x.size()+1,r,0,icl);
+    Linear::post(home,t,x.size()+1,irt,0,ipl);
   }
 
   void
   linear(Home home,
-         const IntArgs& a, const IntVarArgs& x, IntRelType r, IntVar y,
-         BoolVar b, IntConLevel) {
+         const IntArgs& a, const IntVarArgs& x, IntRelType irt, IntVar y,
+         Reify r, IntPropLevel) {
     if (a.size() != x.size())
       throw ArgumentSizeMismatch("Int::linear");
-    if (home.failed()) return;
+    GECODE_POST;
     Region re(home);
     Linear::Term<IntView>* t = re.alloc<Linear::Term<IntView> >(x.size()+1);
     for (int i = x.size(); i--; ) {
       t[i].a=a[i]; t[i].x=x[i];
     }
     t[x.size()].a=-1; t[x.size()].x=y;
-    Linear::post(home,t,x.size()+1,r,0,b);
+    Linear::post(home,t,x.size()+1,irt,0,r);
   }
 
 }
