@@ -7,8 +7,8 @@
  *     Christian Schulte, 2003
  *
  *  Last modified:
- *     $Date: 2010-03-04 03:32:21 +1100 (Thu, 04 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10364 $
+ *     $Date: 2016-06-29 17:28:17 +0200 (Wed, 29 Jun 2016) $ by $Author: schulte $
+ *     $Revision: 15137 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -82,6 +82,13 @@ namespace Gecode { namespace Int { namespace Linear {
     return PropCost::linear(PropCost::LO, x.size()+y.size());
   }
 
+  template<class Val, class P, class N, PropCond pc>
+  void
+  Lin<Val,P,N,pc>::reschedule(Space& home) {
+    x.reschedule(home,*this,pc);
+    y.reschedule(home,*this,pc);
+  }
+
   template<class Val, class P, class N, PropCond pc>
   forceinline size_t
   Lin<Val,P,N,pc>::dispose(Space& home) {
@@ -111,6 +118,14 @@ namespace Gecode { namespace Int { namespace Linear {
     b.update(home,share,p.b);
   }
 
+  template<class Val, class P, class N, PropCond pc, class Ctrl>
+  void
+  ReLin<Val,P,N,pc,Ctrl>::reschedule(Space& home) {
+    x.reschedule(home,*this,pc);
+    y.reschedule(home,*this,pc);
+    b.reschedule(home,*this,PC_INT_VAL);
+  }
+
   template<class Val, class P, class N, PropCond pc, class Ctrl>
   forceinline size_t
   ReLin<Val,P,N,pc,Ctrl>::dispose(Space& home) {
@@ -389,46 +404,53 @@ namespace Gecode { namespace Int { namespace Linear {
    *
    */
 
-  template<class Val, class P, class N, class Ctrl>
+  template<class Val, class P, class N, class Ctrl, ReifyMode rm>
   forceinline
-  ReEq<Val,P,N,Ctrl>::ReEq(Home home,
-                           ViewArray<P>& x, ViewArray<N>& y, Val c, Ctrl b)
+  ReEq<Val,P,N,Ctrl,rm>::ReEq(Home home,
+                              ViewArray<P>& x, ViewArray<N>& y, Val c, Ctrl b)
     : ReLin<Val,P,N,PC_INT_BND,Ctrl>(home,x,y,c,b) {}
 
-  template<class Val, class P, class N, class Ctrl>
+  template<class Val, class P, class N, class Ctrl, ReifyMode rm>
   ExecStatus
-  ReEq<Val,P,N,Ctrl>::post(Home home,
-                           ViewArray<P>& x, ViewArray<N>& y, Val c, Ctrl b) {
+  ReEq<Val,P,N,Ctrl,rm>::post(Home home,
+                              ViewArray<P>& x, ViewArray<N>& y, Val c, Ctrl b) {
     ViewArray<NoView> nva;
     if (y.size() == 0) {
-      (void) new (home) ReEq<Val,P,NoView,Ctrl>(home,x,nva,c,b);
+      (void) new (home) ReEq<Val,P,NoView,Ctrl,rm>(home,x,nva,c,b);
     } else if (x.size() == 0) {
-      (void) new (home) ReEq<Val,N,NoView,Ctrl>(home,y,nva,-c,b);
+      (void) new (home) ReEq<Val,N,NoView,Ctrl,rm>(home,y,nva,-c,b);
     } else {
-      (void) new (home) ReEq<Val,P,N,Ctrl>(home,x,y,c,b);
+      (void) new (home) ReEq<Val,P,N,Ctrl,rm>(home,x,y,c,b);
     }
     return ES_OK;
   }
 
 
-  template<class Val, class P, class N, class Ctrl>
+  template<class Val, class P, class N, class Ctrl, ReifyMode rm>
   forceinline
-  ReEq<Val,P,N,Ctrl>::ReEq(Space& home, bool share, ReEq<Val,P,N,Ctrl>& p)
+  ReEq<Val,P,N,Ctrl,rm>::ReEq(Space& home, bool share,
+                              ReEq<Val,P,N,Ctrl,rm>& p)
     : ReLin<Val,P,N,PC_INT_BND,Ctrl>(home,share,p) {}
 
-  template<class Val, class P, class N, class Ctrl>
+  template<class Val, class P, class N, class Ctrl, ReifyMode rm>
   Actor*
-  ReEq<Val,P,N,Ctrl>::copy(Space& home, bool share) {
-    return new (home) ReEq<Val,P,N,Ctrl>(home,share,*this);
+  ReEq<Val,P,N,Ctrl,rm>::copy(Space& home, bool share) {
+    return new (home) ReEq<Val,P,N,Ctrl,rm>(home,share,*this);
   }
 
-  template<class Val, class P, class N, class Ctrl>
+  template<class Val, class P, class N, class Ctrl, ReifyMode rm>
   ExecStatus
-  ReEq<Val,P,N,Ctrl>::propagate(Space& home, const ModEventDelta& med) {
-    if (b.zero())
+  ReEq<Val,P,N,Ctrl,rm>::propagate(Space& home, const ModEventDelta& med) {
+    if (b.zero()) {
+      if (rm == RM_IMP)
+        return home.ES_SUBSUMED(*this);
       GECODE_REWRITE(*this,(Nq<Val,P,N>::post(home(*this),x,y,c)));
-    if (b.one())
+    }
+    if (b.one()) {
+      if (rm == RM_PMI)
+        return home.ES_SUBSUMED(*this);
       GECODE_REWRITE(*this,(Eq<Val,P,N>::post(home(*this),x,y,c)));
+    }
 
     Val sl = 0;
     Val su = 0;
@@ -437,11 +459,13 @@ namespace Gecode { namespace Int { namespace Linear {
     bounds_n<Val,N>(med, y, c, sl, su);
 
     if ((-sl == c) && (-su == c)) {
-      GECODE_ME_CHECK(b.one_none(home));
+      if (rm != RM_IMP)
+        GECODE_ME_CHECK(b.one_none(home));
       return home.ES_SUBSUMED(*this);
     }
     if ((-sl > c) || (-su < c)) {
-      GECODE_ME_CHECK(b.zero_none(home));
+      if (rm != RM_PMI)
+        GECODE_ME_CHECK(b.zero_none(home));
       return home.ES_SUBSUMED(*this);
     }
     return ES_FIX;
@@ -798,46 +822,52 @@ namespace Gecode { namespace Int { namespace Linear {
    *
    */
 
-  template<class Val, class P, class N>
+  template<class Val, class P, class N, ReifyMode rm>
   forceinline
-  ReLq<Val,P,N>::ReLq
-  (Home home, ViewArray<P>& x, ViewArray<N>& y, Val c, BoolView b)
+  ReLq<Val,P,N,rm>::ReLq(Home home,
+                      ViewArray<P>& x, ViewArray<N>& y, Val c, BoolView b)
     : ReLin<Val,P,N,PC_INT_BND,BoolView>(home,x,y,c,b) {}
 
-  template<class Val, class P, class N>
+  template<class Val, class P, class N, ReifyMode rm>
   ExecStatus
-  ReLq<Val,P,N>::post
-  (Home home, ViewArray<P>& x, ViewArray<N>& y, Val c, BoolView b) {
+  ReLq<Val,P,N,rm>::post(Home home,
+                         ViewArray<P>& x, ViewArray<N>& y, Val c, BoolView b) {
     ViewArray<NoView> nva;
     if (y.size() == 0) {
-      (void) new (home) ReLq<Val,P,NoView>(home,x,nva,c,b);
+      (void) new (home) ReLq<Val,P,NoView,rm>(home,x,nva,c,b);
     } else if (x.size() == 0) {
-      (void) new (home) ReLq<Val,NoView,N>(home,nva,y,c,b);
+      (void) new (home) ReLq<Val,NoView,N,rm>(home,nva,y,c,b);
     } else {
-      (void) new (home) ReLq<Val,P,N>(home,x,y,c,b);
+      (void) new (home) ReLq<Val,P,N,rm>(home,x,y,c,b);
     }
     return ES_OK;
   }
 
 
-  template<class Val, class P, class N>
+  template<class Val, class P, class N, ReifyMode rm>
   forceinline
-  ReLq<Val,P,N>::ReLq(Space& home, bool share, ReLq<Val,P,N>& p)
+  ReLq<Val,P,N,rm>::ReLq(Space& home, bool share, ReLq<Val,P,N,rm>& p)
     : ReLin<Val,P,N,PC_INT_BND,BoolView>(home,share,p) {}
 
-  template<class Val, class P, class N>
+  template<class Val, class P, class N, ReifyMode rm>
   Actor*
-  ReLq<Val,P,N>::copy(Space& home, bool share) {
-    return new (home) ReLq<Val,P,N>(home,share,*this);
+  ReLq<Val,P,N,rm>::copy(Space& home, bool share) {
+    return new (home) ReLq<Val,P,N,rm>(home,share,*this);
   }
 
-  template<class Val, class P, class N>
+  template<class Val, class P, class N, ReifyMode rm>
   ExecStatus
-  ReLq<Val,P,N>::propagate(Space& home, const ModEventDelta& med) {
-    if (b.zero())
+  ReLq<Val,P,N,rm>::propagate(Space& home, const ModEventDelta& med) {
+    if (b.zero()) {
+      if (rm == RM_IMP)
+        return home.ES_SUBSUMED(*this);
       GECODE_REWRITE(*this,(Lq<Val,N,P>::post(home(*this),y,x,-c-1)));
-    if (b.one())
+    }
+    if (b.one()) {
+      if (rm == RM_PMI)
+        return home.ES_SUBSUMED(*this);
       GECODE_REWRITE(*this,(Lq<Val,P,N>::post(home(*this),x,y,c)));
+    }
 
     // Eliminate singletons
     Val sl = 0;
@@ -847,11 +877,13 @@ namespace Gecode { namespace Int { namespace Linear {
     bounds_n<Val,N>(med,y,c,sl,su);
 
     if (-sl > c) {
-      GECODE_ME_CHECK(b.zero_none(home));
+      if (rm != RM_PMI)
+        GECODE_ME_CHECK(b.zero_none(home));
       return home.ES_SUBSUMED(*this);
     }
     if (-su <= c) {
-      GECODE_ME_CHECK(b.one_none(home));
+      if (rm != RM_IMP)
+        GECODE_ME_CHECK(b.one_none(home));
       return home.ES_SUBSUMED(*this);
     }
 
