@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2013-02-14 16:29:11 +0100 (Thu, 14 Feb 2013) $ by $Author: schulte $
- *     $Revision: 13292 $
+ *     $Date: 2016-06-29 17:28:17 +0200 (Wed, 29 Jun 2016) $ by $Author: schulte $
+ *     $Revision: 15137 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -216,6 +216,10 @@ namespace Gecode {
     void cancel(Space& home, Propagator& p, PropCond pc) {
       (void) home; (void) p; (void) pc;
     }
+    /// Schedule propagator \a p
+    void reschedule(Space& home, Propagator& p, PropCond pc) {
+      (void) home; (void) p; (void) pc;
+    }
     //@}
 
     /// \name Cloning
