@@ -7,8 +7,8 @@
  *     Christian Schulte, 2011
  *
  *  Last modified:
- *     $Date: 2011-07-13 18:16:57 +0200 (Wed, 13 Jul 2011) $ by $Author: schulte $
- *     $Revision: 12192 $
+ *     $Date: 2016-06-29 17:28:17 +0200 (Wed, 29 Jun 2016) $ by $Author: schulte $
+ *     $Revision: 15137 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -103,11 +103,11 @@ namespace Gecode { namespace Int { namespace NoOverlap {
   forceinline ExecStatus
   ManBox<Dim,n>::nooverlap(Space& home, ManBox<Dim,n>& box) {
     for (int i=0; i<n; i++)
-      if ((d[i].sec() <= box.d[i].lsc()) || 
+      if ((d[i].sec() <= box.d[i].lsc()) ||
           (box.d[i].sec() <= d[i].lsc())) {
         // Does not overlap for dimension i
         for (int j=i+1; j<n; j++)
-          if ((d[j].sec() <= box.d[j].lsc()) || 
+          if ((d[j].sec() <= box.d[j].lsc()) ||
               (box.d[j].sec() <= d[j].lsc()))
             return ES_OK;
         // Does not overlap for only dimension i, hence propagate
@@ -138,6 +138,12 @@ namespace Gecode { namespace Int { namespace NoOverlap {
     for (int i=0; i<n; i++)
       d[i].cancel(home,p);
   }
+  template<class Dim, int n>
+  forceinline void
+  ManBox<Dim,n>::reschedule(Space& home, Propagator& p) {
+    for (int i=0; i<n; i++)
+      d[i].reschedule(home,p);
+  }
 
 
   /*
@@ -191,6 +197,12 @@ namespace Gecode { namespace Int { namespace NoOverlap {
     ManBox<Dim,n>::cancel(home,p);
     o.cancel(home, p, PC_BOOL_VAL);
   }
+  template<class Dim, int n>
+  forceinline void
+  OptBox<Dim,n>::reschedule(Space& home, Propagator& p) {
+    ManBox<Dim,n>::reschedule(home,p);
+    o.reschedule(home, p, PC_BOOL_VAL);
+  }
 
 }}}
 
