@@ -11,8 +11,8 @@
  *     Christian Schulte, 2011
  *
  *  Last modified:
- *     $Date: 2011-06-30 16:20:54 +0200 (Thu, 30 Jun 2011) $ by $Author: schulte $
- *     $Revision: 12138 $
+ *     $Date: 2016-08-17 14:21:02 +0200 (Wed, 17 Aug 2016) $ by $Author: schulte $
+ *     $Revision: 15151 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -47,7 +47,7 @@ namespace Gecode { namespace Int { namespace Precede {
   assigned(View x, int v) {
     return x.assigned() && (x.val() == v);
   }
-    
+
   template<class View>
   forceinline
   Single<View>::Index::Index(Space& home, Propagator& p,
@@ -59,9 +59,9 @@ namespace Gecode { namespace Int { namespace Precede {
   Single<View>::Index::Index(Space& home, bool share, Index& a)
     : Advisor(home,share,a), i(a.i) {}
 
-  
+
   template<class View>
-  forceinline ExecStatus 
+  forceinline ExecStatus
   Single<View>::updateAlpha(Space& home) {
     int n = x.size();
     while ((alpha < n) && !x[alpha].in(s))
@@ -82,12 +82,12 @@ namespace Gecode { namespace Int { namespace Precede {
       GECODE_ME_CHECK(x[alpha].eq(home, s));
     return ES_OK;
   }
-  
+
   template<class View>
   forceinline
-  Single<View>::Single(Home home, ViewArray<View>& x0, 
+  Single<View>::Single(Home home, ViewArray<View>& x0,
                        int s0, int t0, int b, int g)
-    : NaryPropagator<View, PC_INT_NONE>(home,x0), 
+    : NaryPropagator<View, PC_INT_NONE>(home,x0),
       c(home), s(s0), t(t0), alpha(0), beta(b), gamma(g) {
     for (int i=x.size(); i--; )
       if (!x[i].assigned())
@@ -124,7 +124,7 @@ namespace Gecode { namespace Int { namespace Precede {
     (void) new (home) Single<View>(home, x, s, t, beta, gamma);
     return ES_OK;
   }
-    
+
 
 
   template<class View>
@@ -171,11 +171,17 @@ namespace Gecode { namespace Int { namespace Precede {
   }
 
   template<class View>
-  PropCost 
+  PropCost
   Single<View>::cost(const Space&, const ModEventDelta&) const {
     return PropCost::linear(PropCost::LO, x.size());
   }
 
+  template<class View>
+  void
+  Single<View>::reschedule(Space& home) {
+    View::schedule(home, *this, ME_INT_BND);
+  }
+
   template<class View>
   ExecStatus
   Single<View>::advise(Space& home, Advisor& a0, const Delta& d) {
@@ -203,7 +209,7 @@ namespace Gecode { namespace Int { namespace Precede {
     }
     return ES_FIX;
   }
-  
+
   template<class View>
   ExecStatus
   Single<View>::propagate(Space& home, const ModEventDelta&) {
@@ -223,10 +229,10 @@ namespace Gecode { namespace Int { namespace Precede {
     } else if ((beta < n) && !x[beta].in(s)) {
       GECODE_ES_CHECK(updateBeta(home));
     }
-    
+
     return (c.empty()) ? home.ES_SUBSUMED(*this) : ES_FIX;
   }
-  
+
 }}}
 
 // STATISTICS: int-prop
