@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2011-12-12 16:21:39 +0100 (Mon, 12 Dec 2011) $ by $Author: schulte $
- *     $Revision: 12489 $
+ *     $Date: 2016-11-08 17:23:24 +0100 (Tue, 08 Nov 2016) $ by $Author: schulte $
+ *     $Revision: 15253 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -42,12 +42,11 @@
 
 namespace Gecode {
 
-  using namespace Int;
-
   void
-  rel(Home home, IntVar x0, IntRelType irt, int n, IntConLevel) {
+  rel(Home home, IntVar x0, IntRelType irt, int n, IntPropLevel) {
+    using namespace Int;
     Limits::check(n,"Int::rel");
-    if (home.failed()) return;
+    GECODE_POST;
     IntView x(x0);
     switch (irt) {
     case IRT_EQ: GECODE_ME_FAIL(x.eq(home,n)); break;
@@ -61,9 +60,10 @@ namespace Gecode {
   }
 
   void
-  rel(Home home, const IntVarArgs& x, IntRelType irt, int n, IntConLevel) {
+  rel(Home home, const IntVarArgs& x, IntRelType irt, int n, IntPropLevel) {
+    using namespace Int;
     Limits::check(n,"Int::rel");
-    if (home.failed()) return;
+    GECODE_POST;
     switch (irt) {
     case IRT_EQ:
       for (int i=x.size(); i--; ) {
@@ -101,26 +101,27 @@ namespace Gecode {
   }
 
   void
-  rel(Home home, IntVar x0, IntRelType irt, IntVar x1, IntConLevel icl) {
-    if (home.failed()) return;
+  rel(Home home, IntVar x0, IntRelType irt, IntVar x1, IntPropLevel ipl) {
+    using namespace Int;
+    GECODE_POST;
     switch (irt) {
     case IRT_EQ:
-      if ((icl == ICL_DOM) || (icl == ICL_DEF)) {
+      if ((vbd(ipl) == IPL_DOM) || (vbd(ipl) == IPL_DEF)) {
         GECODE_ES_FAIL((Rel::EqDom<IntView,IntView>::post(home,x0,x1)));
       } else {
         GECODE_ES_FAIL((Rel::EqBnd<IntView,IntView>::post(home,x0,x1)));
       }
       break;
     case IRT_NQ:
-      GECODE_ES_FAIL(Rel::Nq<IntView>::post(home,x0,x1)); break;
+      GECODE_ES_FAIL((Rel::Nq<IntView,IntView>::post(home,x0,x1))); break;
     case IRT_GQ:
       std::swap(x0,x1); // Fall through
     case IRT_LQ:
-      GECODE_ES_FAIL(Rel::Lq<IntView>::post(home,x0,x1)); break;
+      GECODE_ES_FAIL((Rel::Lq<IntView,IntView>::post(home,x0,x1))); break;
     case IRT_GR:
       std::swap(x0,x1); // Fall through
     case IRT_LE:
-      GECODE_ES_FAIL(Rel::Le<IntView>::post(home,x0,x1)); break;
+      GECODE_ES_FAIL((Rel::Le<IntView,IntView>::post(home,x0,x1))); break;
     default:
       throw UnknownRelation("Int::rel");
     }
@@ -128,8 +129,9 @@ namespace Gecode {
 
   void
   rel(Home home, const IntVarArgs& x, IntRelType irt, IntVar y,
-      IntConLevel icl) {
-    if (home.failed()) return;
+      IntPropLevel ipl) {
+    using namespace Int;
+    GECODE_POST;
     switch (irt) {
     case IRT_EQ:
       {
@@ -137,7 +139,7 @@ namespace Gecode {
         xv[x.size()]=y;
         for (int i=x.size(); i--; )
           xv[i]=x[i];
-        if ((icl == ICL_DOM) || (icl == ICL_DEF)) {
+        if ((vbd(ipl) == IPL_DOM) || (vbd(ipl) == IPL_DEF)) {
           GECODE_ES_FAIL(Rel::NaryEqDom<IntView>::post(home,xv));
         } else {
           GECODE_ES_FAIL(Rel::NaryEqBnd<IntView>::post(home,xv));
@@ -146,27 +148,27 @@ namespace Gecode {
       break;
     case IRT_NQ:
       for (int i=x.size(); i--; ) {
-        GECODE_ES_FAIL(Rel::Nq<IntView>::post(home,x[i],y));
+        GECODE_ES_FAIL((Rel::Nq<IntView,IntView>::post(home,x[i],y)));
       }
       break;
     case IRT_GQ:
       for (int i=x.size(); i--; ) {
-        GECODE_ES_FAIL(Rel::Lq<IntView>::post(home,y,x[i]));
+        GECODE_ES_FAIL((Rel::Lq<IntView,IntView>::post(home,y,x[i])));
       }
       break;
     case IRT_LQ:
       for (int i=x.size(); i--; ) {
-        GECODE_ES_FAIL(Rel::Lq<IntView>::post(home,x[i],y));
+        GECODE_ES_FAIL((Rel::Lq<IntView,IntView>::post(home,x[i],y)));
       }
       break;
     case IRT_GR:
       for (int i=x.size(); i--; ) {
-        GECODE_ES_FAIL(Rel::Le<IntView>::post(home,y,x[i]));
+        GECODE_ES_FAIL((Rel::Le<IntView,IntView>::post(home,y,x[i])));
       }
       break;
     case IRT_LE:
       for (int i=x.size(); i--; ) {
-        GECODE_ES_FAIL(Rel::Le<IntView>::post(home,x[i],y));
+        GECODE_ES_FAIL((Rel::Le<IntView,IntView>::post(home,x[i],y)));
       }
       break;
     default:
@@ -177,11 +179,12 @@ namespace Gecode {
 
   void
   rel(Home home, IntVar x0, IntRelType irt, IntVar x1, Reify r,
-      IntConLevel icl) {
-    if (home.failed()) return;
+      IntPropLevel ipl) {
+    using namespace Int;
+    GECODE_POST;
     switch (irt) {
     case IRT_EQ:
-      if ((icl == ICL_DOM) || (icl == ICL_DEF)) {
+      if ((vbd(ipl) == IPL_DOM) || (vbd(ipl) == IPL_DEF)) {
         switch (r.mode()) {
         case RM_EQV:
           GECODE_ES_FAIL((Rel::ReEqDom<IntView,BoolView,RM_EQV>
@@ -218,7 +221,7 @@ namespace Gecode {
     case IRT_NQ:
       {
         NegBoolView n(r.var());
-        if (icl == ICL_BND) {
+        if (vbd(ipl) == IPL_BND) {
           switch (r.mode()) {
           case RM_EQV:
             GECODE_ES_FAIL((Rel::ReEqBnd<IntView,NegBoolView,RM_EQV>
@@ -301,12 +304,13 @@ namespace Gecode {
 
   void
   rel(Home home, IntVar x, IntRelType irt, int n, Reify r,
-      IntConLevel icl) {
+      IntPropLevel ipl) {
+    using namespace Int;
     Limits::check(n,"Int::rel");
-    if (home.failed()) return;
+    GECODE_POST;
     switch (irt) {
     case IRT_EQ:
-      if ((icl == ICL_DOM) || (icl == ICL_DEF)) {
+      if ((vbd(ipl) == IPL_DOM) || (vbd(ipl) == IPL_DEF)) {
         switch (r.mode()) {
         case RM_EQV:
           GECODE_ES_FAIL((Rel::ReEqDomInt<IntView,BoolView,RM_EQV>
@@ -343,7 +347,7 @@ namespace Gecode {
     case IRT_NQ:
       {
         NegBoolView nb(r.var());
-        if (icl == ICL_BND) {
+        if (vbd(ipl) == IPL_BND) {
           switch (r.mode()) {
           case RM_EQV:
             GECODE_ES_FAIL((Rel::ReEqBndInt<IntView,NegBoolView,RM_EQV>
@@ -426,14 +430,16 @@ namespace Gecode {
 
   void
   rel(Home home, const IntVarArgs& x, IntRelType irt,
-      IntConLevel icl) {
-    if (home.failed() || ((irt != IRT_NQ) && (x.size() < 2))) 
+      IntPropLevel ipl) {
+    using namespace Int;
+    GECODE_POST;
+    if ((irt != IRT_NQ) && (x.size() < 2))
       return;
     switch (irt) {
     case IRT_EQ:
       {
         ViewArray<IntView> xv(home,x);
-        if ((icl == ICL_DOM) || (icl == ICL_DEF)) {
+        if ((vbd(ipl) == IPL_DOM) || (vbd(ipl) == IPL_DEF)) {
           GECODE_ES_FAIL(Rel::NaryEqDom<IntView>::post(home,xv));
         } else {
           GECODE_ES_FAIL(Rel::NaryEqBnd<IntView>::post(home,xv));
@@ -466,7 +472,7 @@ namespace Gecode {
         GECODE_ES_FAIL((Rel::NaryLqLe<IntView,1>::post(home,y)));
       }
       for (int i=x.size()-1; i--; )
-        GECODE_ES_FAIL(Rel::Le<IntView>::post(home,x[i+1],x[i]));
+        GECODE_ES_FAIL((Rel::Le<IntView,IntView>::post(home,x[i+1],x[i])));
       break;
     case IRT_GQ:
       {
@@ -483,38 +489,43 @@ namespace Gecode {
 
   void
   rel(Home home, const IntVarArgs& x, IntRelType irt, const IntVarArgs& y,
-      IntConLevel icl) {
-    if (home.failed()) return;
+      IntPropLevel ipl) {
+    using namespace Int;
+    GECODE_POST;
 
     switch (irt) {
     case IRT_GR:
       {
         ViewArray<IntView> xv(home,x), yv(home,y);
-        GECODE_ES_FAIL(Rel::LexLqLe<IntView>::post(home,yv,xv,true));
+        GECODE_ES_FAIL((Rel::LexLqLe<IntView,IntView>
+                        ::post(home,yv,xv,true)));
       }
       break;
     case IRT_LE:
       {
         ViewArray<IntView> xv(home,x), yv(home,y);
-        GECODE_ES_FAIL(Rel::LexLqLe<IntView>::post(home,xv,yv,true));
+        GECODE_ES_FAIL((Rel::LexLqLe<IntView,IntView>
+                        ::post(home,xv,yv,true)));
       }
       break;
     case IRT_GQ:
       {
         ViewArray<IntView> xv(home,x), yv(home,y);
-        GECODE_ES_FAIL(Rel::LexLqLe<IntView>::post(home,yv,xv,false));
+        GECODE_ES_FAIL((Rel::LexLqLe<IntView,IntView>
+                        ::post(home,yv,xv,false)));
       }
       break;
     case IRT_LQ:
       {
         ViewArray<IntView> xv(home,x), yv(home,y);
-        GECODE_ES_FAIL(Rel::LexLqLe<IntView>::post(home,xv,yv,false));
+        GECODE_ES_FAIL((Rel::LexLqLe<IntView,IntView>
+                        ::post(home,xv,yv,false)));
       }
       break;
     case IRT_EQ:
       if (x.size() != y.size()) {
         home.fail();
-      } else if ((icl == ICL_DOM) || (icl == ICL_DEF))
+      } else if ((vbd(ipl) == IPL_DOM) || (vbd(ipl) == IPL_DEF))
         for (int i=x.size(); i--; ) {
           GECODE_ES_FAIL((Rel::EqDom<IntView,IntView>
                           ::post(home,x[i],y[i])));
@@ -528,7 +539,8 @@ namespace Gecode {
     case IRT_NQ:
       {
         ViewArray<IntView> xv(home,x), yv(home,y);
-        GECODE_ES_FAIL(Rel::LexNq<IntView>::post(home,xv,yv));
+        GECODE_ES_FAIL((Rel::LexNq<IntView,IntView>
+                        ::post(home,xv,yv)));
       }
       break;
     default:
@@ -536,6 +548,87 @@ namespace Gecode {
     }
   }
 
+  namespace {
+
+    /// Return view array
+    ViewArray<Int::ConstIntView>
+    viewarray(Space& home, const IntArgs& x) {
+      ViewArray<Int::ConstIntView> xv(home, x.size());
+      for (int i = x.size(); i--; ) {
+        Int::Limits::check(x[i],"Int::rel");
+        xv[i] = Int::ConstIntView(x[i]);
+      }
+      return xv;
+    }
+
+  }
+
+  void
+  rel(Home home, const IntVarArgs& x, IntRelType irt, const IntArgs& y,
+      IntPropLevel) {
+    using namespace Int;
+    GECODE_POST;
+
+    switch (irt) {
+    case IRT_GR:
+      {
+        ViewArray<IntView> xv(home,x);
+        ViewArray<ConstIntView> yv(viewarray(home,y));
+        GECODE_ES_FAIL((Rel::LexLqLe<ConstIntView,IntView>
+                        ::post(home,yv,xv,true)));
+      }
+      break;
+    case IRT_LE:
+      {
+        ViewArray<IntView> xv(home,x);
+        ViewArray<ConstIntView> yv(viewarray(home,y));
+        GECODE_ES_FAIL((Rel::LexLqLe<IntView,ConstIntView>
+                        ::post(home,xv,yv,true)));
+      }
+      break;
+    case IRT_GQ:
+      {
+        ViewArray<IntView> xv(home,x);
+        ViewArray<ConstIntView> yv(viewarray(home,y));
+        GECODE_ES_FAIL((Rel::LexLqLe<ConstIntView,IntView>
+                        ::post(home,yv,xv,false)));
+      }
+      break;
+    case IRT_LQ:
+      {
+        ViewArray<IntView> xv(home,x);
+        ViewArray<ConstIntView> yv(viewarray(home,y));
+        GECODE_ES_FAIL((Rel::LexLqLe<IntView,ConstIntView>
+                        ::post(home,xv,yv,false)));
+      }
+      break;
+    case IRT_EQ:
+      if (x.size() != y.size()) {
+        home.fail();
+      } else {
+        for (int i=x.size(); i--; )
+          GECODE_ME_FAIL(IntView(x[i]).eq(home,y[i]));
+      }
+      break;
+    case IRT_NQ:
+      {
+        ViewArray<IntView> xv(home,x); 
+        ViewArray<ConstIntView> yv(viewarray(home,y));
+        GECODE_ES_FAIL((Rel::LexNq<IntView,ConstIntView>
+                        ::post(home,xv,yv)));
+      }
+      break;
+    default:
+      throw UnknownRelation("Int::rel");
+    }
+  }
+
+  void
+  rel(Home home, const IntArgs& x, IntRelType irt, const IntVarArgs& y,
+      IntPropLevel ipl) {
+    rel(home,y,irt,x,ipl);
+  }
+
 }
 
 // STATISTICS: int-post
