@@ -11,8 +11,8 @@
  *     Christian Schulte, 2009
  *
  *  Last modified:
- *     $Date: 2012-09-07 17:31:22 +0200 (Fri, 07 Sep 2012) $
- *     $Revision: 13068 $
+ *     $Date: 2016-06-29 17:28:17 +0200 (Wed, 29 Jun 2016) $
+ *     $Revision: 15137 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -43,14 +43,15 @@ namespace Gecode { namespace Int { namespace Sequence {
 
   template<class View, class Val>
   forceinline
-  Sequence<View,Val>::Sequence(Home home, ViewArray<View>& x0, Val s0, 
-                               int q0, int l0, int u0)    
-    : Propagator(home), x(x0), s(s0), q(q0), l(l0), u(u0), 
-      vvsamax(home,x,s0,q0), vvsamin(home,x,s0,q0), ac(home) {
+  Sequence<View,Val>::Sequence(Home home, ViewArray<View>& x0, Val s0,
+                               int q0, int l0, int u0)
+    : Propagator(home), x(x0), s(s0), q(q0), l(l0), u(u0),
+      vvsamax(home,x,s0,q0), vvsamin(home,x,s0,q0), ac(home),
+      tofail(false) {
     home.notice(*this,AP_DISPOSE);
     for (int i=x.size(); i--; ) {
       if (undecided(x[i],s)) {
-        x[i].subscribe(home,*new (home) SupportAdvisor<View>(home,*this,ac,i));   
+        x[i].subscribe(home,*new (home) SupportAdvisor<View>(home,*this,ac,i));
       } else {
         x[i].schedule(home,*this,x[i].assigned() ? ME_INT_VAL : ME_INT_BND);
       }
@@ -87,7 +88,7 @@ namespace Gecode { namespace Int { namespace Sequence {
   forceinline
   Sequence<View,Val>::Sequence(Space& home, bool share, Sequence& p)
     : Propagator(home,share,p), q(p.q), l(p.l), u(p.u),
-      vvsamax(), vvsamin() {
+      vvsamax(), vvsamin(), tofail(p.tofail) {
     UpdateVal<Val>::update(s,home,share,p.s);
     x.update(home,share,p.x);
     ac.update(home,share,p.ac);
@@ -115,6 +116,11 @@ namespace Gecode { namespace Int { namespace Sequence {
       }
     }
 
+    if ((status == ES_FAILED) && disabled()) {
+      tofail = true;
+      return ES_FIX;
+    }
+
     return status;
   }
 
@@ -177,8 +183,21 @@ namespace Gecode { namespace Int { namespace Sequence {
   }
 
   template<class View, class Val>
-  ExecStatus 
+  void
+  Sequence<View,Val>::reschedule(Space& home) {
+    for (int i=x.size(); i--; )
+      if (!undecided(x[i],s))
+        x[i].schedule(home,*this,x[i].assigned() ? ME_INT_VAL : ME_INT_BND);
+    if (tofail)
+      View::schedule(home,*this,ME_INT_BND);
+  }
+
+  template<class View, class Val>
+  ExecStatus
   Sequence<View,Val>::propagate(Space& home, const ModEventDelta&) {
+    if (tofail)
+      return ES_FAILED;
+
     GECODE_ES_CHECK(vvsamax.propagate(home,x,s,q,l,u));
     GECODE_ES_CHECK(vvsamin.propagate(home,x,s,q,l,u));
 
