@@ -7,8 +7,8 @@
  *     Christian Schulte, 2009
  *
  *  Last modified:
- *     $Date: 2011-05-25 16:56:41 +0200 (Wed, 25 May 2011) $ by $Author: schulte $
- *     $Revision: 12022 $
+ *     $Date: 2016-06-29 17:28:17 +0200 (Wed, 29 Jun 2016) $ by $Author: schulte $
+ *     $Revision: 15137 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -64,19 +64,19 @@ namespace Gecode { namespace Int {
   }
 
   template<class ManTask>
-  forceinline ModEvent 
+  forceinline ModEvent
   ManToOptTask<ManTask>::mandatory(Space& home) {
     return _m.one(home);
   }
   template<class ManTask>
-  forceinline ModEvent 
+  forceinline ModEvent
   ManToOptTask<ManTask>::excluded(Space& home) {
     return _m.zero(home);
   }
 
   template<class ManTask>
   forceinline void
-  ManToOptTask<ManTask>::update(Space& home, bool share, 
+  ManToOptTask<ManTask>::update(Space& home, bool share,
                                 ManToOptTask<ManTask>& t) {
     ManTask::update(home, share, t);
     _m.update(home,share,t._m);
@@ -86,15 +86,22 @@ namespace Gecode { namespace Int {
   forceinline void
   ManToOptTask<ManTask>::subscribe(Space& home, Propagator& p, PropCond pc) {
     ManTask::subscribe(home, p, pc);
-    _m.subscribe(home, p, Int::PC_BOOL_VAL);
+    _m.subscribe(home, p, PC_BOOL_VAL);
   }
   template<class ManTask>
   forceinline void
   ManToOptTask<ManTask>::cancel(Space& home, Propagator& p, PropCond pc) {
-    _m.cancel(home, p, Int::PC_BOOL_VAL);
+    _m.cancel(home, p, PC_BOOL_VAL);
     ManTask::cancel(home, p, pc);
   }
 
+  template<class ManTask>
+  forceinline void
+  ManToOptTask<ManTask>::reschedule(Space& home, Propagator& p, PropCond pc) {
+    _m.reschedule(home, p, PC_BOOL_VAL);
+    ManTask::reschedule(home, p, pc);
+  }
+
 }}
 
 // STATISTICS: int-var
