@@ -7,8 +7,8 @@
  *     Christian Schulte, 2009
  *
  *  Last modified:
- *     $Date: 2011-05-25 16:56:41 +0200 (Wed, 25 May 2011) $ by $Author: schulte $
- *     $Revision: 12022 $
+ *     $Date: 2016-04-19 17:19:45 +0200 (Tue, 19 Apr 2016) $ by $Author: schulte $
+ *     $Revision: 14967 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -45,26 +45,27 @@ namespace Gecode { namespace Int { namespace Unary {
 
   forceinline void
   OmegaNode::init(const OmegaNode&, const OmegaNode&) {
-    p = 0; ect = -Int::Limits::infinity;
+    p = 0; ect = -Limits::infinity;
   }
 
   forceinline void
   OmegaNode::update(const OmegaNode& l, const OmegaNode& r) {
-    p = l.p + r.p; 
+    p = l.p + r.p;
     ect = std::max(plus(l.ect,r.p), r.ect);
   }
 
   template<class TaskView>
+  forceinline
   OmegaTree<TaskView>::OmegaTree(Region& r, const TaskViewArray<TaskView>& t)
     : TaskTree<TaskView,OmegaNode>(r,t) {
     for (int i=tasks.size(); i--; ) {
-      leaf(i).p = 0; leaf(i).ect = -Int::Limits::infinity;
+      leaf(i).p = 0; leaf(i).ect = -Limits::infinity;
     }
     init();
   }
 
   template<class TaskView>
-  forceinline void 
+  forceinline void
   OmegaTree<TaskView>::insert(int i) {
     leaf(i).p = tasks[i].pmin();
     leaf(i).ect = tasks[i].est()+tasks[i].pmin();
@@ -74,22 +75,22 @@ namespace Gecode { namespace Int { namespace Unary {
   template<class TaskView>
   forceinline void
   OmegaTree<TaskView>::remove(int i) {
-    leaf(i).p = 0; leaf(i).ect = -Int::Limits::infinity;
+    leaf(i).p = 0; leaf(i).ect = -Limits::infinity;
     update(i);
   }
 
   template<class TaskView>
-  forceinline int 
+  forceinline int
   OmegaTree<TaskView>::ect(void) const {
     return root().ect;
   }
-  
+
   template<class TaskView>
-  forceinline int 
+  forceinline int
   OmegaTree<TaskView>::ect(int i) const {
     // Check whether task i is in?
     OmegaTree<TaskView>& o = const_cast<OmegaTree<TaskView>&>(*this);
-    if (o.leaf(i).ect != -Int::Limits::infinity) {
+    if (o.leaf(i).ect != -Limits::infinity) {
       o.remove(i);
       int ect = o.root().ect;
       o.insert(i);
@@ -98,11 +99,11 @@ namespace Gecode { namespace Int { namespace Unary {
       return root().ect;
     }
   }
-  
+
 
 
   /*
-   * Ome lambda tree
+   * Omega lambda tree
    */
 
   forceinline void
@@ -119,7 +120,7 @@ namespace Gecode { namespace Int { namespace Unary {
       lp = l.lp + r.p;
     } else {
       resLp = r.resLp;
-      lp = l.p + r.lp;      
+      lp = l.p + r.lp;
     }
     if ((r.lect >= plus(l.ect,r.lp)) && (r.lect >= plus(l.lect,r.p))) {
       lect = r.lect; resEct = r.resEct;
@@ -127,7 +128,7 @@ namespace Gecode { namespace Int { namespace Unary {
       assert(plus(l.ect,r.lp) > r.lect);
       lect = plus(l.ect,r.lp); resEct = r.resLp;
     } else {
-      assert((plus(l.lect,r.p) > r.lect) && 
+      assert((plus(l.lect,r.p) > r.lect) &&
              (plus(l.lect,r.p) > plus(l.ect,r.lp)));
       lect = plus(l.lect,r.p); resEct = l.resEct;
     }
@@ -135,7 +136,8 @@ namespace Gecode { namespace Int { namespace Unary {
 
 
   template<class TaskView>
-  OmegaLambdaTree<TaskView>::OmegaLambdaTree(Region& r, 
+  forceinline
+  OmegaLambdaTree<TaskView>::OmegaLambdaTree(Region& r,
                                              const TaskViewArray<TaskView>& t,
                                              bool inc)
     : TaskTree<TaskView,OmegaLambdaNode>(r,t) {
@@ -152,7 +154,7 @@ namespace Gecode { namespace Int { namespace Unary {
       // Enter no tasks into tree (omega = empty, lambda = empty)
       for (int i=tasks.size(); i--; ) {
         leaf(i).p = leaf(i).lp = 0;
-        leaf(i).ect = leaf(i).lect = -Int::Limits::infinity;
+        leaf(i).ect = leaf(i).lect = -Limits::infinity;
         leaf(i).resEct = OmegaLambdaNode::undef;
         leaf(i).resLp = OmegaLambdaNode::undef;
       }
@@ -161,12 +163,12 @@ namespace Gecode { namespace Int { namespace Unary {
   }
 
   template<class TaskView>
-  forceinline void 
+  forceinline void
   OmegaLambdaTree<TaskView>::shift(int i) {
     // That means that i is in omega
-    assert(leaf(i).ect > -Int::Limits::infinity);
+    assert(leaf(i).ect > -Limits::infinity);
     leaf(i).p = 0;
-    leaf(i).ect = -Int::Limits::infinity;
+    leaf(i).ect = -Limits::infinity;
     leaf(i).resEct = i;
     leaf(i).resLp = i;
     update(i);
@@ -175,7 +177,7 @@ namespace Gecode { namespace Int { namespace Unary {
   template<class TaskView>
   forceinline void
   OmegaLambdaTree<TaskView>::oinsert(int i) {
-    leaf(i).p = tasks[i].pmin(); 
+    leaf(i).p = tasks[i].pmin();
     leaf(i).ect = tasks[i].est()+tasks[i].pmin();
     update(i);
   }
@@ -183,7 +185,7 @@ namespace Gecode { namespace Int { namespace Unary {
   template<class TaskView>
   forceinline void
   OmegaLambdaTree<TaskView>::linsert(int i) {
-    leaf(i).lp = tasks[i].pmin(); 
+    leaf(i).lp = tasks[i].pmin();
     leaf(i).lect = tasks[i].est()+tasks[i].pmin();
     leaf(i).resEct = i;
     leaf(i).resLp = i;
@@ -193,8 +195,8 @@ namespace Gecode { namespace Int { namespace Unary {
   template<class TaskView>
   forceinline void
   OmegaLambdaTree<TaskView>::lremove(int i) {
-    leaf(i).lp = 0; 
-    leaf(i).lect = -Int::Limits::infinity;
+    leaf(i).lp = 0;
+    leaf(i).lect = -Limits::infinity;
     leaf(i).resEct = OmegaLambdaNode::undef;
     leaf(i).resLp = OmegaLambdaNode::undef;
     update(i);
@@ -205,25 +207,25 @@ namespace Gecode { namespace Int { namespace Unary {
   OmegaLambdaTree<TaskView>::lempty(void) const {
     return root().resEct < 0;
   }
-  
+
   template<class TaskView>
-  forceinline int 
+  forceinline int
   OmegaLambdaTree<TaskView>::responsible(void) const {
     return root().resEct;
   }
-  
+
   template<class TaskView>
-  forceinline int 
+  forceinline int
   OmegaLambdaTree<TaskView>::ect(void) const {
     return root().ect;
   }
-  
+
   template<class TaskView>
-  forceinline int 
+  forceinline int
   OmegaLambdaTree<TaskView>::lect(void) const {
     return root().lect;
   }
-  
+
 }}}
 
 // STATISTICS: int-prop
