@@ -7,8 +7,8 @@
  *     Christian Schulte, 2012
  *
  *  Last modified:
- *     $Date: 2013-05-22 21:29:33 +0200 (Wed, 22 May 2013) $ by $Author: tack $
- *     $Revision: 13656 $
+ *     $Date: 2017-03-08 11:58:56 +0100 (Wed, 08 Mar 2017) $ by $Author: schulte $
+ *     $Revision: 15562 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -35,38 +35,49 @@
  *
  */
 
+#include <functional>
+
 namespace Gecode {
 
   /**
    * \brief Tie-break limit function
-   * 
+   *
    * Here the value \a w is the worst and \b is the best merit value
    * found. The function must return the merit value that is considered
    * the limit for breaking ties.
    *
    * \ingroup TaskModelBranch
    */
-  typedef double (*BranchTbl)(const Space& home, double w, double b);
+  typedef std::function<double(const Space& home, double w, double b)>
+    BranchTbl;
 
   /**
    * \brief Variable branching information
    * \ingroup TaskModelBranch
    */
+  template<class Var>
   class VarBranch {
+  public:
+    /// Corresponding merit function
+    typedef typename BranchTraits<Var>::Merit MeritFunction;
   protected:
     /// Tie-breaking limit function
     BranchTbl _tbl;
     /// Random number generator
     Rnd _rnd;
-    /// Decay information for AFC and activity
+    /// Decay information for AFC and action
     double _decay;
     /// AFC information
     AFC _afc;
-    /// Activity information
-    Activity _act;
-    /// Merit function (generic function pointer)
-    VoidFunction _mf;
+    /// Action information
+    Action _act;
+    /// CHB information
+    CHB _chb;
+    /// Merit function
+    MeritFunction _mf;
   public:
+    /// Initialize
+    VarBranch(void);
     /// Initialize with tie-break limit function \a t
     VarBranch(BranchTbl t);
     /// Initialize with random number generator \a r
@@ -75,10 +86,12 @@ namespace Gecode {
     VarBranch(double d, BranchTbl t);
     /// Initialize with AFC \a a and tie-break limit function \a t
     VarBranch(AFC a, BranchTbl t);
-    /// Initialize with activity \a a and tie-break limit function \a t
-    VarBranch(Activity a, BranchTbl t);
+    /// Initialize with action \a a and tie-break limit function \a t
+    VarBranch(Action a, BranchTbl t);
+    /// Initialize with CHB \a c and tie-break limit function \a t
+    VarBranch(CHB c, BranchTbl t);
     /// Initialize with merit function \a f and tie-break limit function \a t
-    VarBranch(void (*f)(void), BranchTbl t);
+    VarBranch(MeritFunction f, BranchTbl t);
     /// Return tie-break limit function
     BranchTbl tbl(void) const;
     /// Return random number generator
@@ -89,85 +102,128 @@ namespace Gecode {
     AFC afc(void) const;
     /// Set AFC to \a a
     void afc(AFC a);
-    /// Return activity
-    Activity activity(void) const;
-    /// Set activity to \a a
-    void activity(Activity a);
+    /// Return action
+    Action action(void) const;
+    /// Set action to \a a
+    void action(Action a);
+    /// Return CHB
+    CHB chb(void) const;
+    /// Set CHB to \a chb
+    void chb(CHB chb);
     /// Return merit function
-    VoidFunction merit(void) const;
+    MeritFunction merit(void) const;
   };
 
   // Variable branching
-  forceinline 
-  VarBranch::VarBranch(BranchTbl t)
+  template<class Var>
+  inline
+  VarBranch<Var>::VarBranch(void)
+    : _tbl(nullptr), _decay(1.0) {}
+
+  template<class Var>
+  inline
+  VarBranch<Var>::VarBranch(BranchTbl t)
     : _tbl(t), _decay(1.0) {}
 
-  forceinline 
-  VarBranch::VarBranch(double d, BranchTbl t)
+  template<class Var>
+  inline
+  VarBranch<Var>::VarBranch(double d, BranchTbl t)
     : _tbl(t), _decay(d) {}
 
-  forceinline 
-  VarBranch::VarBranch(AFC a, BranchTbl t)
+  template<class Var>
+  inline
+  VarBranch<Var>::VarBranch(AFC a, BranchTbl t)
     : _tbl(t), _decay(1.0), _afc(a) {
-    if (!_afc.initialized())
-      throw UninitializedAFC("VarBranch::VarBranch");
+    if (!_afc)
+      throw UninitializedAFC("VarBranch<Var>::VarBranch");
   }
 
-  forceinline 
-  VarBranch::VarBranch(Activity a, BranchTbl t)
+  template<class Var>
+  inline
+  VarBranch<Var>::VarBranch(Action a, BranchTbl t)
     : _tbl(t), _decay(1.0), _act(a) {
-    if (!_act.initialized())
-      throw UninitializedActivity("VarBranch::VarBranch");
+    if (!_act)
+      throw UninitializedAction("VarBranch<Var>::VarBranch");
   }
 
-  forceinline 
-  VarBranch::VarBranch(Rnd r)
-    : _tbl(NULL), _rnd(r), _decay(1.0) {
-    if (!_rnd.initialized())
-      throw UninitializedRnd("VarBranch::VarBranch");
+  template<class Var>
+  inline
+  VarBranch<Var>::VarBranch(CHB c, BranchTbl t)
+    : _tbl(t), _decay(1.0), _chb(c) {
+    if (!_chb)
+      throw UninitializedCHB("VarBranch<Var>::VarBranch");
   }
 
-  forceinline 
-  VarBranch::VarBranch(VoidFunction f, BranchTbl t)
+  template<class Var>
+  inline
+  VarBranch<Var>::VarBranch(Rnd r)
+    : _tbl(nullptr), _rnd(r), _decay(1.0) {
+    if (!_rnd)
+      throw UninitializedRnd("VarBranch<Var>::VarBranch");
+  }
+
+  template<class Var>
+  inline
+  VarBranch<Var>::VarBranch(MeritFunction f, BranchTbl t)
     : _tbl(t), _decay(1.0), _mf(f) {}
 
-  forceinline BranchTbl
-  VarBranch::tbl(void) const {
+  template<class Var>
+  inline BranchTbl
+  VarBranch<Var>::tbl(void) const {
     return _tbl;
   }
 
+  template<class Var>
   inline Rnd
-  VarBranch::rnd(void) const {
+  VarBranch<Var>::rnd(void) const {
     return _rnd;
   }
 
+  template<class Var>
   inline double
-  VarBranch::decay(void) const {
+  VarBranch<Var>::decay(void) const {
     return _decay;
   }
 
+  template<class Var>
   inline AFC
-  VarBranch::afc(void) const {
+  VarBranch<Var>::afc(void) const {
     return _afc;
   }
 
+  template<class Var>
   inline void
-  VarBranch::afc(AFC a) {
+  VarBranch<Var>::afc(AFC a) {
     _afc=a;
   }
 
-  inline Activity
-  VarBranch::activity(void) const {
+  template<class Var>
+  inline Action
+  VarBranch<Var>::action(void) const {
     return _act;
   }
 
+  template<class Var>
   inline void
-  VarBranch::activity(Activity a) {
+  VarBranch<Var>::action(Action a) {
     _act=a;
   }
 
-  forceinline VoidFunction
-  VarBranch::merit(void) const {
+  template<class Var>
+  inline CHB
+  VarBranch<Var>::chb(void) const {
+    return _chb;
+  }
+
+  template<class Var>
+  inline void
+  VarBranch<Var>::chb(CHB chb) {
+    _chb=chb;
+  }
+
+  template<class Var>
+  inline typename VarBranch<Var>::MeritFunction
+  VarBranch<Var>::merit(void) const {
     return _mf;
   }
 
