@@ -7,8 +7,8 @@
  *     Christian Schulte, 2012
  *
  *  Last modified:
- *     $Date: 2012-10-30 07:46:12 +0100 (Tue, 30 Oct 2012) $ by $Author: tack $
- *     $Revision: 13166 $
+ *     $Date: 2017-04-01 20:27:10 +0200 (Sat, 01 Apr 2017) $ by $Author: schulte $
+ *     $Revision: 15623 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -49,12 +49,12 @@ namespace Gecode {
   public:
     /// Define the view type
     typedef _View View;
-    /// The branch filter that corresponds to the view type
-    typedef typename BranchTraits<typename View::VarType>::Filter BranchFilter;
+    /// The corresponding variable type
+    typedef typename View::VarType Var;
     /// \name Initialization
     //@{
     /// Constructor for creation
-    ViewSel(Space& home, const VarBranch& vb);
+    ViewSel(Space& home, const VarBranch<Var>& vb);
     /// Constructor for copying during cloning
     ViewSel(Space& home, bool shared, ViewSel<View>& vs);
     //@}
@@ -63,19 +63,27 @@ namespace Gecode {
     /// Select a view from \a x starting from \a s and return its position
     virtual int select(Space& home, ViewArray<View>& x, int s) = 0;
     /// Select a view from \a x starting from \a s and return its position
-    virtual int select(Space& home, ViewArray<View>& x, int s, 
-                       BranchFilter bf) = 0;
+    virtual int select(Space& home, ViewArray<View>& x, int s,
+                       BrancherFilter<View>& f) = 0;
+    /// Select a view from \a x starting from \a s and return its position
+    virtual int select(Space& home, ViewArray<View>& x, int s,
+                       BrancherNoFilter<View>& f);
     /// Select ties from \a x starting from \a s
-    virtual void ties(Space& home, ViewArray<View>& x, int s, 
+    virtual void ties(Space& home, ViewArray<View>& x, int s,
                       int* ties, int& n) = 0;
     /// Select ties from \a x starting from \a s
-    virtual void ties(Space& home, ViewArray<View>& x, int s, 
-                      int* ties, int& n, BranchFilter bf) = 0;
+    virtual void ties(Space& home, ViewArray<View>& x, int s,
+                      int* ties, int& n,
+                      BrancherFilter<View>& f) = 0;
+    /// Select ties from \a x starting from \a s
+    virtual void ties(Space& home, ViewArray<View>& x, int s,
+                      int* ties, int& n,
+                      BrancherNoFilter<View>& f);
     /// Break ties in \a x and update to new ties
-    virtual void brk(Space& home, ViewArray<View>& x, 
+    virtual void brk(Space& home, ViewArray<View>& x,
                      int* ties, int& n) = 0;
     /// Select a view from \a x considering views with positions in \a ties
-    virtual int select(Space& home, ViewArray<View>& x, 
+    virtual int select(Space& home, ViewArray<View>& x,
                        int* ties, int n) = 0;
     //@}
     /// \name Resource management and cloning
@@ -86,6 +94,8 @@ namespace Gecode {
     virtual bool notice(void) const;
     /// Dispose view selection
     virtual void dispose(Space& home);
+    /// Unused destructor
+    virtual ~ViewSel(void);
     //@}
     /// \name Memory management
     //@{
@@ -101,12 +111,13 @@ namespace Gecode {
   /// Select the first unassigned view
   template<class View>
   class ViewSelNone : public ViewSel<View> {
-    typedef typename ViewSel<View>::BranchFilter BranchFilter;
+  protected:
+    typedef typename ViewSel<View>::Var Var;
   public:
     /// \name Initialization
     //@{
     /// Constructor for creation
-    ViewSelNone(Space& home, const VarBranch& vb);
+    ViewSelNone(Space& home, const VarBranch<Var>& vb);
     /// Constructor for copying during cloning
     ViewSelNone(Space& home, bool shared, ViewSelNone<View>& vs);
     //@}
@@ -115,17 +126,17 @@ namespace Gecode {
     /// Select a view from \a x starting at \a s and return its position
     virtual int select(Space& home, ViewArray<View>& x, int s);
     /// Select a view from \a x starting at \a s and return its position
-    virtual int select(Space& home, ViewArray<View>& x, int s, 
-                       BranchFilter bf);
+    virtual int select(Space& home, ViewArray<View>& x, int s,
+                       BrancherFilter<View>& f);
     /// Select ties from \a x starting at \a s
-    virtual void ties(Space& home, ViewArray<View>& x, int s, 
+    virtual void ties(Space& home, ViewArray<View>& x, int s,
                       int* ties, int& n);
     /// Select ties from \a x starting at \a s
-    virtual void ties(Space& home, ViewArray<View>& x, int s, 
+    virtual void ties(Space& home, ViewArray<View>& x, int s,
                       int* ties, int& n,
-                      BranchFilter bf);
+                      BrancherFilter<View>& f);
     /// Break ties in \a x and update to new ties
-    virtual void brk(Space& home, ViewArray<View>& x, 
+    virtual void brk(Space& home, ViewArray<View>& x,
                      int* ties, int& n);
     /// Select a view from \a x considering view with positions in \a ties
     virtual int select(Space& home, ViewArray<View>& x, int* ties, int n);
@@ -140,15 +151,15 @@ namespace Gecode {
   /// Select a view randomly
   template<class View>
   class ViewSelRnd : public ViewSel<View> {
-    typedef typename ViewSel<View>::BranchFilter BranchFilter;
   protected:
+    typedef typename ViewSel<View>::Var Var;
     /// The random number generator used
     Rnd r;
   public:
     /// \name Initialization
     //@{
     /// Constructor for creation
-    ViewSelRnd(Space& home, const VarBranch& vb);
+    ViewSelRnd(Space& home, const VarBranch<Var>& vb);
     /// Constructor for copying during cloning
     ViewSelRnd(Space& home, bool shared, ViewSelRnd<View>& vs);
     //@}
@@ -158,13 +169,14 @@ namespace Gecode {
     virtual int select(Space& home, ViewArray<View>& x, int s);
     /// Select a view from \a x starting from \a s and return its position
     virtual int select(Space& home, ViewArray<View>& x, int s,
-                       BranchFilter bf);
+                       BrancherFilter<View>& f);
     /// Select ties from \a x starting from \a s
-    virtual void ties(Space& home, ViewArray<View>& x, int s, 
+    virtual void ties(Space& home, ViewArray<View>& x, int s,
                       int* ties, int& n);
     /// Select ties from \a x starting from \a s
-    virtual void ties(Space& home, ViewArray<View>& x, int s, 
-                      int* ties, int& n, BranchFilter bf);
+    virtual void ties(Space& home, ViewArray<View>& x, int s,
+                      int* ties, int& n,
+                      BrancherFilter<View>& f);
     /// Break ties in \a x and update to new ties
     virtual void brk(Space& home, ViewArray<View>& x, int* ties, int& n);
     /// Select a view from \a x considering view with positions in \a ties
@@ -197,8 +209,8 @@ namespace Gecode {
   template<class Choose, class Merit>
   class ViewSelChoose : public ViewSel<typename Merit::View> {
   protected:
+    typedef typename ViewSel<typename Merit::View>::Var Var;
     typedef typename ViewSel<typename Merit::View>::View View;
-    typedef typename ViewSel<typename Merit::View>::BranchFilter BranchFilter;
     /// Type of merit
     typedef typename Merit::Val Val;
     /// How to choose
@@ -209,7 +221,7 @@ namespace Gecode {
     /// \name Initialization
     //@{
     /// Constructor for creation
-    ViewSelChoose(Space& home, const VarBranch& vb);
+    ViewSelChoose(Space& home, const VarBranch<Var>& vb);
     /// Constructor for copying during cloning
     ViewSelChoose(Space& home, bool shared, ViewSelChoose<Choose,Merit>& vs);
     //@}
@@ -218,14 +230,15 @@ namespace Gecode {
     /// Select a view from \a x starting from \a s and return its position
     virtual int select(Space& home, ViewArray<View>& x, int s);
     /// Select a view from \a x starting from \a s and return its position
-    virtual int select(Space& home, ViewArray<View>& x, int s, 
-                       BranchFilter bf);
+    virtual int select(Space& home, ViewArray<View>& x, int s,
+                       BrancherFilter<View>& f);
     /// Select ties from \a x starting from \a s
-    virtual void ties(Space& home, ViewArray<View>& x, int s, 
+    virtual void ties(Space& home, ViewArray<View>& x, int s,
                       int* ties, int& n);
     /// Select ties from \a x starting from \a s
-    virtual void ties(Space& home, ViewArray<View>& x, int s, 
-                      int* ties, int& n, BranchFilter bf);
+    virtual void ties(Space& home, ViewArray<View>& x, int s,
+                      int* ties, int& n,
+                      BrancherFilter<View>& f);
     /// Break ties in \a x and update to new ties
     virtual void brk(Space& home, ViewArray<View>& x, int* ties, int& n);
     /// Select a view from \a x considering views with positions in \a ties
@@ -247,43 +260,51 @@ namespace Gecode {
   protected:
     typedef typename ViewSelChoose<Choose,Merit>::Val Val;
     typedef typename ViewSelChoose<Choose,Merit>::View View;
-    typedef typename ViewSelChoose<Choose,Merit>::BranchFilter BranchFilter;
+    typedef typename ViewSelChoose<Choose,Merit>::Var Var;
     using ViewSelChoose<Choose,Merit>::c;
     using ViewSelChoose<Choose,Merit>::m;
     /// Tie-break limit function
-    BranchTbl tbl;
+    SharedData<BranchTbl> tbl;
   public:
     /// \name Initialization
     //@{
     /// Constructor for initialization
-    ViewSelChooseTbl(Space& home, const VarBranch& vb);
+    ViewSelChooseTbl(Space& home, const VarBranch<Var>& vb);
     /// Constructor for copying during cloning
-    ViewSelChooseTbl(Space& home, bool shared, 
-                     ViewSelChooseTbl<Choose,Merit>& vs); 
+    ViewSelChooseTbl(Space& home, bool shared,
+                     ViewSelChooseTbl<Choose,Merit>& vs);
     //@}
     /// \name View selection and tie breaking
     //@{
     /// Select ties from \a x starting from \a s
-    virtual void ties(Space& home, ViewArray<View>& x, int s, 
+    virtual void ties(Space& home, ViewArray<View>& x, int s,
                       int* ties, int& n);
     /// Select ties from \a x starting from \a s
-    virtual void ties(Space& home, ViewArray<View>& x, int s, 
-                      int* ties, int& n, BranchFilter bf);
+    virtual void ties(Space& home, ViewArray<View>& x, int s,
+                      int* ties, int& n,
+                      BrancherFilter<View>& f);
     /// Break ties in \a x and update to new ties
     virtual void brk(Space& home, ViewArray<View>& x, int* ties, int& n);
     //@}
+    /// \name Resource management and cloning
+    //@{
+    /// Whether dispose must always be called (that is, notice is needed)
+    virtual bool notice(void) const;
+    /// Delete view selection
+    virtual void dispose(Space& home);
+    //@}
   };
 
   /// Select view with least merit
   template<class Merit>
   class ViewSelMin : public ViewSelChoose<ChooseMin,Merit> {
     typedef typename ViewSelChoose<ChooseMin,Merit>::View View;
-    typedef typename ViewSelChoose<ChooseMin,Merit>::BranchFilter BranchFilter;
+    typedef typename ViewSelChoose<ChooseMin,Merit>::Var Var;
   public:
     /// \name Initialization
     //@{
     /// Constructor for initialization
-    ViewSelMin(Space& home, const VarBranch& vb);
+    ViewSelMin(Space& home, const VarBranch<Var>& vb);
     /// Constructor for copying during cloning
     ViewSelMin(Space& home, bool shared, ViewSelMin<Merit>& vs);
     //@}
@@ -298,12 +319,12 @@ namespace Gecode {
   template<class Merit>
   class ViewSelMinTbl : public ViewSelChooseTbl<ChooseMin,Merit> {
     typedef typename ViewSelChooseTbl<ChooseMin,Merit>::View View;
-    typedef typename ViewSelChooseTbl<ChooseMin,Merit>::BranchFilter BranchFilter;
+    typedef typename ViewSelChooseTbl<ChooseMin,Merit>::Var Var;
   public:
     /// \name Initialization
     //@{
     /// Constructor for initialization
-    ViewSelMinTbl(Space& home, const VarBranch& vb);
+    ViewSelMinTbl(Space& home, const VarBranch<Var>& vb);
     /// Constructor for copying during cloning
     ViewSelMinTbl(Space& home, bool shared, ViewSelMinTbl<Merit>& vs);
     //@}
@@ -318,12 +339,12 @@ namespace Gecode {
   template<class Merit>
   class ViewSelMax : public ViewSelChoose<ChooseMax,Merit> {
     typedef typename ViewSelChoose<ChooseMax,Merit>::View View;
-    typedef typename ViewSelChoose<ChooseMax,Merit>::BranchFilter BranchFilter;
+    typedef typename ViewSelChoose<ChooseMax,Merit>::Var Var;
   public:
     /// \name Initialization
     //@{
     /// Constructor for initialization
-    ViewSelMax(Space& home, const VarBranch& vb);
+    ViewSelMax(Space& home, const VarBranch<Var>& vb);
     /// Constructor for copying during cloning
     ViewSelMax(Space& home, bool shared, ViewSelMax<Merit>& vs);
     //@}
@@ -338,12 +359,12 @@ namespace Gecode {
   template<class Merit>
   class ViewSelMaxTbl : public ViewSelChooseTbl<ChooseMax,Merit> {
     typedef typename ViewSelChooseTbl<ChooseMax,Merit>::View View;
-    typedef typename ViewSelChooseTbl<ChooseMax,Merit>::BranchFilter BranchFilter;
+    typedef typename ViewSelChooseTbl<ChooseMax,Merit>::Var Var;
   public:
     /// \name Initialization
     //@{
     /// Constructor for initialization
-    ViewSelMaxTbl(Space& home, const VarBranch& vb);
+    ViewSelMaxTbl(Space& home, const VarBranch<Var>& vb);
     /// Constructor for copying during cloning
     ViewSelMaxTbl(Space& home, bool shared, ViewSelMaxTbl<Merit>& vs);
     //@}
@@ -358,11 +379,25 @@ namespace Gecode {
 
   template<class View>
   forceinline
-  ViewSel<View>::ViewSel(Space&, const VarBranch&) {}
+  ViewSel<View>::ViewSel(Space&, const VarBranch<Var>&) {}
   template<class View>
   forceinline
   ViewSel<View>::ViewSel(Space&, bool, ViewSel<View>&) {}
   template<class View>
+  int
+  ViewSel<View>::select(Space&, ViewArray<View>&, int,
+                        BrancherNoFilter<View>&) {
+    GECODE_NEVER;
+    return 0;
+  }
+  template<class View>
+  void
+  ViewSel<View>::ties(Space&, ViewArray<View>&, int,
+                      int*, int&,
+                      BrancherNoFilter<View>&) {
+    GECODE_NEVER;
+  }
+  template<class View>
   bool
   ViewSel<View>::notice(void) const {
     return false;
@@ -371,6 +406,8 @@ namespace Gecode {
   void
   ViewSel<View>::dispose(Space&) {}
   template<class View>
+  ViewSel<View>::~ViewSel(void) {}
+  template<class View>
   forceinline void
   ViewSel<View>::operator delete(void*) {}
   template<class View>
@@ -383,13 +420,14 @@ namespace Gecode {
   }
 
 
+
   template<class View>
   forceinline
-  ViewSelNone<View>::ViewSelNone(Space& home, const VarBranch& vb) 
+  ViewSelNone<View>::ViewSelNone(Space& home, const VarBranch<Var>& vb)
       : ViewSel<View>(home,vb) {}
   template<class View>
   forceinline
-  ViewSelNone<View>::ViewSelNone(Space& home, bool shared, 
+  ViewSelNone<View>::ViewSelNone(Space& home, bool shared,
                                  ViewSelNone<View>& vs)
     : ViewSel<View>(home,shared,vs) {}
   template<class View>
@@ -399,12 +437,13 @@ namespace Gecode {
   }
   template<class View>
   int
-  ViewSelNone<View>::select(Space&, ViewArray<View>&, int s, BranchFilter) {
+  ViewSelNone<View>::select(Space&, ViewArray<View>&, int s,
+                            BrancherFilter<View>&) {
     return s;
   }
   template<class View>
-  void 
-  ViewSelNone<View>::ties(Space&, ViewArray<View>& x, int s, 
+  void
+  ViewSelNone<View>::ties(Space&, ViewArray<View>& x, int s,
                           int* ties, int& n) {
     int j=0; ties[j++]=s;
     for (int i=s+1; i<x.size(); i++)
@@ -414,15 +453,14 @@ namespace Gecode {
     assert(n > 0);
   }
   template<class View>
-  void 
-  ViewSelNone<View>::ties(Space& home, ViewArray<View>& x, int s, 
-                          int* ties, int& n, BranchFilter bf) {
+  void
+  ViewSelNone<View>::ties(Space& home, ViewArray<View>& x, int s,
+                          int* ties, int& n,
+                          BrancherFilter<View>& f) {
     int j=0; ties[j++]=s;
-    for (int i=s+1; i<x.size(); i++) {
-      typename View::VarType y(x[i].varimp());
-      if (!x[i].assigned() && bf(home,y,i))
+    for (int i=s+1; i<x.size(); i++)
+      if (!x[i].assigned() && f(home,x[i],i))
         ties[j++]=i;
-    }
     n=j;
     assert(n > 0);
   }
@@ -445,7 +483,7 @@ namespace Gecode {
 
   template<class View>
   forceinline
-  ViewSelRnd<View>::ViewSelRnd(Space& home, const VarBranch& vb) 
+  ViewSelRnd<View>::ViewSelRnd(Space& home, const VarBranch<Var>& vb)
       : ViewSel<View>(home,vb), r(vb.rnd()) {}
   template<class View>
   forceinline
@@ -465,34 +503,34 @@ namespace Gecode {
     return j;
   }
   template<class View>
-  int ViewSelRnd<View>::select(Space& home, ViewArray<View>& x, int s,
-                               BranchFilter bf) {
+  int
+  ViewSelRnd<View>::select(Space& home, ViewArray<View>& x, int s,
+                           BrancherFilter<View>& f) {
     unsigned int n=1;
     int j=s;
-    for (int i=s+1; i<x.size(); i++) {
-      typename View::VarType y(x[i].varimp());
-      if (!x[i].assigned() && bf(home,y,i)) {
+    for (int i=s+1; i<x.size(); i++)
+      if (!x[i].assigned() && f(home,x[i],i)) {
         n++;
         if (r(n) == 0U)
           j=i;
       }
-    }
     return j;
   }
   template<class View>
-  void 
-  ViewSelRnd<View>::ties(Space& home, ViewArray<View>& x, int s, 
+  void
+  ViewSelRnd<View>::ties(Space& home, ViewArray<View>& x, int s,
                          int* ties, int& n) {
     n=1; ties[0] = select(home,x,s);
   }
   template<class View>
   void
-  ViewSelRnd<View>::ties(Space& home, ViewArray<View>& x, int s, 
-                         int* ties, int& n, BranchFilter bf) {
-    n=1; ties[0] = select(home,x,s,bf);
+  ViewSelRnd<View>::ties(Space& home, ViewArray<View>& x, int s,
+                         int* ties, int& n,
+                         BrancherFilter<View>&) {
+    n=1; ties[0] = select(home,x,s);
   }
   template<class View>
-  void 
+  void
   ViewSelRnd<View>::brk(Space&, ViewArray<View>&, int* ties, int& n) {
     ties[0] = ties[static_cast<int>(r(static_cast<unsigned int>(n)))];
     n=1;
@@ -523,13 +561,13 @@ namespace Gecode {
 
   template<class Choose, class Merit>
   forceinline
-  ViewSelChoose<Choose,Merit>::ViewSelChoose(Space& home, const VarBranch& vb) 
+  ViewSelChoose<Choose,Merit>::ViewSelChoose(Space& home, const VarBranch<Var>& vb)
     : ViewSel<View>(home,vb), m(home,vb) {}
 
   template<class Choose, class Merit>
   forceinline
-  ViewSelChoose<Choose,Merit>::ViewSelChoose(Space& home, bool shared, 
-                                             ViewSelChoose<Choose,Merit>& vs) 
+  ViewSelChoose<Choose,Merit>::ViewSelChoose(Space& home, bool shared,
+                                             ViewSelChoose<Choose,Merit>& vs)
     : ViewSel<View>(home,shared,vs), m(home,shared,vs.m) {}
 
   template<class Choose, class Merit>
@@ -550,28 +588,26 @@ namespace Gecode {
   }
 
   template<class Choose, class Merit>
-  int 
-  ViewSelChoose<Choose,Merit>::select(Space& home, ViewArray<View>& x, int s, 
-                                      BranchFilter bf) {
+  int
+  ViewSelChoose<Choose,Merit>::select(Space& home, ViewArray<View>& x, int s,
+                                      BrancherFilter<View>& f) {
     // Consider x[s] as the so-far best view
     int b_i = s;
     Val b_m = m(home,x[s],s);
-    // Scan all assigned views from s+1 onwards
-    for (int i=s+1; i<x.size(); i++) {
-      typename View::VarType y(x[i].varimp());
-      if (!x[i].assigned() && bf(home,y,i)) {
+    // Scan all non-assigned views from s+1 onwards
+    for (int i=s+1; i<x.size(); i++)
+      if (!x[i].assigned() && f(home,x[i],i)) {
         Val mxi = m(home,x[i],i);
         if (c(mxi,b_m)) {
           b_i = i; b_m = mxi;
         }
       }
-    }
     return b_i;
   }
 
   template<class Choose, class Merit>
-  void 
-  ViewSelChoose<Choose,Merit>::ties(Space& home, ViewArray<View>& x, int s, 
+  void
+  ViewSelChoose<Choose,Merit>::ties(Space& home, ViewArray<View>& x, int s,
                                     int* ties, int& n) {
     // Consider x[s] as the so-far best view and record as tie
     Val b = m(home,x[s],s);
@@ -593,15 +629,15 @@ namespace Gecode {
   }
 
   template<class Choose, class Merit>
-  void 
-  ViewSelChoose<Choose,Merit>::ties(Space& home, ViewArray<View>& x, int s, 
-                                    int* ties, int& n, BranchFilter bf) {
+  void
+  ViewSelChoose<Choose,Merit>::ties(Space& home, ViewArray<View>& x, int s,
+                                    int* ties, int& n,
+                                    BrancherFilter<View>& f) {
     // Consider x[s] as the so-far best view and record as tie
     Val b = m(home,x[s],s);
     int j=0; ties[j++]=s;
-    for (int i=s+1; i<x.size(); i++) {
-      typename View::VarType y(x[i].varimp());
-      if (!x[i].assigned() && bf(home,y,i)) {
+    for (int i=s+1; i<x.size(); i++)
+      if (!x[i].assigned() && f(home,x[i],i)) {
         Val mxi = m(home,x[i],i);
         if (c(mxi,b)) {
           // Found a better one, reset all ties and record
@@ -611,15 +647,14 @@ namespace Gecode {
           ties[j++]=i;
         }
       }
-    }
     n=j;
     // There must be at least one tie, of course!
     assert(n > 0);
   }
 
   template<class Choose, class Merit>
-  void 
-  ViewSelChoose<Choose,Merit>::brk(Space& home, ViewArray<View>& x, 
+  void
+  ViewSelChoose<Choose,Merit>::brk(Space& home, ViewArray<View>& x,
                                    int* ties, int& n) {
     // Keep first tie in place
     Val b = m(home,x[ties[0]],ties[0]);
@@ -636,13 +671,13 @@ namespace Gecode {
       }
     }
     n=j;
-    // There must be at least one tie, of course!      
+    // There must be at least one tie, of course!
     assert(n > 0);
   }
 
   template<class Choose, class Merit>
-  int 
-  ViewSelChoose<Choose,Merit>::select(Space& home, ViewArray<View>& x, 
+  int
+  ViewSelChoose<Choose,Merit>::select(Space& home, ViewArray<View>& x,
                                       int* ties, int n) {
     int b_i = ties[0];
     Val b_m = m(home,x[ties[0]],ties[0]);
@@ -654,15 +689,15 @@ namespace Gecode {
     }
     return b_i;
   }
-  
+
   template<class Choose, class Merit>
-  bool 
+  bool
   ViewSelChoose<Choose,Merit>::notice(void) const {
     return m.notice();
   }
 
   template<class Choose, class Merit>
-  void 
+  void
   ViewSelChoose<Choose,Merit>::dispose(Space& home) {
     m.dispose(home);
   }
@@ -670,20 +705,25 @@ namespace Gecode {
 
   template<class Choose, class Merit>
   forceinline
-  ViewSelChooseTbl<Choose,Merit>::ViewSelChooseTbl(Space& home, 
-                                                   const VarBranch& vb) 
-    : ViewSelChoose<Choose,Merit>(home,vb), tbl(vb.tbl()) {}
+  ViewSelChooseTbl<Choose,Merit>::ViewSelChooseTbl(Space& home,
+                                                   const VarBranch<Var>& vb)
+    : ViewSelChoose<Choose,Merit>(home,vb), tbl(vb.tbl()) {
+    if (!tbl())
+      throw InvalidFunction("ViewSelChooseTbl::ViewSelChooseTbl");
+  }
 
   template<class Choose, class Merit>
   forceinline
   ViewSelChooseTbl<Choose,Merit>::ViewSelChooseTbl
-  (Space& home, bool shared, 
-   ViewSelChooseTbl<Choose,Merit>& vs) 
-    : ViewSelChoose<Choose,Merit>(home,shared,vs), tbl(vs.tbl) {}
+  (Space& home, bool shared,
+   ViewSelChooseTbl<Choose,Merit>& vs)
+    : ViewSelChoose<Choose,Merit>(home,shared,vs) {
+    tbl.update(home,shared,vs.tbl);
+  }
 
   template<class Choose, class Merit>
-  void 
-  ViewSelChooseTbl<Choose,Merit>::ties(Space& home, ViewArray<View>& x, int s, 
+  void
+  ViewSelChooseTbl<Choose,Merit>::ties(Space& home, ViewArray<View>& x, int s,
                                        int* ties, int& n) {
     // Find the worst and best merit value
     Val w = m(home,x[s],s);
@@ -697,7 +737,8 @@ namespace Gecode {
           w=mxi;
       }
     // Compute tie-break limit
-    double l = tbl(home,static_cast<double>(w),static_cast<double>(b));
+    GECODE_VALID_FUNCTION(tbl());
+    double l = tbl()(home,static_cast<double>(w),static_cast<double>(b));
     // If the limit is not better than the worst merit, everything is a tie
     if (!c(l,static_cast<double>(w))) {
       int j=0;
@@ -722,31 +763,30 @@ namespace Gecode {
 
   template<class Choose, class Merit>
   void
-  ViewSelChooseTbl<Choose,Merit>::ties(Space& home, ViewArray<View>& x, int s, 
-                                       int* ties, int& n, BranchFilter bf) {
+  ViewSelChooseTbl<Choose,Merit>::ties(Space& home, ViewArray<View>& x, int s,
+                                       int* ties, int& n,
+                                       BrancherFilter<View>& f) {
     // Find the worst and best merit value
+    assert(f(home,x[s],s));
     Val w = m(home,x[s],s);
     Val b = w;
-    for (int i=s+1; i<x.size(); i++) {
-      typename View::VarType y(x[i].varimp());
-      if (!x[i].assigned() && bf(home,y,i)) {
+    for (int i=s+1; i<x.size(); i++)
+      if (!x[i].assigned() && f(home,x[i],i)) {
         Val mxi = m(home,x[i],i);
         if (c(mxi,b))
           b=mxi;
         else if (c(w,mxi))
           w=mxi;
       }
-    }
     // Compute tie-break limit
-    double l = tbl(home,static_cast<double>(w),static_cast<double>(b));
+    GECODE_VALID_FUNCTION(tbl());
+    double l = tbl()(home,static_cast<double>(w),static_cast<double>(b));
     // If the limit is not better than the worst merit, everything is a tie
     if (!c(l,static_cast<double>(w))) {
       int j=0;
-      for (int i=s; i<x.size(); i++) {
-        typename View::VarType y(x[i].varimp());
-        if (!x[i].assigned() && bf(home,y,i)) 
+      for (int i=s; i<x.size(); i++)
+        if (!x[i].assigned() && f(home,x[i],i))
           ties[j++]=i;
-      }
       n=j;
     } else {
       // The limit is not allowed to better than the best merit value
@@ -754,14 +794,12 @@ namespace Gecode {
         l = static_cast<double>(b);
       // Record all ties that are not worse than the limit merit value
       int j=0;
-      for (int i=s; i<x.size(); i++) {
-        typename View::VarType y(x[i].varimp());
-        if (!x[i].assigned() && bf(home,y,i) && 
+      for (int i=s; i<x.size(); i++)
+        if (!x[i].assigned() && f(home,x[i],i) &&
             !c(l,static_cast<double>(m(home,x[i],i))))
           ties[j++]=i;
-      }
       n=j;
-      }
+    }
     // There will be at least one tie (the best will qualify, of course)
     assert(n > 0);
   }
@@ -781,7 +819,8 @@ namespace Gecode {
         w=mxi;
     }
     // Compute tie-break limit
-    double l = tbl(home,static_cast<double>(w),static_cast<double>(b));
+    GECODE_VALID_FUNCTION(tbl());
+    double l = tbl()(home,static_cast<double>(w),static_cast<double>(b));
     // If the limit is not better than the worst merit, everything is a tie
     // and no breaking is required
     if (c(l,static_cast<double>(w))) {
@@ -798,22 +837,32 @@ namespace Gecode {
     // There will be at least one tie (the best will qualify)
     assert(n > 0);
   }
+  template<class Choose, class Merit>
+  bool
+  ViewSelChooseTbl<Choose,Merit>::notice(void) const {
+    return true;
+  }
+  template<class Choose, class Merit>
+  void
+  ViewSelChooseTbl<Choose,Merit>::dispose(Space&) {
+    tbl.~SharedData<BranchTbl>();
+  }
 
 
 
   template<class Merit>
   forceinline
-  ViewSelMin<Merit>::ViewSelMin(Space& home, const VarBranch& vb) 
+  ViewSelMin<Merit>::ViewSelMin(Space& home, const VarBranch<Var>& vb)
     : ViewSelChoose<ChooseMin,Merit>(home,vb) {}
 
   template<class Merit>
   forceinline
-  ViewSelMin<Merit>::ViewSelMin(Space& home, bool shared, 
-                                ViewSelMin<Merit>& vs) 
+  ViewSelMin<Merit>::ViewSelMin(Space& home, bool shared,
+                                ViewSelMin<Merit>& vs)
     : ViewSelChoose<ChooseMin,Merit>(home,shared,vs) {}
 
   template<class Merit>
-  ViewSel<typename ViewSelMin<Merit>::View>* 
+  ViewSel<typename ViewSelMin<Merit>::View>*
   ViewSelMin<Merit>::copy(Space& home, bool shared) {
     return new (home) ViewSelMin<Merit>(home,shared,*this);
   }
@@ -821,17 +870,17 @@ namespace Gecode {
 
   template<class Merit>
   forceinline
-  ViewSelMinTbl<Merit>::ViewSelMinTbl(Space& home, const VarBranch& vb) 
+  ViewSelMinTbl<Merit>::ViewSelMinTbl(Space& home, const VarBranch<Var>& vb)
     : ViewSelChooseTbl<ChooseMin,Merit>(home,vb) {}
 
   template<class Merit>
   forceinline
-  ViewSelMinTbl<Merit>::ViewSelMinTbl(Space& home, bool shared, 
-                                      ViewSelMinTbl<Merit>& vs) 
+  ViewSelMinTbl<Merit>::ViewSelMinTbl(Space& home, bool shared,
+                                      ViewSelMinTbl<Merit>& vs)
     : ViewSelChooseTbl<ChooseMin,Merit>(home,shared,vs) {}
 
   template<class Merit>
-  ViewSel<typename ViewSelMinTbl<Merit>::View>* 
+  ViewSel<typename ViewSelMinTbl<Merit>::View>*
   ViewSelMinTbl<Merit>::copy(Space& home, bool shared) {
     return new (home) ViewSelMinTbl<Merit>(home,shared,*this);
   }
@@ -840,17 +889,17 @@ namespace Gecode {
 
   template<class Merit>
   forceinline
-  ViewSelMax<Merit>::ViewSelMax(Space& home, const VarBranch& vb) 
+  ViewSelMax<Merit>::ViewSelMax(Space& home, const VarBranch<Var>& vb)
     : ViewSelChoose<ChooseMax,Merit>(home,vb) {}
 
   template<class Merit>
   forceinline
-  ViewSelMax<Merit>::ViewSelMax(Space& home, bool shared, 
-                                ViewSelMax<Merit>& vs) 
+  ViewSelMax<Merit>::ViewSelMax(Space& home, bool shared,
+                                ViewSelMax<Merit>& vs)
     : ViewSelChoose<ChooseMax,Merit>(home,shared,vs) {}
 
   template<class Merit>
-  ViewSel<typename ViewSelMax<Merit>::View>* 
+  ViewSel<typename ViewSelMax<Merit>::View>*
   ViewSelMax<Merit>::copy(Space& home, bool shared) {
     return new (home) ViewSelMax<Merit>(home,shared,*this);
   }
@@ -859,17 +908,17 @@ namespace Gecode {
 
   template<class Merit>
   forceinline
-  ViewSelMaxTbl<Merit>::ViewSelMaxTbl(Space& home, const VarBranch& vb) 
+  ViewSelMaxTbl<Merit>::ViewSelMaxTbl(Space& home, const VarBranch<Var>& vb)
     : ViewSelChooseTbl<ChooseMax,Merit>(home,vb) {}
 
   template<class Merit>
   forceinline
-  ViewSelMaxTbl<Merit>::ViewSelMaxTbl(Space& home, bool shared, 
-                                      ViewSelMaxTbl<Merit>& vs) 
+  ViewSelMaxTbl<Merit>::ViewSelMaxTbl(Space& home, bool shared,
+                                      ViewSelMaxTbl<Merit>& vs)
     : ViewSelChooseTbl<ChooseMax,Merit>(home,shared,vs) {}
 
   template<class Merit>
-  ViewSel<typename ViewSelMaxTbl<Merit>::View>* 
+  ViewSel<typename ViewSelMaxTbl<Merit>::View>*
   ViewSelMaxTbl<Merit>::copy(Space& home, bool shared) {
     return new (home) ViewSelMaxTbl<Merit>(home,shared,*this);
   }
