@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2015-01-05 07:32:41 +0100 (Mon, 05 Jan 2015) $ by $Author: tack $
- *     $Revision: 14336 $
+ *     $Date: 2017-03-17 23:04:57 +0100 (Fri, 17 Mar 2017) $ by $Author: schulte $
+ *     $Revision: 15597 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -56,11 +56,7 @@ namespace Gecode {
    */
   Actor* Actor::sentinel;
 
-#ifdef __GNUC__
-  /// To avoid warnings from GCC
   Actor::~Actor(void) {}
-#endif
-
 
 
   /*
@@ -69,9 +65,13 @@ namespace Gecode {
    */
   ExecStatus
   Propagator::advise(Space&, Advisor&, const Delta&) {
-    assert(false);
+    GECODE_NEVER;
     return ES_FAILED;
   }
+  void
+  Propagator::advise(Space&, Advisor&) {
+    GECODE_NEVER;
+  }
 
 
   /*
@@ -93,7 +93,7 @@ namespace Gecode {
     return NULL;
   }
 
-  void 
+  void
   Brancher::print(const Space&, const Choice&, unsigned int,
                   std::ostream&) const {
   }
@@ -111,8 +111,7 @@ namespace Gecode {
   VarImpDisposerBase* Space::vd[AllVarConf::idx_d];
 #endif
 
-  Space::Space(void)
-    : sm(new SharedMemory), mm(sm), _wmp_afc(0U) {
+  Space::Space(void) : sm(new SharedMemory), mm(sm) {
 #ifdef GECODE_HAS_VAR_DISPOSE
     for (int i=0; i<AllVarConf::idx_d; i++)
       _vars_d[i] = NULL;
@@ -128,84 +127,55 @@ namespace Gecode {
     // Initialize propagator queues
     for (int i=0; i<=PropCost::AC_MAX; i++)
       pc.p.queue[i].init();
-    pc.p.branch_id = reserved_branch_id+1;
-    pc.p.n_sub = 0;
+    pc.p.bid_sc = (reserved_bid+1) << sc_bits;
+    pc.p.n_sub  = 0;
   }
 
   void
-  Space::notice(Actor& a, ActorProperty p, bool duplicate) {
-    if (p & AP_DISPOSE) {
-      if (duplicate && (d_fst != NULL)) {
-        for (Actor** f = d_fst; f < d_cur; f++)
-          if (&a == *f)
-            return;
-      }
-      if (d_cur == d_lst) {
-        // Resize
-        if (d_fst == NULL) {
-          // Create new array
-          d_fst = alloc<Actor*>(4);
-          d_cur = d_fst;
-          d_lst = d_fst+4;
-        } else {
-          // Resize existing array
-          unsigned int n = static_cast<unsigned int>(d_lst - d_fst);
-          assert(n != 0);
-          d_fst = realloc<Actor*>(d_fst,n,2*n);
-          d_cur = d_fst+n;
-          d_lst = d_fst+2*n;
-        }
-      }
-      *(d_cur++) = &a;
-    } else if (p & AP_WEAKLY) {
-      if (wmp() == 0)
-        wmp(2);
-      else
-        wmp(wmp()+1);
-    }
-  }
-
-  void
-  Space::ignore(Actor& a, ActorProperty p, bool duplicate) {
-    if (p & AP_DISPOSE) {
-      // Check wether array has already been discarded as space
-      // deletion is already in progress
-      if (d_fst == NULL)
-        return;
-      Actor** f = d_fst;
-      if (duplicate) {
-        while (f < d_cur)
-          if (&a == *f)
-            break;
-          else
-            f++;
-        if (f == d_cur)
+  Space::ap_notice_dispose(Actor* a, bool duplicate) {
+    // Note that a might be a marked pointer!
+    if (duplicate && (d_fst != NULL)) {
+      for (Actor** f = d_fst; f < d_cur; f++)
+        if (a == *f)
           return;
-      } else {
-        while (&a != *f)
-          f++;
-      }
-      *f = *(--d_cur);
-    } else if (p & AP_WEAKLY) {
-      assert(wmp() > 1U);
-      wmp(wmp()-1);
     }
+    if (d_cur == d_lst) {
+      // Resize
+      if (d_fst == NULL) {
+        // Create new array
+        d_fst = alloc<Actor*>(4);
+        d_cur = d_fst;
+        d_lst = d_fst+4;
+      } else {
+        // Resize existing array
+        unsigned int n = static_cast<unsigned int>(d_lst - d_fst);
+        assert(n != 0);
+        d_fst = realloc<Actor*>(d_fst,n,2*n);
+        d_cur = d_fst+n;
+        d_lst = d_fst+2*n;
+      }
+    }
+    *(d_cur++) = a;
   }
 
-  unsigned int
-  Space::propagators(void) const {
-    unsigned int n = 0;
-    for (Propagators p(*this); p(); ++p)
-      n++;
-    return n;
-  }
-
-  unsigned int
-  Space::branchers(void) const {
-    unsigned int n = 0;
-    for (Branchers b(*this); b(); ++b)
-      n++;
-    return n;
+  void
+  Space::ap_ignore_dispose(Actor* a, bool duplicate) {
+    // Note that a might be a marked pointer!
+    assert(d_fst != NULL);
+    Actor** f = d_fst;
+    if (duplicate) {
+      while (f < d_cur)
+        if (a == *f)
+          break;
+        else
+          f++;
+      if (f == d_cur)
+        return;
+    } else {
+      while (a != *f)
+        f++;
+    }
+    *f = *(--d_cur);
   }
 
   void
@@ -224,7 +194,9 @@ namespace Gecode {
       // So that d_unforce knows that deletion is in progress
       d_fst = NULL;
       while (a < e) {
-        (void) (*a)->dispose(*this);
+        // Ignore entries for tracers
+        if (!Support::marked(*a))
+          (void) (*a)->dispose(*this);
         a++;
       }
     }
@@ -250,77 +222,223 @@ namespace Gecode {
 
   SpaceStatus
   Space::status(StatusStatistics& stat) {
-    SpaceStatus s = SS_FAILED;
     // Check whether space is failed
-    if (failed()) {
-      s = SS_FAILED; goto exit;
-    }
+    if (failed())
+      return SS_FAILED;
     assert(pc.p.active <= &pc.p.queue[PropCost::AC_MAX+1]);
+    Propagator* p;
     // Check whether space is stable but not failed
     if (pc.p.active >= &pc.p.queue[0]) {
-      Propagator* p;
       ModEventDelta med_o;
-      goto unstable;
-    execute:
-      stat.propagate++;
-      // Keep old modification event delta
-      med_o = p->u.med;
-      // Clear med but leave propagator in queue
-      p->u.med = 0;
-      switch (p->propagate(*this,med_o)) {
-      case ES_FAILED:
-        // Count failure
-        if (afc_enabled())
-          gafc.fail(p->gafc);
-        // Mark as failed
-        fail(); s = SS_FAILED; goto exit;
-      case ES_NOFIX:
-        // Find next, if possible
-        if (p->u.med != 0) {
-        unstable:
-          // There is at least one propagator in a queue
+      if ((pc.p.bid_sc & ((1 << sc_bits) - 1)) == 0) {
+        // No support for disabled propagators and tracing
+        // Check whether space is stable but not failed
+        goto f_unstable;
+      f_execute:
+        stat.propagate++;
+        // Keep old modification event delta
+        med_o = p->u.med;
+        // Clear med but leave propagator in queue
+        p->u.med = 0;
+        switch (p->propagate(*this,med_o)) {
+        case ES_FAILED:
+          goto failed;
+        case ES_NOFIX:
+          // Find next, if possible
+          if (p->u.med != 0) {
+          f_unstable:
+            // There is at least one propagator in a queue
+            do {
+              assert(pc.p.active >= &pc.p.queue[0]);
+              // First propagator or link back to queue
+              ActorLink* fst = pc.p.active->next();
+              if (pc.p.active != fst) {
+                p = Propagator::cast(fst);
+                goto f_execute;
+              }
+              pc.p.active--;
+            } while (true);
+            GECODE_NEVER;
+          }
+          // Fall through
+        case ES_FIX:
+          // Clear med
+          p->u.med = 0;
+          // Put into idle queue
+          p->unlink(); pl.head(p);
+        f_stable_or_unstable:
+          // There might be a propagator in the queue
           do {
             assert(pc.p.active >= &pc.p.queue[0]);
             // First propagator or link back to queue
             ActorLink* fst = pc.p.active->next();
             if (pc.p.active != fst) {
               p = Propagator::cast(fst);
-              goto execute;
+              goto f_execute;
             }
-            pc.p.active--;
-          } while (true);
+          } while (--pc.p.active >= &pc.p.queue[0]);
+          assert(pc.p.active < &pc.p.queue[0]);
+          goto f_stable;
+        case __ES_SUBSUMED:
+          p->unlink(); rfree(p,p->u.size);
+          goto f_stable_or_unstable;
+        case __ES_PARTIAL:
+          // Schedule propagator with specified propagator events
+          assert(p->u.med != 0);
+          enqueue(p);
+          goto f_unstable;
+        default:
           GECODE_NEVER;
         }
-        // Fall through
-      case ES_FIX:
-        // Clear med and put into idle queue
-        p->u.med = 0; p->unlink(); pl.head(p);
-      stable_or_unstable:
-        // There might be a propagator in the queue
-        do {
-          assert(pc.p.active >= &pc.p.queue[0]);
-          // First propagator or link back to queue
-          ActorLink* fst = pc.p.active->next();
-          if (pc.p.active != fst) {
-            p = Propagator::cast(fst);
-            goto execute;
+      f_stable: ;
+      } else if ((pc.p.bid_sc & ((1 << sc_bits) - 1)) == sc_disabled) {
+        // Support for disabled propagators
+        goto d_unstable;
+      d_execute:
+        stat.propagate++;
+        if (p->disabled())
+          goto d_put_into_idle;
+        // Keep old modification event delta
+        med_o = p->u.med;
+        // Clear med but leave propagator in queue
+        p->u.med = 0;
+        switch (p->propagate(*this,med_o)) {
+        case ES_FAILED:
+          goto failed;
+        case ES_NOFIX:
+          // Find next, if possible
+          if (p->u.med != 0) {
+          d_unstable:
+            // There is at least one propagator in a queue
+            do {
+              assert(pc.p.active >= &pc.p.queue[0]);
+              // First propagator or link back to queue
+              ActorLink* fst = pc.p.active->next();
+              if (pc.p.active != fst) {
+                p = Propagator::cast(fst);
+                goto d_execute;
+              }
+              pc.p.active--;
+            } while (true);
+            GECODE_NEVER;
           }
-        } while (--pc.p.active >= &pc.p.queue[0]);
-        assert(pc.p.active < &pc.p.queue[0]);
-        goto stable;
-      case __ES_SUBSUMED:
-        p->unlink(); rfree(p,p->u.size);
-        goto stable_or_unstable;
-      case __ES_PARTIAL:
-        // Schedule propagator with specified propagator events
-        assert(p->u.med != 0);
-        enqueue(p);
-        goto unstable;
-      default:
-        GECODE_NEVER;
+          // Fall through
+        case ES_FIX:
+        d_put_into_idle:
+          // Clear med
+          p->u.med = 0;
+          // Put into idle queue
+          p->unlink(); pl.head(p);
+        d_stable_or_unstable:
+          // There might be a propagator in the queue
+          do {
+            assert(pc.p.active >= &pc.p.queue[0]);
+            // First propagator or link back to queue
+            ActorLink* fst = pc.p.active->next();
+            if (pc.p.active != fst) {
+              p = Propagator::cast(fst);
+              goto d_execute;
+            }
+          } while (--pc.p.active >= &pc.p.queue[0]);
+          assert(pc.p.active < &pc.p.queue[0]);
+          goto d_stable;
+        case __ES_SUBSUMED:
+          p->unlink(); rfree(p,p->u.size);
+          goto d_stable_or_unstable;
+        case __ES_PARTIAL:
+          // Schedule propagator with specified propagator events
+          assert(p->u.med != 0);
+          enqueue(p);
+          goto d_unstable;
+        default:
+          GECODE_NEVER;
+        }
+      d_stable: ;
+      } else {
+        // Support disabled propagators and tracing
+        // Find a non-disabled tracer recorder (possibly null)
+        TraceRecorder* tr = findtr();
+
+#define GECODE_STATUS_TRACE(q,s) \
+  if ((tr != NULL) && (tr->events() & TE_PROPAGATE) && \
+      (tr->filter()(p->group()))) {                    \
+    PropagateTraceInfo pti(p->id(),p->group(),q,       \
+                           PropagateTraceInfo::s);     \
+    tr->tracer()._propagate(*this,pti);                \
+  }
+
+        goto t_unstable;
+      t_execute:
+        stat.propagate++;
+        if (p->disabled())
+          goto t_put_into_idle;
+        pc.p.vti.propagator(*p);
+        // Keep old modification event delta
+        med_o = p->u.med;
+        // Clear med but leave propagator in queue
+        p->u.med = 0;
+        switch (p->propagate(*this,med_o)) {
+        case ES_FAILED:
+          GECODE_STATUS_TRACE(p,FAILED);
+          goto failed;
+        case ES_NOFIX:
+          // Find next, if possible
+          if (p->u.med != 0) {
+            GECODE_STATUS_TRACE(p,NOFIX);
+          t_unstable:
+            // There is at least one propagator in a queue
+            do {
+              assert(pc.p.active >= &pc.p.queue[0]);
+              // First propagator or link back to queue
+              ActorLink* fst = pc.p.active->next();
+              if (pc.p.active != fst) {
+                p = Propagator::cast(fst);
+                goto t_execute;
+              }
+              pc.p.active--;
+            } while (true);
+            GECODE_NEVER;
+          }
+          // Fall through
+        case ES_FIX:
+          GECODE_STATUS_TRACE(p,FIX);
+        t_put_into_idle:
+          // Clear med
+          p->u.med = 0;
+          // Put into idle queue
+          p->unlink(); pl.head(p);
+        t_stable_or_unstable:
+          // There might be a propagator in the queue
+          do {
+            assert(pc.p.active >= &pc.p.queue[0]);
+            // First propagator or link back to queue
+            ActorLink* fst = pc.p.active->next();
+            if (pc.p.active != fst) {
+              p = Propagator::cast(fst);
+              goto t_execute;
+            }
+          } while (--pc.p.active >= &pc.p.queue[0]);
+          assert(pc.p.active < &pc.p.queue[0]);
+          goto t_stable;
+        case __ES_SUBSUMED:
+          GECODE_STATUS_TRACE(NULL,SUBSUMED);
+          p->unlink(); rfree(p,p->u.size);
+          goto t_stable_or_unstable;
+        case __ES_PARTIAL:
+          GECODE_STATUS_TRACE(p,NOFIX);
+          // Schedule propagator with specified propagator events
+          assert(p->u.med != 0);
+          enqueue(p);
+          goto t_unstable;
+        default:
+          GECODE_NEVER;
+        }
+      t_stable:
+        pc.p.vti.other();
+#undef GECODE_STATUS_TRACE
       }
     }
-  stable:
+
     /*
      * Find the next brancher that has still alternatives left
      *
@@ -347,18 +465,37 @@ namespace Gecode {
     while (b_status != Brancher::cast(&bl))
       if (b_status->status(*this)) {
         // Brancher still has choices to generate
-        s = SS_BRANCH; goto exit;
+        return SS_BRANCH;
       } else {
         // Brancher is exhausted
         b_status = Brancher::cast(b_status->next());
       }
     // No brancher with alternatives left, space is solved
-    s = SS_SOLVED;
-  exit:
-    stat.wmp = (wmp() > 0U);
-    if (wmp() == 1U) 
-      wmp(0U);
-    return s;
+    return SS_SOLVED;
+
+    // Process failure
+  failed:
+    // Count failure
+    gpi.fail(p->gpi());
+    // Mark as failed
+    fail();
+    // Propagate top priority propagators
+    ActorLink* e = &pc.p.queue[PropCost::AC_RECORD];
+    for (ActorLink* a = e->next(); a != e; a = a->next()) {
+      Propagator* top = Propagator::cast(a);
+      // Keep old modification event delta
+      ModEventDelta top_med_o = top->u.med;
+      // Clear med but leave propagator in queue
+      top->u.med = 0;
+      switch (top->propagate(*this,top_med_o)) {
+      case ES_FIX:
+      case __ES_SUBSUMED:
+        break;
+      default:
+        GECODE_NEVER;
+      }
+    }
+    return SS_FAILED;
   }
 
 
@@ -369,7 +506,7 @@ namespace Gecode {
     if (failed() || (b_status == Brancher::cast(&bl))) {
       // There are no more choices to be generated
       // Delete all branchers
-      Brancher* b = Brancher::cast(bl.next()); 
+      Brancher* b = Brancher::cast(bl.next());
       while (b != Brancher::cast(&bl)) {
         Brancher* d = b;
         b = Brancher::cast(b->next());
@@ -413,10 +550,24 @@ namespace Gecode {
       throw SpaceIllegalAlternative("Space::commit");
     if (failed())
       return;
-    if (Brancher* b = brancher(c._id)) {
+    if (Brancher* b = brancher(c.bid)) {
       // There is a matching brancher
-      if (b->commit(*this,c,a) == ES_FAILED)
-        fail();
+      if (pc.p.bid_sc & sc_trace) {
+        TraceRecorder* tr = findtr();
+        if ((tr != NULL) && (tr->events() & TE_COMMIT) &&
+            tr->filter()(b->group())) {
+          CommitTraceInfo cti(*b,c,a);
+          tr->tracer()._commit(*this,cti);
+        }
+        pc.p.vti.brancher(*b);
+        ExecStatus es = b->commit(*this,c,a);
+        pc.p.vti.other();
+        if (es == ES_FAILED)
+          fail();
+      } else {
+        if (b->commit(*this,c,a) == ES_FAILED)
+          fail();
+      }
     } else {
       // There is no matching brancher!
       throw SpaceNoBrancher("Space::commit");
@@ -429,10 +580,24 @@ namespace Gecode {
       throw SpaceIllegalAlternative("Space::commit");
     if (failed())
       return;
-    if (Brancher* b = brancher(c._id)) {
+    if (Brancher* b = brancher(c.bid)) {
       // There is a matching brancher
-      if (b->commit(*this,c,a) == ES_FAILED)
-        fail();
+      if (pc.p.bid_sc & sc_trace) {
+        TraceRecorder* tr = findtr();
+        if ((tr != NULL) && (tr->events() & TE_COMMIT) &&
+            tr->filter()(b->group())) {
+          CommitTraceInfo cti(*b,c,a);
+          tr->tracer()._commit(*this,cti);
+        }
+        pc.p.vti.brancher(*b);
+        ExecStatus es = b->commit(*this,c,a);
+        pc.p.vti.other();
+        if (es == ES_FAILED)
+          fail();
+      } else {
+        if (b->commit(*this,c,a) == ES_FAILED)
+          fail();
+      }
     }
   }
 
@@ -442,7 +607,7 @@ namespace Gecode {
       throw SpaceIllegalAlternative("Space::ngl");
     if (failed())
       return NULL;
-    if (Brancher* b = brancher(c._id)) {
+    if (Brancher* b = brancher(c.bid)) {
       // There is a matching brancher
       return b->ngl(*this,c,a);
     } else {
@@ -456,7 +621,7 @@ namespace Gecode {
       throw SpaceIllegalAlternative("Space::print");
     if (failed())
       return;
-    if (Brancher* b = const_cast<Space&>(*this).brancher(c._id)) {
+    if (Brancher* b = const_cast<Space&>(*this).brancher(c.bid)) {
       // There is a matching brancher
       b->print(*this,c,a,o);
     } else {
@@ -469,23 +634,15 @@ namespace Gecode {
   Space::kill_brancher(unsigned int id) {
     if (failed())
       return;
-    for (Brancher* b = Brancher::cast(bl.next()); 
+    for (Brancher* b = Brancher::cast(bl.next());
          b != Brancher::cast(&bl); b = Brancher::cast(b->next()))
       if (b->id() == id) {
-        // Make sure that neither b_status nor b_commit does not point to b
-        if (b_commit == b)
-          b_commit = Brancher::cast(b->next());
-        if (b_status == b)
-          b_status = Brancher::cast(b->next());
-        b->unlink();
-        rfree(b,b->dispose(*this));
+        kill(*b);
         return;
       }
   }
 
 
-
-
   /*
    * Space cloning
    *
@@ -498,11 +655,10 @@ namespace Gecode {
    *
    */
   Space::Space(bool share, Space& s)
-    : sm(s.sm->copy(share)), 
+    : sm(s.sm->copy(share)),
       mm(sm,s.mm,s.pc.p.n_sub*sizeof(Propagator**)),
-      gafc(s.gafc),
-      d_fst(&Actor::sentinel),
-      _wmp_afc(s._wmp_afc) {
+      gpi(s.gpi),
+      d_fst(&Actor::sentinel) {
 #ifdef GECODE_HAS_VAR_DISPOSE
     for (int i=0; i<AllVarConf::idx_d; i++)
       _vars_d[i] = NULL;
@@ -554,14 +710,14 @@ namespace Gecode {
   }
 
   Space*
-  Space::_clone(bool share) {
+  Space::_clone(bool share_data, bool share_info) {
     if (failed())
       throw SpaceFailed("Space::clone");
     if (!stable())
       throw SpaceNotStable("Space::clone");
 
     // Copy all data structures (which in turn will invoke the constructor)
-    Space* c = copy(share);
+    Space* c = copy(share_data);
 
     if (c->d_fst != &Actor::sentinel)
       throw SpaceNotCloned("Space::clone");
@@ -578,8 +734,11 @@ namespace Gecode {
         c->d_cur = c->d_fst;
         c->d_lst = c->d_fst+n+1;
         for (Actor** d_fst_iter = d_fst; d_fst_iter != d_cur; d_fst_iter++) {
-          if ((*d_fst_iter)->prev())
-            *(c->d_cur++) = Actor::cast((*d_fst_iter)->prev());
+          ptrdiff_t m;
+          Actor* a = static_cast<Actor*>(Support::ptrsplit(*d_fst_iter,m));
+          if (a->prev())
+            *(c->d_cur++) = Actor::cast(static_cast<ActorLink*>
+                                        (Support::ptrjoin(a->prev(),m)));
         }
       }
     }
@@ -636,8 +795,23 @@ namespace Gecode {
     for (int i=0; i<=PropCost::AC_MAX; i++)
       c->pc.p.queue[i].init();
     // Copy propagation only data
-    c->pc.p.n_sub = pc.p.n_sub;
-    c->pc.p.branch_id = pc.p.branch_id;
+    c->pc.p.n_sub  = pc.p.n_sub;
+    c->pc.p.bid_sc = pc.p.bid_sc;
+
+    if (!share_info) {
+      // Re-allocate afc information
+      for (ActorLink* c_a = c->pl.next(); c_a != &c->pl; c_a = c_a->next()) {
+        Propagator* p = Propagator::cast(c_a);
+        GPI::Info* gpi = c->gpi.allocate(p->gpi().gid);
+        if (p->disabled())
+          p->gpi_disabled = Support::mark(gpi);
+        else
+          p->gpi_disabled = gpi;
+      }
+    }
+    // Reset execution information
+    c->pc.p.vti.other(); pc.p.vti.other();
+
     return c;
   }
 
@@ -646,19 +820,29 @@ namespace Gecode {
   }
 
   bool
-  Space::master(const CRI& cri) {
-    if (cri.last() != NULL)
-      constrain(*cri.last());
-    cri.nogoods().post(*this);
-    // Perform a restart even if a solution has been found
-    return true;
+  Space::master(const MetaInfo& mi) {
+    switch (mi.type()) {
+    case MetaInfo::RESTART:
+      if (mi.last() != NULL)
+        constrain(*mi.last());
+      mi.nogoods().post(*this);
+      // Perform a restart even if a solution has been found
+      return true;
+    case MetaInfo::PORTFOLIO:
+      // Kill all branchers
+      BrancherGroup::all.kill(*this);
+      return true;
+    default: GECODE_NEVER;
+      return true;
+    }
   }
 
   bool
-  Space::slave(const CRI&) {
+  Space::slave(const MetaInfo&) {
     return true;
   }
 
+
   void
   LocalObject::fwdcopy(Space& home, bool share) {
     ActorLink::cast(this)->prev(copy(home,share));
@@ -671,29 +855,167 @@ namespace Gecode {
     e << id();
   }
 
-  void
-  Space::afc_decay(double d) {
-    afc_enable();
-    // Commit outstanding decay operations
-    if (gafc.decay() != 1.0)
-      for (Propagators p(*this); p(); ++p)
-        (void) gafc.afc(p.propagator().gafc);
-    gafc.decay(d);
-  }
-
-  void
-  Space::afc_set(double a) {
-    afc_enable();
-    for (Propagators p(*this); p(); ++p)
-      gafc.set(p.propagator().gafc,a);
-  }
-
-
   bool
   NGL::notice(void) const {
     return false;
   }
 
+  NGL::~NGL(void) {
+  }
+
+
+  /*
+   * Groups
+   */
+
+  Group Group::all(GROUPID_ALL);
+  Group Group::def(GROUPID_DEF);
+
+  PropagatorGroup PropagatorGroup::all(GROUPID_ALL);
+  PropagatorGroup PropagatorGroup::def(GROUPID_DEF);
+
+  BrancherGroup BrancherGroup::all(GROUPID_ALL);
+  BrancherGroup BrancherGroup::def(GROUPID_DEF);
+
+  unsigned int Group::next = GROUPID_DEF+1;
+  Support::Mutex Group::m;
+
+
+  Group::Group(void) {
+    m.acquire();
+    gid = next++;
+    m.release();
+    if (gid == GROUPID_MAX)
+      throw TooManyGroups("Group::Group");
+  }
+
+
+  PropagatorGroup&
+  PropagatorGroup::move(Space& home, PropagatorGroup g) {
+    if ((id() != GROUPID_ALL) && (id() != g.id()))
+      for (Space::Propagators ps(home); ps(); ++ps)
+        if (g.in(ps.propagator().group()))
+          ps.propagator().group(*this);
+    return *this;
+  }
+
+  PropagatorGroup&
+  PropagatorGroup::move(Space& home, unsigned int pid) {
+    if (id() == GROUPID_ALL)
+      return *this;
+    for (Space::Propagators ps(home); ps(); ++ps)
+      if (ps.propagator().id() == pid) {
+        ps.propagator().group(*this);
+        return *this;
+      }
+    throw UnknownPropagator("PropagatorGroup::move");
+    GECODE_NEVER;
+    return *this;
+  }
+
+  unsigned int
+  PropagatorGroup::size(Space& home) const {
+    if (home.failed())
+      return 0;
+    unsigned int n=0;
+    for (Space::Propagators ps(home); ps(); ++ps)
+      if (in(ps.propagator().group()))
+        n++;
+    return n;
+  }
+
+  void
+  PropagatorGroup::kill(Space& home) {
+    if (home.failed())
+      return;
+    Space::Propagators ps(home);
+    while (ps()) {
+      Propagator& p = ps.propagator();
+      ++ps;
+      if (in(p.group()))
+        home.kill(p);
+    }
+  }
+
+  void
+  PropagatorGroup::disable(Space& home) {
+    if (home.failed())
+      return;
+    for (Space::Propagators ps(home); ps(); ++ps)
+      if (in(ps.propagator().group()))
+        ps.propagator().disable(home);
+  }
+
+  void
+  PropagatorGroup::enable(Space& home, bool s) {
+    if (home.failed())
+      return;
+    if (s) {
+      Space::Propagators ps(home);
+      while (ps()) {
+        Propagator& p = ps.propagator();
+        ++ps;
+        if (in(p.group())) {
+          p.enable(home);
+          p.reschedule(home);
+        }
+      }
+    } else {
+      for (Space::Propagators ps(home); ps(); ++ps)
+        if (in(ps.propagator().group()))
+          ps.propagator().enable(home);
+    }
+  }
+
+
+  BrancherGroup&
+  BrancherGroup::move(Space& home, BrancherGroup g) {
+    if ((id() != GROUPID_ALL) && (id() != g.id()))
+      for (Space::Branchers bs(home); bs(); ++bs)
+        if (g.in(bs.brancher().group()))
+          bs.brancher().group(*this);
+    return *this;
+  }
+
+  BrancherGroup&
+  BrancherGroup::move(Space& home, unsigned int bid) {
+    if (id() == GROUPID_ALL)
+      return *this;
+    for (Space::Branchers bs(home); bs(); ++bs)
+      if (bs.brancher().id() == bid) {
+        bs.brancher().group(*this);
+        return *this;
+      }
+    throw UnknownBrancher("BrancherGroup::move");
+    GECODE_NEVER;
+    return *this;
+  }
+
+  unsigned int
+  BrancherGroup::size(Space& home) const {
+    if (home.failed())
+      return 0;
+    unsigned int n=0;
+    for (Space::Branchers bs(home); bs(); ++bs)
+      if (in(bs.brancher().group()))
+        n++;
+    return n;
+  }
+
+  void
+  BrancherGroup::kill(Space& home) {
+    if (home.failed())
+      return;
+    Space::Branchers bs(home);
+    while (bs()) {
+      Brancher& b = bs.brancher();
+      ++bs;
+      if (in(b.group()))
+        home.kill(b);
+    }
+  }
+
+
 }
 
 // STATISTICS: kernel-core
