@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2013-05-02 17:10:16 +0200 (Thu, 02 May 2013) $ by $Author: schulte $
- *     $Revision: 13603 $
+ *     $Date: 2017-03-17 23:04:57 +0100 (Fri, 17 Mar 2017) $ by $Author: schulte $
+ *     $Revision: 15597 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -45,143 +45,119 @@ namespace Gecode {
   //@{
 
   /// %Exception: Operation on failed space invoked
-  class GECODE_VTABLE_EXPORT SpaceFailed : public Exception {
+  class GECODE_KERNEL_EXPORT SpaceFailed : public Exception {
   public:
     /// Initialize with location \a l
     SpaceFailed(const char* l);
   };
 
   /// %Exception: Operation on not stable space invoked
-  class GECODE_VTABLE_EXPORT SpaceNotStable : public Exception {
+  class GECODE_KERNEL_EXPORT SpaceNotStable : public Exception {
   public:
     /// Initialize with location \a l
     SpaceNotStable(const char* l);
   };
 
   /// %Exception: Copy constructor did not call base class copy constructor
-  class GECODE_VTABLE_EXPORT SpaceNotCloned : public Exception {
+  class GECODE_KERNEL_EXPORT SpaceNotCloned : public Exception {
   public:
     /// Initialize with location \a l
     SpaceNotCloned(const char* l);
   };
 
   /// %Exception: Commit when no brancher present
-  class GECODE_VTABLE_EXPORT SpaceNoBrancher : public Exception {
+  class GECODE_KERNEL_EXPORT SpaceNoBrancher : public Exception {
   public:
     /// Initialize with location \a l
     SpaceNoBrancher(const char* l);
   };
 
   /// %Exception: Commit with illegal alternative
-  class GECODE_VTABLE_EXPORT SpaceIllegalAlternative : public Exception {
+  class GECODE_KERNEL_EXPORT SpaceIllegalAlternative : public Exception {
   public:
     /// Initialize with location \a l
     SpaceIllegalAlternative(const char* l);
   };
 
+  /// %Exception: too many groups
+  class GECODE_KERNEL_EXPORT TooManyGroups : public Exception {
+  public:
+    /// Initialize with location \a l
+    TooManyGroups(const char* l);
+  };
+
+  /// %Exception: unknown propagator
+  class GECODE_KERNEL_EXPORT UnknownPropagator : public Exception {
+  public:
+    /// Initialize with location \a l
+    UnknownPropagator(const char* l);
+  };
+
   /// %Exception: too many branchers
-  class GECODE_VTABLE_EXPORT TooManyBranchers : public Exception {
+  class GECODE_KERNEL_EXPORT TooManyBranchers : public Exception {
   public:
     /// Initialize with location \a l
     TooManyBranchers(const char* l);
   };
 
+  /// %Exception: unknown brancher
+  class GECODE_KERNEL_EXPORT UnknownBrancher : public Exception {
+  public:
+    /// Initialize with location \a l
+    UnknownBrancher(const char* l);
+  };
+
   /// %Exception: illegal decay factor
-  class GECODE_VTABLE_EXPORT IllegalDecay : public Exception {
+  class GECODE_KERNEL_EXPORT IllegalDecay : public Exception {
   public:
     /// Initialize with location \a l
     IllegalDecay(const char* l);
   };
 
+  /// %Exception: invalid function
+  class GECODE_KERNEL_EXPORT InvalidFunction : public Exception {
+  public:
+    /// Initialize with location \a l
+    InvalidFunction(const char* l);
+  };
+
   /// %Exception: uninitialized AFC
-  class GECODE_VTABLE_EXPORT UninitializedAFC : public Exception {
+  class GECODE_KERNEL_EXPORT UninitializedAFC : public Exception {
   public:
     /// Initialize with location \a l
     UninitializedAFC(const char* l);
   };
 
-  /// %Exception: uninitialized activity
-  class GECODE_VTABLE_EXPORT UninitializedActivity : public Exception {
+  /// %Exception: uninitialized action
+  class GECODE_KERNEL_EXPORT UninitializedAction : public Exception {
   public:
     /// Initialize with location \a l
-    UninitializedActivity(const char* l);
+    UninitializedAction(const char* l);
+  };
+
+  /// %Exception: uninitialized action
+  class GECODE_KERNEL_EXPORT UninitializedCHB : public Exception {
+  public:
+    /// Initialize with location \a l
+    UninitializedCHB(const char* l);
   };
 
   /// %Exception: uninitialized random number generator
-  class GECODE_VTABLE_EXPORT UninitializedRnd : public Exception {
+  class GECODE_KERNEL_EXPORT UninitializedRnd : public Exception {
   public:
     /// Initialize with location \a l
     UninitializedRnd(const char* l);
   };
 
-  /// %Exception: AFC has wrong arity
-  class GECODE_VTABLE_EXPORT AFCWrongArity : public Exception {
+  /// %Exception: action has wrong arity
+  class GECODE_KERNEL_EXPORT MoreThanOneTracer : public Exception {
   public:
     /// Initialize with location \a l
-    AFCWrongArity(const char* l);
-  };
-
-  /// %Exception: activity has wrong arity
-  class GECODE_VTABLE_EXPORT ActivityWrongArity : public Exception {
-  public:
-    /// Initialize with location \a l
-    ActivityWrongArity(const char* l);
+    MoreThanOneTracer(const char* l);
   };
 
   //@}
 
-  /*
-   * Classes for exceptions raised by kernel
-   *
-   */
-  inline
-  SpaceFailed::SpaceFailed(const char* l)
-    : Exception(l,"Attempt to invoke operation on failed space") {}
-
-  inline
-  SpaceNotStable::SpaceNotStable(const char* l)
-    : Exception(l,"Attempt to invoke operation on not stable space") {}
-
-  inline
-  SpaceNotCloned::SpaceNotCloned(const char* l)
-    : Exception(l,"Copy constructor of space did not call base class copy constructor") {}
-
-  inline
-  SpaceNoBrancher::SpaceNoBrancher(const char* l)
-    : Exception(l,"Attempt to commit with no brancher") {}
-
-  inline
-  SpaceIllegalAlternative::SpaceIllegalAlternative(const char* l)
-    : Exception(l,"Attempt to commit with illegal alternative") {}
-
-  inline
-  TooManyBranchers::TooManyBranchers(const char* l)
-    : Exception(l,"Too many branchers created") {}
-
-  inline
-  UninitializedRnd::UninitializedRnd(const char* l)
-    : Exception(l,"Uninitialized random generator for branching") {}
-
-  inline
-  IllegalDecay::IllegalDecay(const char* l)
-    : Exception(l,"Illegal decay factor") {}
-
-  inline
-  UninitializedAFC::UninitializedAFC(const char* l)
-    : Exception(l,"Uninitialized AFC information for branching") {}
-
-  inline
-  UninitializedActivity::UninitializedActivity(const char* l)
-    : Exception(l,"Uninitialized activity information for branching") {}
-
-  inline
-  AFCWrongArity::AFCWrongArity(const char* l)
-    : Exception(l,"AFC has wrong number of variables") {}
-
-  inline
-  ActivityWrongArity::ActivityWrongArity(const char* l)
-    : Exception(l,"Activity has wrong number of variables") {}
-
 }
 
 // STATISTICS: kernel-other
