@@ -9,8 +9,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2016-06-29 17:28:17 +0200 (Wed, 29 Jun 2016) $ by $Author: schulte $
+ *     $Revision: 15137 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -70,6 +70,8 @@ namespace Gecode {
   public:
     /// Cost function (defined as PC_UNARY_LO)
     virtual PropCost cost(const Space& home, const ModEventDelta& med) const;
+    /// Schedule function
+    virtual void reschedule(Space& home);
     /// Delete propagator and return its size
     virtual size_t dispose(Space& home);
   };
@@ -98,6 +100,8 @@ namespace Gecode {
   public:
     /// Cost function (defined as low binary)
     virtual PropCost cost(const Space& home, const ModEventDelta& med) const;
+    /// Schedule function
+    virtual void reschedule(Space& home);
     /// Delete propagator and return its size
     virtual size_t dispose(Space& home);
   };
@@ -126,6 +130,8 @@ namespace Gecode {
   public:
     /// Cost function (defined as low ternary)
     virtual PropCost cost(const Space& home, const ModEventDelta& med) const;
+    /// Schedule function
+    virtual void reschedule(Space& home);
     /// Delete propagator and return its size
     virtual size_t dispose(Space& home);
   };
@@ -154,6 +160,8 @@ namespace Gecode {
   public:
     /// Cost function (defined as low linear)
     virtual PropCost cost(const Space& home, const ModEventDelta& med) const;
+    /// Schedule function
+    virtual void reschedule(Space& home);
     /// Delete propagator and return its size
     virtual size_t dispose(Space& home);
   };
@@ -185,6 +193,8 @@ namespace Gecode {
   public:
     /// Cost function (defined as low linear)
     virtual PropCost cost(const Space& home, const ModEventDelta& med) const;
+    /// Schedule function
+    virtual void reschedule(Space& home);
     /// Delete propagator and return its size
     virtual size_t dispose(Space& home);
   };
@@ -216,6 +226,8 @@ namespace Gecode {
   public:
     /// Cost function (defined as low binary)
     virtual PropCost cost(const Space& home, const ModEventDelta& med) const;
+    /// Schedule function
+    virtual void reschedule(Space& home);
     /// Delete propagator and return its size
     virtual size_t dispose(Space& home);
   };
@@ -250,6 +262,8 @@ namespace Gecode {
   public:
     /// Cost function (defined as low ternary)
     virtual PropCost cost(const Space& home, const ModEventDelta& med) const;
+    /// Schedule function
+    virtual void reschedule(Space& home);
     /// Delete propagator and return its size
     virtual size_t dispose(Space& home);
   };
@@ -281,6 +295,8 @@ namespace Gecode {
   public:
     /// Cost function (defined as low linear)
     virtual PropCost cost(const Space& home, const ModEventDelta& med) const;
+    /// Schedule function
+    virtual void reschedule(Space& home);
     /// Delete propagator and return its size
     virtual size_t dispose(Space& home);
   };
@@ -321,6 +337,13 @@ namespace Gecode {
     return PropCost::unary(PropCost::LO);
   }
 
+  template<class View, PropCond pc>
+  void
+  UnaryPropagator<View,pc>::reschedule(Space& home) {
+    if (pc != PC_GEN_NONE)
+      x0.reschedule(home,*this,pc);
+  }
+
   template<class View, PropCond pc>
   forceinline size_t
   UnaryPropagator<View,pc>::dispose(Space& home) {
@@ -369,6 +392,15 @@ namespace Gecode {
     return PropCost::binary(PropCost::LO);
   }
 
+  template<class View, PropCond pc>
+  void
+  BinaryPropagator<View,pc>::reschedule(Space& home) {
+    if (pc != PC_GEN_NONE) {
+      x0.reschedule(home,*this,pc);
+      x1.reschedule(home,*this,pc);
+    }
+  }
+
   template<class View, PropCond pc>
   forceinline size_t
   BinaryPropagator<View,pc>::dispose(Space& home) {
@@ -422,6 +454,16 @@ namespace Gecode {
     return PropCost::ternary(PropCost::LO);;
   }
 
+  template<class View, PropCond pc>
+  void
+  TernaryPropagator<View,pc>::reschedule(Space& home) {
+    if (pc != PC_GEN_NONE) {
+      x0.reschedule(home,*this,pc);
+      x1.reschedule(home,*this,pc);
+      x2.reschedule(home,*this,pc);
+    }
+  }
+
   template<class View, PropCond pc>
   forceinline size_t
   TernaryPropagator<View,pc>::dispose(Space& home) {
@@ -469,6 +511,13 @@ namespace Gecode {
     return PropCost::linear(PropCost::LO,x.size());
   }
 
+  template<class View, PropCond pc>
+  void
+  NaryPropagator<View,pc>::reschedule(Space& home) {
+    if (pc != PC_GEN_NONE)
+      x.reschedule(home,*this,pc);
+  }
+
   template<class View, PropCond pc>
   forceinline size_t
   NaryPropagator<View,pc>::dispose(Space& home) {
@@ -517,6 +566,15 @@ namespace Gecode {
     return PropCost::linear(PropCost::LO,x.size()+1);
   }
 
+  template<class View, PropCond pc>
+  void
+  NaryOnePropagator<View,pc>::reschedule(Space& home) {
+    if (pc != PC_GEN_NONE) {
+      x.reschedule(home,*this,pc);
+      y.reschedule(home,*this,pc);
+    }
+  }
+
   template<class View, PropCond pc>
   forceinline size_t
   NaryOnePropagator<View,pc>::dispose(Space& home) {
@@ -568,6 +626,15 @@ namespace Gecode {
     return PropCost::binary(PropCost::LO);
   }
 
+  template<class View0, PropCond pc0, class View1, PropCond pc1>
+  void
+  MixBinaryPropagator<View0,pc0,View1,pc1>::reschedule(Space& home) {
+    if (pc0 != PC_GEN_NONE)
+      x0.reschedule(home,*this,pc0);
+    if (pc1 != PC_GEN_NONE)
+      x1.reschedule(home,*this,pc1);
+  }
+
   template<class View0, PropCond pc0, class View1, PropCond pc1>
   forceinline size_t
   MixBinaryPropagator<View0,pc0,View1,pc1>::dispose(Space& home) {
@@ -629,6 +696,18 @@ namespace Gecode {
     return PropCost::ternary(PropCost::LO);
   }
 
+  template<class View0, PropCond pc0, class View1, PropCond pc1,
+            class View2, PropCond pc2>
+  void
+  MixTernaryPropagator<View0,pc0,View1,pc1,View2,pc2>::reschedule(Space& home) {
+    if (pc0 != PC_GEN_NONE)
+      x0.reschedule(home,*this,pc0);
+    if (pc1 != PC_GEN_NONE)
+      x1.reschedule(home,*this,pc1);
+    if (pc2 != PC_GEN_NONE)
+      x2.reschedule(home,*this,pc2);
+  }
+
   template<class View0, PropCond pc0, class View1, PropCond pc1,
             class View2, PropCond pc2>
   forceinline size_t
@@ -683,6 +762,15 @@ namespace Gecode {
     return PropCost::linear(PropCost::LO,x.size()+1);
   }
 
+  template<class View0, PropCond pc0, class View1, PropCond pc1>
+  void
+  MixNaryOnePropagator<View0,pc0,View1,pc1>::reschedule(Space& home) {
+    if (pc0 != PC_GEN_NONE)
+      x.reschedule(home,*this,pc0);
+    if (pc1 != PC_GEN_NONE)
+      y.reschedule(home,*this,pc1);
+  }
+
   template<class View0, PropCond pc0, class View1, PropCond pc1>
   forceinline size_t
   MixNaryOnePropagator<View0,pc0,View1,pc1>::dispose(Space& home) {
