@@ -7,8 +7,8 @@
  *     Christian Schulte, 2008
  *
  *  Last modified:
- *     $Date: 2013-02-18 21:53:58 +0100 (Mon, 18 Feb 2013) $ by $Author: schulte $
- *     $Revision: 13310 $
+ *     $Date: 2017-02-23 06:10:29 +0100 (Thu, 23 Feb 2017) $ by $Author: schulte $
+ *     $Revision: 15476 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -66,7 +66,7 @@ namespace Gecode {
     /// Return degree (number of subscribed propagators and advisors)
     unsigned int degree(void) const;
     /// Return accumulated failure count
-    double afc(const Space& home) const;
+    double afc(void) const;
     //@}
 
     /// \name Domain tests
@@ -115,8 +115,8 @@ namespace Gecode {
   }
   template<class VarImp>
   forceinline double
-  VarImpVar<VarImp>::afc(const Space& home) const {
-    return x->afc(home);
+  VarImpVar<VarImp>::afc(void) const {
+    return x->afc();
   }
   template<class VarImp>
   forceinline bool
