@@ -7,8 +7,8 @@
  *     Christian Schulte, 2005
  *
  *  Last modified:
- *     $Date: 2013-02-18 21:53:58 +0100 (Mon, 18 Feb 2013) $ by $Author: schulte $
- *     $Revision: 13310 $
+ *     $Date: 2017-03-09 09:51:58 +0100 (Thu, 09 Mar 2017) $ by $Author: schulte $
+ *     $Revision: 15565 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -53,7 +53,7 @@ namespace Gecode {
     /// Return degree (number of subscribed propagators and advisors)
     unsigned int degree(void) const;
     /// Return accumulated failure count
-    double afc(const Space& home) const;
+    double afc(void) const;
     /// Return whether this view is derived from a VarImpView
     static bool varderived(void);
     /// Return dummy variable implementation of view
@@ -88,10 +88,16 @@ namespace Gecode {
     void subscribe(Space& home, Propagator& p, PropCond pc, bool schedule=true);
     /// Cancel subscription of propagator \a p with propagation condition \a pc to view
     void cancel(Space& home, Propagator& p, PropCond pc);
-    /// Subscribe advisor \a a to view
-    void subscribe(Space& home, Advisor& a);
+    /// Re-schedule propagator \a p with propagation condition \a pc
+    void reschedule(Space& home, Propagator& p, PropCond pc);
+    /** \brief Subscribe advisor \a a to view
+     *
+     * If \a fail is true, run the advisor also on failure. This
+     * feature is undocumented.
+     */
+    void subscribe(Space& home, Advisor& a, bool fail=false);
     /// Cancel subscription of advisor \a a
-    void cancel(Space& home, Advisor& a);
+    void cancel(Space& home, Advisor& a, bool fail=false);
     //@}
 
     /// \name Delta information for advisors
@@ -127,6 +133,8 @@ namespace Gecode {
     VarImpView(void);
     /// Initialize with variable implementation \a y
     VarImpView(VarImpType* y);
+    /// Set variable implementation to \a y
+    void varimp(VarImpType* y);
   public:
     /// \name Generic view information
     //@{
@@ -137,7 +145,7 @@ namespace Gecode {
     /// Return degree (number of subscribed propagators and advisors)
     unsigned int degree(void) const;
     /// Return accumulated failure count
-    double afc(const Space& home) const;
+    double afc(void) const;
     //@}
 
     /// \name Domain tests
@@ -168,10 +176,16 @@ namespace Gecode {
     void subscribe(Space& home, Propagator& p, PropCond pc, bool schedule=true);
     /// Cancel subscription of propagator \a p with propagation condition \a pc to view
     void cancel(Space& home, Propagator& p, PropCond pc);
-    /// Subscribe advisor \a a to view
-    void subscribe(Space& home, Advisor& a);
+    /// Re-schedule propagator \a p with propagation condition \a pc
+    void reschedule(Space& home, Propagator& p, PropCond pc);
+    /** \brief Subscribe advisor \a a to view
+     *
+     * If \a fail is true, run the advisor also on failure. This
+     * feature is undocumented.
+     */
+    void subscribe(Space& home, Advisor& a, bool fail=false);
     /// Cancel subscription of advisor \a a
-    void cancel(Space& home, Advisor& a);
+    void cancel(Space& home, Advisor& a, bool fail=false);
     //@}
 
     /// \name Delta information for advisors
@@ -216,9 +230,9 @@ namespace Gecode {
     View x;
     /// Default constructor
     DerivedView(void);
+  public:
     /// Initialize with view \a y
     DerivedView(const View& y);
-  public:
     /// \name Generic view information
     //@{
     /// Return whether this view is derived from a VarImpView
@@ -230,7 +244,7 @@ namespace Gecode {
     /// Return degree (number of subscribed propagators)
     unsigned int degree(void) const;
     /// Return accumulated failure count
-    double afc(const Space& home) const;
+    double afc(void) const;
     //@}
 
     /// \name Domain tests
@@ -261,10 +275,16 @@ namespace Gecode {
     void subscribe(Space& home, Propagator& p, PropCond pc, bool schedule=true);
     /// Cancel subscription of propagator \a p with propagation condition \a pc to view
     void cancel(Space& home, Propagator& p, PropCond pc);
-    /// Subscribe advisor \a a to view
-    void subscribe(Space& home, Advisor& a);
+    /// Re-schedule propagator \a p with propagation condition \a pc
+    void reschedule(Space& home, Propagator& p, PropCond pc);
+    /** \brief Subscribe advisor \a a to view
+     *
+     * If \a fail is true, run the advisor also on failure. This
+     * feature is undocumented.
+     */
+    void subscribe(Space& home, Advisor& a, bool fail=false);
     /// Cancel subscription of advisor \a a
-    void cancel(Space& home, Advisor& a);
+    void cancel(Space& home, Advisor& a, bool fail=false);
     //@}
 
     /// \name Delta information for advisors
@@ -348,7 +368,7 @@ namespace Gecode {
   }
   template<class View>
   forceinline double
-  ConstView<View>::afc(const Space&) const {
+  ConstView<View>::afc(void) const {
     return 0.0;
   }
   template<class View>
@@ -368,7 +388,7 @@ namespace Gecode {
   }
   template<class View>
   forceinline void
-  ConstView<View>::subscribe(Space& home, Propagator& p, PropCond, 
+  ConstView<View>::subscribe(Space& home, Propagator& p, PropCond,
                              bool schedule) {
     if (schedule)
       View::schedule(home,p,ME_GEN_ASSIGNED);
@@ -379,11 +399,16 @@ namespace Gecode {
   }
   template<class View>
   forceinline void
-  ConstView<View>::subscribe(Space&, Advisor&) {
+  ConstView<View>::reschedule(Space& home, Propagator& p, PropCond) {
+    View::schedule(home,p,ME_GEN_ASSIGNED);
   }
   template<class View>
   forceinline void
-  ConstView<View>::cancel(Space&, Advisor&) {
+  ConstView<View>::subscribe(Space&, Advisor&, bool) {
+  }
+  template<class View>
+  forceinline void
+  ConstView<View>::cancel(Space&, Advisor&, bool) {
   }
   template<class View>
   forceinline void
@@ -424,6 +449,11 @@ namespace Gecode {
   VarImpView<Var>::VarImpView(VarImpType* y)
     : x(y) {}
   template<class Var>
+  forceinline void
+  VarImpView<Var>::varimp(VarImpType* y) {
+    x=y;
+  }
+  template<class Var>
   forceinline bool
   VarImpView<Var>::varderived(void) {
     return true;
@@ -433,15 +463,15 @@ namespace Gecode {
   VarImpView<Var>::varimp(void) const {
     return x;
   }
-  template<class Var>
+ template<class Var>
   forceinline unsigned int
   VarImpView<Var>::degree(void) const {
     return x->degree();
   }
   template<class Var>
   forceinline double
-  VarImpView<Var>::afc(const Space& home) const {
-    return x->afc(home);
+  VarImpView<Var>::afc(void) const {
+    return x->afc();
   }
   template<class Var>
   forceinline bool
@@ -461,13 +491,18 @@ namespace Gecode {
   }
   template<class Var>
   forceinline void
-  VarImpView<Var>::subscribe(Space& home, Advisor& a) {
-    x->subscribe(home,a);
+  VarImpView<Var>::reschedule(Space& home, Propagator& p, PropCond pc) {
+    x->reschedule(home,p,pc);
   }
   template<class Var>
   forceinline void
-  VarImpView<Var>::cancel(Space& home, Advisor& a) {
-    x->cancel(home,a);
+  VarImpView<Var>::subscribe(Space& home, Advisor& a, bool fail) {
+    x->subscribe(home,a,fail);
+  }
+  template<class Var>
+  forceinline void
+  VarImpView<Var>::cancel(Space& home, Advisor& a, bool fail) {
+    x->cancel(home,a,fail);
   }
   template<class Var>
   forceinline void
@@ -534,8 +569,8 @@ namespace Gecode {
   }
   template<class View>
   forceinline double
-  DerivedView<View>::afc(const Space& home) const {
-    return x.afc(home);
+  DerivedView<View>::afc(void) const {
+    return x.afc();
   }
   template<class View>
   forceinline bool
@@ -572,13 +607,18 @@ namespace Gecode {
   }
   template<class View>
   forceinline void
-  DerivedView<View>::subscribe(Space& home, Advisor& a) {
-    x.subscribe(home,a);
+  DerivedView<View>::reschedule(Space& home, Propagator& p, PropCond pc) {
+    x.reschedule(home,p,pc);
   }
   template<class View>
   forceinline void
-  DerivedView<View>::cancel(Space& home, Advisor& a) {
-    x.cancel(home,a);
+  DerivedView<View>::subscribe(Space& home, Advisor& a, bool fail) {
+    x.subscribe(home,a,fail);
+  }
+  template<class View>
+  forceinline void
+  DerivedView<View>::cancel(Space& home, Advisor& a, bool fail) {
+    x.cancel(home,a,fail);
   }
   template<class View>
   forceinline ModEvent
@@ -599,31 +639,31 @@ namespace Gecode {
 
   /// Test whether two views are the same
   template<class ViewA, class ViewB>
-  forceinline bool 
+  forceinline bool
   same(const ConstView<ViewA>&, const ConstView<ViewB>&) {
     return false;
   }
   /// Test whether two views are the same
   template<class Var, class View>
-  forceinline bool 
+  forceinline bool
   same(const VarImpView<Var>&, const ConstView<View>&) {
     return false;
   }
   /// Test whether two views are the same
   template<class ViewA, class ViewB>
-  forceinline bool 
+  forceinline bool
   same(const ConstView<ViewA>&, const DerivedView<ViewB>&) {
     return false;
   }
   /// Test whether two views are the same
   template<class Var, class View>
-  forceinline bool 
+  forceinline bool
   same(const VarImpView<Var>&, const DerivedView<View>&) {
     return false;
   }
   /// Test whether two views are the same
   template<class View, class Var>
-  forceinline bool 
+  forceinline bool
   same(const DerivedView<View>&, const VarImpView<Var>&) {
     return false;
   }
@@ -635,7 +675,7 @@ namespace Gecode {
   }
   /// Test whether two views are the same
   template<class ViewA, class ViewB>
-  forceinline bool 
+  forceinline bool
   same(const DerivedView<ViewA>& x, const DerivedView<ViewB>& y) {
     return same(x.base(),y.base());
   }
