@@ -11,8 +11,8 @@
  *     Vincent Barichard, 2012
  *
  *  Last modified:
- *     $Date: 2013-04-29 14:55:17 +0200 (Mon, 29 Apr 2013) $ by $Author: schulte $
- *     $Revision: 13588 $
+ *     $Date: 2016-08-08 16:24:17 +0200 (Mon, 08 Aug 2016) $ by $Author: schulte $
+ *     $Revision: 15141 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -67,7 +67,7 @@ namespace Gecode {
     SetRel rs;
 #endif
     /// Possibly a misc Boolean expression
-    MiscExpr* m;
+    Misc* m;
 
     /// Default constructor
     Node(void);
@@ -87,11 +87,11 @@ namespace Gecode {
    * Operations for nodes
    *
    */
-  BoolExpr::Node::Node(void) 
+  BoolExpr::Node::Node(void)
     : use(1), l(NULL), r(NULL), m(NULL) {}
 
-  BoolExpr::Node::~Node(void) {    
-    delete m;  
+  BoolExpr::Node::~Node(void) {
+    delete m;
   }
 
   void*
@@ -197,7 +197,7 @@ namespace Gecode {
   }
 #endif
 
-  BoolExpr::BoolExpr(BoolExpr::MiscExpr* m)
+  BoolExpr::BoolExpr(BoolExpr::Misc* m)
     : n(new Node) {
     n->same = 1;
     n->t    = NT_MISC;
@@ -217,7 +217,7 @@ namespace Gecode {
     return *this;
   }
 
-  BoolExpr::MiscExpr::~MiscExpr(void) {}
+  BoolExpr::Misc::~Misc(void) {}
 
   BoolExpr::~BoolExpr(void) {
     if (n->decrement())
@@ -261,13 +261,13 @@ namespace Gecode {
       void post(Home home, NodeType t,
                 BoolVarArgs& bp, BoolVarArgs& bn,
                 int& ip, int& in,
-                IntConLevel icl) const;
+                IntPropLevel ipl) const;
       /// Post propagators for expression
       GECODE_MINIMODEL_EXPORT
-      BoolVar expr(Home home, IntConLevel icl) const;
+      BoolVar expr(Home home, IntPropLevel ipl) const;
       /// Post propagators for relation
       GECODE_MINIMODEL_EXPORT
-      void rel(Home home, IntConLevel icl) const;
+      void rel(Home home, IntPropLevel ipl) const;
       /// Allocate memory from region
       static void* operator new(size_t s, Region& r);
       /// No-op (for exceptions)
@@ -292,7 +292,7 @@ namespace Gecode {
     }
 
     BoolVar
-    NNF::expr(Home home, IntConLevel icl) const {
+    NNF::expr(Home home, IntPropLevel ipl) const {
       if ((t == BoolExpr::NT_VAR) && !u.a.neg)
         return u.a.x->x;
       BoolVar b(home,0,1);
@@ -302,7 +302,7 @@ namespace Gecode {
         Gecode::rel(home, u.a.x->x, IRT_NQ, b);
         break;
       case BoolExpr::NT_RLIN:
-        u.a.x->rl.post(home, b, !u.a.neg, icl);
+        u.a.x->rl.post(home, b, !u.a.neg, ipl);
         break;
 #ifdef GECODE_HAS_FLOAT_VARS
       case BoolExpr::NT_RLINFLOAT:
@@ -315,13 +315,13 @@ namespace Gecode {
         break;
 #endif
       case BoolExpr::NT_MISC:
-        u.a.x->m->post(home, b, !u.a.neg, icl);
+        u.a.x->m->post(home, b, u.a.neg, ipl);
         break;
       case BoolExpr::NT_AND:
         {
           BoolVarArgs bp(p), bn(n);
           int ip=0, in=0;
-          post(home, BoolExpr::NT_AND, bp, bn, ip, in, icl);
+          post(home, BoolExpr::NT_AND, bp, bn, ip, in, ipl);
           clause(home, BOT_AND, bp, bn, b);
         }
         break;
@@ -329,7 +329,7 @@ namespace Gecode {
         {
           BoolVarArgs bp(p), bn(n);
           int ip=0, in=0;
-          post(home, BoolExpr::NT_OR, bp, bn, ip, in, icl);
+          post(home, BoolExpr::NT_OR, bp, bn, ip, in, ipl);
           clause(home, BOT_OR, bp, bn, b);
         }
         break;
@@ -341,16 +341,16 @@ namespace Gecode {
             l = u.b.l->u.a.x->x;
             if (u.b.l->u.a.neg) n = !n;
           } else {
-            l = u.b.l->expr(home,icl);
+            l = u.b.l->expr(home,ipl);
           }
           BoolVar r;
           if (u.b.r->t == BoolExpr::NT_VAR) {
             r = u.b.r->u.a.x->x;
             if (u.b.r->u.a.neg) n = !n;
           } else {
-            r = u.b.r->expr(home,icl);
+            r = u.b.r->expr(home,ipl);
           }
-          Gecode::rel(home, l, n ? BOT_XOR : BOT_EQV, r, b, icl);
+          Gecode::rel(home, l, n ? BOT_XOR : BOT_EQV, r, b, ipl);
         }
         break;
       default:
@@ -361,9 +361,9 @@ namespace Gecode {
 
     void
     NNF::post(Home home, NodeType t,
-                        BoolVarArgs& bp, BoolVarArgs& bn,
-                        int& ip, int& in,
-                        IntConLevel icl) const {
+              BoolVarArgs& bp, BoolVarArgs& bn,
+              int& ip, int& in,
+              IntPropLevel ipl) const {
       if (this->t != t) {
         switch (this->t) {
         case BoolExpr::NT_VAR:
@@ -376,7 +376,7 @@ namespace Gecode {
         case BoolExpr::NT_RLIN:
           {
             BoolVar b(home,0,1);
-            u.a.x->rl.post(home, b, !u.a.neg, icl);
+            u.a.x->rl.post(home, b, !u.a.neg, ipl);
             bp[ip++]=b;
           }
           break;
@@ -401,28 +401,28 @@ namespace Gecode {
         case BoolExpr::NT_MISC:
           {
             BoolVar b(home,0,1);
-            u.a.x->m->post(home, b, !u.a.neg, icl);
+            u.a.x->m->post(home, b, u.a.neg, ipl);
             bp[ip++]=b;
           }
-          break;      
+          break;
         default:
-          bp[ip++] = expr(home, icl);
+          bp[ip++] = expr(home, ipl);
           break;
         }
       } else {
-        u.b.l->post(home, t, bp, bn, ip, in, icl);
-        u.b.r->post(home, t, bp, bn, ip, in, icl);
+        u.b.l->post(home, t, bp, bn, ip, in, ipl);
+        u.b.r->post(home, t, bp, bn, ip, in, ipl);
       }
     }
 
     void
-    NNF::rel(Home home, IntConLevel icl) const {
+    NNF::rel(Home home, IntPropLevel ipl) const {
       switch (t) {
       case BoolExpr::NT_VAR:
         Gecode::rel(home, u.a.x->x, IRT_EQ, u.a.neg ? 0 : 1);
         break;
       case BoolExpr::NT_RLIN:
-        u.a.x->rl.post(home, !u.a.neg, icl);
+        u.a.x->rl.post(home, !u.a.neg, ipl);
         break;
 #ifdef GECODE_HAS_FLOAT_VARS
       case BoolExpr::NT_RLINFLOAT:
@@ -437,18 +437,18 @@ namespace Gecode {
       case BoolExpr::NT_MISC:
         {
           BoolVar b(home,!u.a.neg,!u.a.neg);
-          u.a.x->m->post(home, b, false, icl);
+          u.a.x->m->post(home, b, false, ipl);
         }
         break;
       case BoolExpr::NT_AND:
-        u.b.l->rel(home, icl);
-        u.b.r->rel(home, icl);
+        u.b.l->rel(home, ipl);
+        u.b.r->rel(home, ipl);
         break;
       case BoolExpr::NT_OR:
         {
           BoolVarArgs bp(p), bn(n);
           int ip=0, in=0;
-          post(home, BoolExpr::NT_OR, bp, bn, ip, in, icl);
+          post(home, BoolExpr::NT_OR, bp, bn, ip, in, ipl);
           clause(home, BOT_OR, bp, bn, 1);
         }
         break;
@@ -456,51 +456,51 @@ namespace Gecode {
         if (u.b.l->t==BoolExpr::NT_VAR &&
             u.b.r->t==BoolExpr::NT_RLIN) {
           u.b.r->u.a.x->rl.post(home, u.b.l->u.a.x->x,
-                                u.b.l->u.a.neg==u.b.r->u.a.neg, icl);
-        } else if (u.b.r->t==BoolExpr::NT_VAR && 
+                                u.b.l->u.a.neg==u.b.r->u.a.neg, ipl);
+        } else if (u.b.r->t==BoolExpr::NT_VAR &&
                    u.b.l->t==BoolExpr::NT_RLIN) {
           u.b.l->u.a.x->rl.post(home, u.b.r->u.a.x->x,
-                                u.b.l->u.a.neg==u.b.r->u.a.neg, icl);
+                                u.b.l->u.a.neg==u.b.r->u.a.neg, ipl);
         } else if (u.b.l->t==BoolExpr::NT_RLIN) {
-          u.b.l->u.a.x->rl.post(home, u.b.r->expr(home,icl),
-                                !u.b.l->u.a.neg,icl);
+          u.b.l->u.a.x->rl.post(home, u.b.r->expr(home,ipl),
+                                !u.b.l->u.a.neg,ipl);
         } else if (u.b.r->t==BoolExpr::NT_RLIN) {
-          u.b.r->u.a.x->rl.post(home, u.b.l->expr(home,icl),
-                                !u.b.r->u.a.neg,icl);
+          u.b.r->u.a.x->rl.post(home, u.b.l->expr(home,ipl),
+                                !u.b.r->u.a.neg,ipl);
 #ifdef GECODE_HAS_FLOAT_VARS
-        } else if (u.b.l->t==BoolExpr::NT_VAR && 
+        } else if (u.b.l->t==BoolExpr::NT_VAR &&
                    u.b.r->t==BoolExpr::NT_RLINFLOAT) {
           u.b.r->u.a.x->rfl.post(home, u.b.l->u.a.x->x,
                                  u.b.l->u.a.neg==u.b.r->u.a.neg);
-        } else if (u.b.r->t==BoolExpr::NT_VAR && 
+        } else if (u.b.r->t==BoolExpr::NT_VAR &&
                    u.b.l->t==BoolExpr::NT_RLINFLOAT) {
           u.b.l->u.a.x->rfl.post(home, u.b.r->u.a.x->x,
                                  u.b.l->u.a.neg==u.b.r->u.a.neg);
         } else if (u.b.l->t==BoolExpr::NT_RLINFLOAT) {
-          u.b.l->u.a.x->rfl.post(home, u.b.r->expr(home,icl),
+          u.b.l->u.a.x->rfl.post(home, u.b.r->expr(home,ipl),
                                  !u.b.l->u.a.neg);
         } else if (u.b.r->t==BoolExpr::NT_RLINFLOAT) {
-          u.b.r->u.a.x->rfl.post(home, u.b.l->expr(home,icl),
+          u.b.r->u.a.x->rfl.post(home, u.b.l->expr(home,ipl),
                                  !u.b.r->u.a.neg);
 #endif
 #ifdef GECODE_HAS_SET_VARS
-        } else if (u.b.l->t==BoolExpr::NT_VAR && 
+        } else if (u.b.l->t==BoolExpr::NT_VAR &&
                    u.b.r->t==BoolExpr::NT_RSET) {
           u.b.r->u.a.x->rs.post(home, u.b.l->u.a.x->x,
                                 u.b.l->u.a.neg==u.b.r->u.a.neg);
-        } else if (u.b.r->t==BoolExpr::NT_VAR && 
+        } else if (u.b.r->t==BoolExpr::NT_VAR &&
                    u.b.l->t==BoolExpr::NT_RSET) {
           u.b.l->u.a.x->rs.post(home, u.b.r->u.a.x->x,
                                 u.b.l->u.a.neg==u.b.r->u.a.neg);
         } else if (u.b.l->t==BoolExpr::NT_RSET) {
-          u.b.l->u.a.x->rs.post(home, u.b.r->expr(home,icl),
+          u.b.l->u.a.x->rs.post(home, u.b.r->expr(home,ipl),
                                 !u.b.l->u.a.neg);
         } else if (u.b.r->t==BoolExpr::NT_RSET) {
-          u.b.r->u.a.x->rs.post(home, u.b.l->expr(home,icl),
+          u.b.r->u.a.x->rs.post(home, u.b.l->expr(home,ipl),
                                 !u.b.r->u.a.neg);
 #endif
         } else {
-          Gecode::rel(home, expr(home, icl), IRT_EQ, 1);
+          Gecode::rel(home, expr(home, ipl), IRT_EQ, 1);
         }
         break;
       default:
@@ -534,7 +534,7 @@ namespace Gecode {
         return nnf(r,n->l,!neg);
       case BoolExpr::NT_AND: case BoolExpr::NT_OR:
         {
-          NodeType t = ((n->t == BoolExpr::NT_AND) == neg) ? 
+          NodeType t = ((n->t == BoolExpr::NT_AND) == neg) ?
             BoolExpr::NT_OR : BoolExpr::NT_AND;
           NNF* x = new (r) NNF;
           x->t = t;
@@ -574,17 +574,17 @@ namespace Gecode {
       return NULL;
     }
   }
-  
+
   BoolVar
-  BoolExpr::expr(Home home, IntConLevel icl) const {
+  BoolExpr::expr(Home home, IntPropLevel ipl) const {
     Region r(home);
-    return NNF::nnf(r,n,false)->expr(home,icl);
+    return NNF::nnf(r,n,false)->expr(home,ipl);
   }
 
   void
-  BoolExpr::rel(Home home, IntConLevel icl) const {
+  BoolExpr::rel(Home home, IntPropLevel ipl) const {
     Region r(home);
-    return NNF::nnf(r,n,false)->rel(home,icl);
+    return NNF::nnf(r,n,false)->rel(home,ipl);
   }
 
 
@@ -629,70 +629,72 @@ namespace Gecode {
    *
    */
   BoolVar
-  expr(Home home, const BoolExpr& e, IntConLevel icl) {
+  expr(Home home, const BoolExpr& e, IntPropLevel ipl) {
+    PostInfo pi(home);
     if (!home.failed())
-      return e.expr(home,icl);
+      return e.expr(home,ipl);
     BoolVar x(home,0,1);
     return x;
   }
 
   void
-  rel(Home home, const BoolExpr& e, IntConLevel icl) {
+  rel(Home home, const BoolExpr& e, IntPropLevel ipl) {
+    GECODE_POST;
     if (home.failed()) return;
-    e.rel(home,icl);
+    e.rel(home,ipl);
   }
 
   /*
    * Boolean element constraints
    *
    */
-  
+
   /// \brief Boolean element expressions
-  class BElementExpr : public BoolExpr::MiscExpr {
-  public:
+  class BElementExpr : public BoolExpr::Misc {
+  protected:
     /// The Boolean expressions
     BoolExpr* a;
     /// The number of Boolean expressions
     int n;
     /// The linear expression for the index
     LinIntExpr idx;
+  public:
     /// Constructor
-    BElementExpr(int size);
+    BElementExpr(const BoolVarArgs& b, const LinIntExpr& idx);
     /// Destructor
     virtual ~BElementExpr(void);
     /// Constrain \a b to be equivalent to the expression (negated if \a neg)
-    virtual void post(Space& home, BoolVar b, bool neg, IntConLevel icl);
+    virtual void post(Home home, BoolVar b, bool neg, IntPropLevel ipl);
   };
 
-  BElementExpr::BElementExpr(int size)
-    : a(heap.alloc<BoolExpr>(size)), n(size) {}
+  BElementExpr::BElementExpr(const BoolVarArgs& b, const LinIntExpr& idx)
+    : a(static_cast<BoolExpr*>(heap.ralloc(sizeof(BoolExpr)*b.size()))), n(b.size()), idx(idx) {
+    for (int i=b.size(); i--;)
+      new (&a[i]) BoolExpr(b[i]);
+  }
 
   BElementExpr::~BElementExpr(void) {
     heap.free<BoolExpr>(a,n);
   }
-  
+
   void
-  BElementExpr::post(Space& home, BoolVar b, bool pos, IntConLevel icl) {
-    IntVar z = idx.post(home, icl);
-    if (z.assigned() && z.val() >= 0 && z.val() < n) {
-      BoolExpr be = pos ? (a[z.val()] == b) : (a[z.val()] == !b);
-      be.rel(home,icl);
+  BElementExpr::post(Home home, BoolVar b, bool neg, IntPropLevel ipl) {
+    IntVar z = idx.post(home, ipl);
+    if (z.assigned() && (z.val() >= 0) && (z.val() < n)) {
+      BoolExpr be = neg ? (a[z.val()] == !b) : (a[z.val()] == b);
+      be.rel(home,ipl);
     } else {
       BoolVarArgs x(n);
       for (int i=n; i--;)
-        x[i] = a[i].expr(home,icl);
-      BoolVar res = pos ? b : (!b).expr(home,icl);
-      element(home, x, z, res, icl);
+        x[i] = a[i].expr(home,ipl);
+      BoolVar res = neg ? (!b).expr(home,ipl) : b;
+      element(home, x, z, res, ipl);
     }
   }
 
   BoolExpr
   element(const BoolVarArgs& b, const LinIntExpr& idx) {
-    BElementExpr* be = new BElementExpr(b.size());
-    for (int i=b.size(); i--;)
-      new (&be->a[i]) BoolExpr(b[i]);
-    be->idx = idx;
-    return BoolExpr(be);
+    return BoolExpr(new BElementExpr(b,idx));
   }
 
 }
