@@ -7,8 +7,8 @@
  *     Christian Schulte, 2010
  *
  *  Last modified:
- *     $Date: 2013-08-19 14:00:39 +0200 (Mon, 19 Aug 2013) $ by $Author: schulte $
- *     $Revision: 13982 $
+ *     $Date: 2016-08-08 16:24:17 +0200 (Mon, 08 Aug 2016) $ by $Author: schulte $
+ *     $Revision: 15141 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -71,12 +71,12 @@ namespace Gecode {
     /// Default constructor
     Node(void);
     /// Generate linear terms from expression
-    void fill(Home home, IntConLevel icl,
+    void fill(Home home, IntPropLevel ipl,
               Int::Linear::Term<Int::IntView>*& ti,
               Int::Linear::Term<Int::BoolView>*& tb,
               long long int m, long long int& d) const;
     /// Generate linear terms for expressions
-    int fill(Home home, IntConLevel icl,
+    int fill(Home home, IntPropLevel ipl,
              Int::Linear::Term<Int::IntView>* ti,
              Int::Linear::Term<Int::BoolView>* tb) const;
     /// Decrement reference count and possibly free memory
@@ -147,23 +147,23 @@ namespace Gecode {
   }
 
   int
-  LinIntExpr::Node::fill(Home home, IntConLevel icl,
-                      Int::Linear::Term<Int::IntView>* ti, 
+  LinIntExpr::Node::fill(Home home, IntPropLevel ipl,
+                      Int::Linear::Term<Int::IntView>* ti,
                       Int::Linear::Term<Int::BoolView>* tb) const {
     long long int d=0;
-    fill(home,icl,ti,tb,1,d);
+    fill(home,ipl,ti,tb,1,d);
     Int::Limits::check(d,"MiniModel::LinIntExpr");
     return static_cast<int>(d);
   }
 
   void
-  LinIntExpr::post(Home home, IntRelType irt, IntConLevel icl) const {
+  LinIntExpr::post(Home home, IntRelType irt, IntPropLevel ipl) const {
     if (home.failed()) return;
     Region r(home);
     if (n->n_bool == 0) {
       // Only integer variables
       if (n->t==NT_ADD && n->l == NULL && n->r->t==NT_NONLIN) {
-        n->r->sum.ne->post(home,irt,-n->c,icl);
+        n->r->sum.ne->post(home,irt,-n->c,ipl);
       } else if (n->t==NT_SUB && n->r->t==NT_NONLIN && n->l==NULL) {
         switch (irt) {
         case IRT_LQ: irt=IRT_GQ; break;
@@ -172,66 +172,66 @@ namespace Gecode {
         case IRT_GR: irt=IRT_LE; break;
         default: break;
         }
-        n->r->sum.ne->post(home,irt,n->c,icl);
+        n->r->sum.ne->post(home,irt,n->c,ipl);
       } else if (irt==IRT_EQ &&
                  n->t==NT_SUB && n->r->t==NT_NONLIN &&
                  n->l != NULL && n->l->t==NT_VAR_INT
                  && n->l->a==1) {
-        (void) n->r->sum.ne->post(home,&n->l->x_int,icl);
+        (void) n->r->sum.ne->post(home,&n->l->x_int,ipl);
       } else if (irt==IRT_EQ &&
                  n->t==NT_SUB && n->r->t==NT_VAR_INT &&
                  n->l != NULL && n->l->t==NT_NONLIN
                  && n->r->a==1) {
-        (void) n->l->sum.ne->post(home,&n->r->x_int,icl);
+        (void) n->l->sum.ne->post(home,&n->r->x_int,ipl);
       } else {
         Int::Linear::Term<Int::IntView>* its =
           r.alloc<Int::Linear::Term<Int::IntView> >(n->n_int);
-        int c = n->fill(home,icl,its,NULL);
-        Int::Linear::post(home, its, n->n_int, irt, -c, icl);
+        int c = n->fill(home,ipl,its,NULL);
+        Int::Linear::post(home, its, n->n_int, irt, -c, ipl);
       }
     } else if (n->n_int == 0) {
       // Only Boolean variables
       Int::Linear::Term<Int::BoolView>* bts =
         r.alloc<Int::Linear::Term<Int::BoolView> >(n->n_bool);
-      int c = n->fill(home,icl,NULL,bts);
-      Int::Linear::post(home, bts, n->n_bool, irt, -c, icl);
+      int c = n->fill(home,ipl,NULL,bts);
+      Int::Linear::post(home, bts, n->n_bool, irt, -c, ipl);
     } else if (n->n_bool == 1) {
       // Integer variables and only one Boolean variable
       Int::Linear::Term<Int::IntView>* its =
         r.alloc<Int::Linear::Term<Int::IntView> >(n->n_int+1);
       Int::Linear::Term<Int::BoolView>* bts =
         r.alloc<Int::Linear::Term<Int::BoolView> >(1);
-      int c = n->fill(home,icl,its,bts);
+      int c = n->fill(home,ipl,its,bts);
       IntVar x(home,0,1);
       channel(home,bts[0].x,x);
       its[n->n_int].x = x;
       its[n->n_int].a = bts[0].a;
-      Int::Linear::post(home, its, n->n_int+1, irt, -c, icl);
+      Int::Linear::post(home, its, n->n_int+1, irt, -c, ipl);
     } else {
       // Both integer and Boolean variables
       Int::Linear::Term<Int::IntView>* its =
         r.alloc<Int::Linear::Term<Int::IntView> >(n->n_int+1);
       Int::Linear::Term<Int::BoolView>* bts =
         r.alloc<Int::Linear::Term<Int::BoolView> >(n->n_bool);
-      int c = n->fill(home,icl,its,bts);
+      int c = n->fill(home,ipl,its,bts);
       int min, max;
       Int::Linear::estimate(&bts[0],n->n_bool,0,min,max);
       IntVar x(home,min,max);
       its[n->n_int].x = x; its[n->n_int].a = 1;
-      Int::Linear::post(home, bts, n->n_bool, IRT_EQ, x, 0, icl);
-      Int::Linear::post(home, its, n->n_int+1, irt, -c, icl);
+      Int::Linear::post(home, bts, n->n_bool, IRT_EQ, x, 0, ipl);
+      Int::Linear::post(home, its, n->n_int+1, irt, -c, ipl);
     }
   }
 
   void
   LinIntExpr::post(Home home, IntRelType irt, const BoolVar& b,
-                IntConLevel icl) const {
+                IntPropLevel ipl) const {
     if (home.failed()) return;
     Region r(home);
     if (n->n_bool == 0) {
       // Only integer variables
       if (n->t==NT_ADD && n->l==NULL && n->r->t==NT_NONLIN) {
-        n->r->sum.ne->post(home,irt,-n->c,b,icl);
+        n->r->sum.ne->post(home,irt,-n->c,b,ipl);
       } else if (n->t==NT_SUB && n->l==NULL && n->r->t==NT_NONLIN) {
         switch (irt) {
         case IRT_LQ: irt=IRT_GQ; break;
@@ -240,73 +240,73 @@ namespace Gecode {
         case IRT_GR: irt=IRT_LE; break;
         default: break;
         }
-        n->r->sum.ne->post(home,irt,n->c,b,icl);
+        n->r->sum.ne->post(home,irt,n->c,b,ipl);
       } else {
         Int::Linear::Term<Int::IntView>* its =
           r.alloc<Int::Linear::Term<Int::IntView> >(n->n_int);
-        int c = n->fill(home,icl,its,NULL);
-        Int::Linear::post(home, its, n->n_int, irt, -c, b, icl);
+        int c = n->fill(home,ipl,its,NULL);
+        Int::Linear::post(home, its, n->n_int, irt, -c, b, ipl);
       }
     } else if (n->n_int == 0) {
       // Only Boolean variables
       Int::Linear::Term<Int::BoolView>* bts =
         r.alloc<Int::Linear::Term<Int::BoolView> >(n->n_bool);
-      int c = n->fill(home,icl,NULL,bts);
-      Int::Linear::post(home, bts, n->n_bool, irt, -c, b, icl);
+      int c = n->fill(home,ipl,NULL,bts);
+      Int::Linear::post(home, bts, n->n_bool, irt, -c, b, ipl);
     } else if (n->n_bool == 1) {
       // Integer variables and only one Boolean variable
       Int::Linear::Term<Int::IntView>* its =
         r.alloc<Int::Linear::Term<Int::IntView> >(n->n_int+1);
       Int::Linear::Term<Int::BoolView>* bts =
         r.alloc<Int::Linear::Term<Int::BoolView> >(1);
-      int c = n->fill(home,icl,its,bts);
+      int c = n->fill(home,ipl,its,bts);
       IntVar x(home,0,1);
       channel(home,bts[0].x,x);
       its[n->n_int].x = x;
       its[n->n_int].a = bts[0].a;
-      Int::Linear::post(home, its, n->n_int+1, irt, -c, b, icl);
+      Int::Linear::post(home, its, n->n_int+1, irt, -c, b, ipl);
     } else {
       // Both integer and Boolean variables
       Int::Linear::Term<Int::IntView>* its =
         r.alloc<Int::Linear::Term<Int::IntView> >(n->n_int+1);
       Int::Linear::Term<Int::BoolView>* bts =
         r.alloc<Int::Linear::Term<Int::BoolView> >(n->n_bool);
-      int c = n->fill(home,icl,its,bts);
+      int c = n->fill(home,ipl,its,bts);
       int min, max;
       Int::Linear::estimate(&bts[0],n->n_bool,0,min,max);
       IntVar x(home,min,max);
       its[n->n_int].x = x; its[n->n_int].a = 1;
-      Int::Linear::post(home, bts, n->n_bool, IRT_EQ, x, 0, icl);
-      Int::Linear::post(home, its, n->n_int+1, irt, -c, b, icl);
+      Int::Linear::post(home, bts, n->n_bool, IRT_EQ, x, 0, ipl);
+      Int::Linear::post(home, its, n->n_int+1, irt, -c, b, ipl);
     }
   }
 
   IntVar
-  LinIntExpr::post(Home home, IntConLevel icl) const {
+  LinIntExpr::post(Home home, IntPropLevel ipl) const {
     if (home.failed()) return IntVar(home,0,0);
     Region r(home);
     if (n->n_bool == 0) {
       // Only integer variables
       Int::Linear::Term<Int::IntView>* its =
         r.alloc<Int::Linear::Term<Int::IntView> >(n->n_int+1);
-      int c = n->fill(home,icl,its,NULL);
+      int c = n->fill(home,ipl,its,NULL);
       if ((n->n_int == 1) && (c == 0) && (its[0].a == 1))
         return its[0].x;
       int min, max;
       Int::Linear::estimate(&its[0],n->n_int,c,min,max);
       IntVar x(home, min, max);
       its[n->n_int].x = x; its[n->n_int].a = -1;
-      Int::Linear::post(home, its, n->n_int+1, IRT_EQ, -c, icl);
+      Int::Linear::post(home, its, n->n_int+1, IRT_EQ, -c, ipl);
       return x;
     } else if (n->n_int == 0) {
       // Only Boolean variables
       Int::Linear::Term<Int::BoolView>* bts =
         r.alloc<Int::Linear::Term<Int::BoolView> >(n->n_bool);
-      int c = n->fill(home,icl,NULL,bts);
+      int c = n->fill(home,ipl,NULL,bts);
       int min, max;
       Int::Linear::estimate(&bts[0],n->n_bool,c,min,max);
       IntVar x(home, min, max);
-      Int::Linear::post(home, bts, n->n_bool, IRT_EQ, x, -c, icl);
+      Int::Linear::post(home, bts, n->n_bool, IRT_EQ, x, -c, ipl);
       return x;
     } else if (n->n_bool == 1) {
       // Integer variables and single Boolean variable
@@ -314,7 +314,7 @@ namespace Gecode {
         r.alloc<Int::Linear::Term<Int::IntView> >(n->n_int+2);
       Int::Linear::Term<Int::BoolView>* bts =
         r.alloc<Int::Linear::Term<Int::BoolView> >(1);
-      int c = n->fill(home,icl,its,bts);
+      int c = n->fill(home,ipl,its,bts);
       IntVar x(home, 0, 1);
       channel(home, x, bts[0].x);
       its[n->n_int].x = x; its[n->n_int].a = bts[0].a;
@@ -322,7 +322,7 @@ namespace Gecode {
       Int::Linear::estimate(&its[0],n->n_int+1,c,y_min,y_max);
       IntVar y(home, y_min, y_max);
       its[n->n_int+1].x = y; its[n->n_int+1].a = -1;
-      Int::Linear::post(home, its, n->n_int+2, IRT_EQ, -c, icl);
+      Int::Linear::post(home, its, n->n_int+2, IRT_EQ, -c, ipl);
       return y;
     } else {
       // Both integer and Boolean variables
@@ -330,17 +330,17 @@ namespace Gecode {
         r.alloc<Int::Linear::Term<Int::IntView> >(n->n_int+2);
       Int::Linear::Term<Int::BoolView>* bts =
         r.alloc<Int::Linear::Term<Int::BoolView> >(n->n_bool);
-      int c = n->fill(home,icl,its,bts);
+      int c = n->fill(home,ipl,its,bts);
       int x_min, x_max;
       Int::Linear::estimate(&bts[0],n->n_bool,0,x_min,x_max);
       IntVar x(home, x_min, x_max);
-      Int::Linear::post(home, bts, n->n_bool, IRT_EQ, x, 0, icl);
+      Int::Linear::post(home, bts, n->n_bool, IRT_EQ, x, 0, ipl);
       its[n->n_int].x = x; its[n->n_int].a = 1;
       int y_min, y_max;
       Int::Linear::estimate(&its[0],n->n_int+1,c,y_min,y_max);
       IntVar y(home, y_min, y_max);
       its[n->n_int+1].x = y; its[n->n_int+1].a = -1;
-      Int::Linear::post(home, its, n->n_int+2, IRT_EQ, -c, icl);
+      Int::Linear::post(home, its, n->n_int+2, IRT_EQ, -c, ipl);
       return y;
     }
   }
@@ -508,8 +508,8 @@ namespace Gecode {
 
 
   void
-  LinIntExpr::Node::fill(Home home, IntConLevel icl,
-                      Int::Linear::Term<Int::IntView>*& ti, 
+  LinIntExpr::Node::fill(Home home, IntPropLevel ipl,
+                      Int::Linear::Term<Int::IntView>*& ti,
                       Int::Linear::Term<Int::BoolView>*& tb,
                       long long int m, long long int& d) const {
     switch (this->t) {
@@ -522,7 +522,7 @@ namespace Gecode {
       ti->a=static_cast<int>(m*a); ti->x=x_int; ti++;
       break;
     case NT_NONLIN:
-      ti->a=static_cast<int>(m); ti->x=sum.ne->post(home, NULL, icl); ti++;
+      ti->a=static_cast<int>(m); ti->x=sum.ne->post(home, NULL, ipl); ti++;
       break;
     case NT_VAR_BOOL:
       Int::Limits::check(m*a,"MiniModel::LinIntExpr");
@@ -547,22 +547,22 @@ namespace Gecode {
         Int::Limits::check(m*c,"MiniModel::LinIntExpr");
         d += m*c;
       } else {
-        l->fill(home,icl,ti,tb,m,d);
+        l->fill(home,ipl,ti,tb,m,d);
       }
-      r->fill(home,icl,ti,tb,m,d);
+      r->fill(home,ipl,ti,tb,m,d);
       break;
     case NT_SUB:
       if (l == NULL) {
         Int::Limits::check(m*c,"MiniModel::LinIntExpr");
         d += m*c;
       } else {
-        l->fill(home,icl,ti,tb,m,d);
+        l->fill(home,ipl,ti,tb,m,d);
       }
-      r->fill(home,icl,ti,tb,-m,d);
+      r->fill(home,ipl,ti,tb,-m,d);
       break;
     case NT_MUL:
       Int::Limits::check(m*a,"MiniModel::LinIntExpr");
-      l->fill(home,icl,ti,tb,m*a,d);
+      l->fill(home,ipl,ti,tb,m*a,d);
       break;
     default:
       GECODE_NEVER;
@@ -576,7 +576,7 @@ namespace Gecode {
    */
   LinIntExpr
   operator +(int c, const IntVar& x) {
-    if (x.assigned() && 
+    if (x.assigned() &&
         Int::Limits::valid(static_cast<long long int>(c)+x.val()))
       return LinIntExpr(c+x.val());
     else
@@ -584,7 +584,7 @@ namespace Gecode {
   }
   LinIntExpr
   operator +(int c, const BoolVar& x) {
-    if (x.assigned() && 
+    if (x.assigned() &&
         Int::Limits::valid(static_cast<long long int>(c)+x.val()))
       return LinIntExpr(c+x.val());
     else
@@ -596,7 +596,7 @@ namespace Gecode {
   }
   LinIntExpr
   operator +(const IntVar& x, int c) {
-    if (x.assigned() && 
+    if (x.assigned() &&
         Int::Limits::valid(static_cast<long long int>(c)+x.val()))
       return LinIntExpr(c+x.val());
     else
@@ -604,7 +604,7 @@ namespace Gecode {
   }
   LinIntExpr
   operator +(const BoolVar& x, int c) {
-    if (x.assigned() && 
+    if (x.assigned() &&
         Int::Limits::valid(static_cast<long long int>(c)+x.val()))
       return LinIntExpr(c+x.val());
     else
@@ -685,7 +685,7 @@ namespace Gecode {
 
   LinIntExpr
   operator -(int c, const IntVar& x) {
-    if (x.assigned() && 
+    if (x.assigned() &&
         Int::Limits::valid(static_cast<long long int>(c)-x.val()))
       return LinIntExpr(c-x.val());
     else
@@ -693,7 +693,7 @@ namespace Gecode {
   }
   LinIntExpr
   operator -(int c, const BoolVar& x) {
-    if (x.assigned() && 
+    if (x.assigned() &&
         Int::Limits::valid(static_cast<long long int>(c)-x.val()))
       return LinIntExpr(c-x.val());
     else
@@ -705,7 +705,7 @@ namespace Gecode {
   }
   LinIntExpr
   operator -(const IntVar& x, int c) {
-    if (x.assigned() && 
+    if (x.assigned() &&
         Int::Limits::valid(x.val()-static_cast<long long int>(c)))
       return LinIntExpr(x.val()-c);
     else
@@ -713,7 +713,7 @@ namespace Gecode {
   }
   LinIntExpr
   operator -(const BoolVar& x, int c) {
-    if (x.assigned() && 
+    if (x.assigned() &&
         Int::Limits::valid(x.val()-static_cast<long long int>(c)))
       return LinIntExpr(x.val()-c);
     else
@@ -814,8 +814,8 @@ namespace Gecode {
   LinIntExpr
   operator *(int a, const IntVar& x) {
     if (a == 0)
-      return LinIntExpr(0.0);
-    else if (x.assigned() && 
+      return LinIntExpr(0);
+    else if (x.assigned() &&
              Int::Limits::valid(static_cast<long long int>(a)*x.val()))
       return LinIntExpr(a*x.val());
     else
@@ -824,8 +824,8 @@ namespace Gecode {
   LinIntExpr
   operator *(int a, const BoolVar& x) {
     if (a == 0)
-      return LinIntExpr(0.0);
-    else if (x.assigned() && 
+      return LinIntExpr(0);
+    else if (x.assigned() &&
              Int::Limits::valid(static_cast<long long int>(a)*x.val()))
       return LinIntExpr(a*x.val());
     else
@@ -834,8 +834,8 @@ namespace Gecode {
   LinIntExpr
   operator *(const IntVar& x, int a) {
     if (a == 0)
-      return LinIntExpr(0.0);
-    else if (x.assigned() && 
+      return LinIntExpr(0);
+    else if (x.assigned() &&
              Int::Limits::valid(static_cast<long long int>(a)*x.val()))
       return LinIntExpr(a*x.val());
     else
@@ -844,8 +844,8 @@ namespace Gecode {
   LinIntExpr
   operator *(const BoolVar& x, int a) {
     if (a == 0)
-      return LinIntExpr(0.0);
-    else if (x.assigned() && 
+      return LinIntExpr(0);
+    else if (x.assigned() &&
              Int::Limits::valid(static_cast<long long int>(a)*x.val()))
       return LinIntExpr(a*x.val());
     else
@@ -854,14 +854,14 @@ namespace Gecode {
   LinIntExpr
   operator *(const LinIntExpr& e, int a) {
     if (a == 0)
-      return LinIntExpr(0.0);
+      return LinIntExpr(0);
     else
       return LinIntExpr(a,e);
   }
   LinIntExpr
   operator *(int a, const LinIntExpr& e) {
     if (a == 0)
-      return LinIntExpr(0.0);
+      return LinIntExpr(0);
     else
       return LinIntExpr(a,e);
   }
@@ -882,12 +882,12 @@ namespace Gecode {
   sum(const IntArgs& a, const BoolVarArgs& x) {
     return LinIntExpr(a,x);
   }
-  LinIntExpr 
+  LinIntExpr
   sum(const Slice<IntArgs>& slice) {
     const Slice<IntArgs>::ArgsType & args = slice;
     return sum(args);
   }
-  LinIntExpr 
+  LinIntExpr
   sum(const Matrix<IntArgs>& matrix) {
     const Matrix<IntArgs>::ArgsType & args = matrix.get_array();
     return sum(args);
@@ -897,7 +897,7 @@ namespace Gecode {
     int i, sum = 0;
     const int size = args.size();
 
-    for (i = 0 ; i < size ; ++i)    
+    for (i = 0 ; i < size ; ++i)
     {
       sum += args[i];
     }
@@ -907,9 +907,10 @@ namespace Gecode {
 
 
   IntVar
-  expr(Home home, const LinIntExpr& e, IntConLevel icl) {
+  expr(Home home, const LinIntExpr& e, IntPropLevel ipl) {
+    PostInfo pi(home);
     if (!home.failed())
-      return e.post(home,icl);
+      return e.post(home,ipl);
     IntVar x(home,Int::Limits::min,Int::Limits::max);
     return x;
   }
