@@ -7,8 +7,8 @@
  *     Christian Schulte, 2009
  *
  *  Last modified:
- *     $Date: 2009-05-12 18:35:58 +1000 (Tue, 12 May 2009) $ by $Author: schulte $
- *     $Revision: 9057 $
+ *     $Date: 2016-04-19 17:19:45 +0200 (Tue, 19 Apr 2016) $ by $Author: schulte $
+ *     $Revision: 14967 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -43,17 +43,17 @@
 #include <gecode/search/support.hh>
 
 namespace Gecode { namespace Search {
-    
-  Engine* 
-  bab(Space* s, size_t sz, const Options& o) {
+
+  Engine*
+  bab(Space* s, const Options& o) {
 #ifdef GECODE_HAS_THREADS
     Options to = o.expand();
     if (to.threads == 1.0)
-      return new WorkerToEngine<Sequential::BAB>(s,sz,to);
+      return new WorkerToEngine<Sequential::BAB>(s,to);
     else
-      return new Parallel::BAB(s,sz,to);
+      return new Parallel::BAB(s,to);
 #else
-    return new WorkerToEngine<Sequential::BAB>(s,sz,o);
+    return new WorkerToEngine<Sequential::BAB>(s,o);
 #endif
   }
 
