@@ -11,8 +11,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2015-03-17 11:15:59 +0100 (Tue, 17 Mar 2015) $ by $Author: tack $
- *     $Revision: 14442 $
+ *     $Date: 2016-04-19 17:19:45 +0200 (Tue, 19 Apr 2016) $ by $Author: schulte $
+ *     $Revision: 14967 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -39,20 +39,44 @@
  *
  */
 
-namespace Gecode {
+namespace Gecode { namespace Search {
 
-  namespace Search {
-    /// Create branch and bound engine
-    GECODE_SEARCH_EXPORT Engine* bab(Space* s, const Options& o);
+  /// Create branch and bound engine
+  GECODE_SEARCH_EXPORT Engine* bab(Space* s, const Options& o);
+
+  /// A BAB engine builder
+  template<class T>
+  class BabBuilder : public Builder {
+    using Builder::opt;
+  public:
+    /// The constructor
+    BabBuilder(const Options& opt);
+    /// The actual build function
+    virtual Engine* operator() (Space* s) const;
+  };
+
+  template<class T>
+  inline
+  BabBuilder<T>::BabBuilder(const Options& opt)
+    : Builder(opt,BAB<T>::best) {}
+
+  template<class T>
+  Engine*
+  BabBuilder<T>::operator() (Space* s) const {
+    return build<T,BAB>(s,opt);
   }
 
-  template<class T>
-  forceinline
-  BAB<T>::BAB(T* s, const Search::Options& o)
-    : Search::EngineBase<T>(Search::bab(s,o)) {}
+}}
+
+namespace Gecode {
 
   template<class T>
-  T*
+  inline
+  BAB<T>::BAB(T* s, const Search::Options& o)
+    : Search::Base<T>(Search::bab(s,o)) {}
+
+  template<class T>
+  inline T*
   bab(T* s, const Search::Options& o) {
     BAB<T> b(s,o);
     T* l = NULL;
@@ -62,6 +86,12 @@ namespace Gecode {
     return l;
   }
 
+  template<class T>
+  SEB
+  bab(const Search::Options& o) {
+    return new Search::BabBuilder<T>(o);
+  }
+
 }
 
 // STATISTICS: search-other
