@@ -7,8 +7,8 @@
  *     Christian Schulte, 2003
  *
  *  Last modified:
- *     $Date: 2015-03-17 11:15:59 +0100 (Tue, 17 Mar 2015) $ by $Author: tack $
- *     $Revision: 14442 $
+ *     $Date: 2016-04-19 17:19:45 +0200 (Tue, 19 Apr 2016) $ by $Author: schulte $
+ *     $Revision: 14967 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -35,25 +35,56 @@
  *
  */
 
-namespace Gecode {
+namespace Gecode { namespace Search {
 
-  namespace Search {
-    /// Create depth-first engine
-    GECODE_SEARCH_EXPORT Engine* dfs(Space* s, const Options& o);
+  /// Create depth-first engine
+  GECODE_SEARCH_EXPORT Engine*
+  dfs(Space* s, const Options& o);
+
+  /// A DFS engine builder
+  template<class T>
+  class DfsBuilder : public Builder {
+    using Builder::opt;
+  public:
+    /// The constructor
+    DfsBuilder(const Options& opt);
+    /// The actual build function
+    virtual Engine* operator() (Space* s) const;
+  };
+
+  template<class T>
+  inline
+  DfsBuilder<T>::DfsBuilder(const Options& opt)
+    : Builder(opt,DFS<T>::best) {}
+
+  template<class T>
+  Engine*
+  DfsBuilder<T>::operator() (Space* s) const {
+    return build<T,DFS>(s,opt);
   }
 
-  template<class T>
-  forceinline
-  DFS<T>::DFS(T* s, const Search::Options& o)
-    : Search::EngineBase<T>(Search::dfs(s,o)) {}
+}}
+
+namespace Gecode {
 
   template<class T>
-  forceinline T*
+  inline
+  DFS<T>::DFS(T* s, const Search::Options& o)
+    : Search::Base<T>(Search::dfs(s,o)) {}
+
+  template<class T>
+  inline T*
   dfs(T* s, const Search::Options& o) {
     DFS<T> d(s,o);
     return d.next();
   }
 
+  template<class T>
+  SEB
+  dfs(const Search::Options& o) {
+    return new Search::DfsBuilder<T>(o);
+  }
+
 }
 
 // STATISTICS: search-other
