@@ -4,11 +4,11 @@
  *     Christian Schulte <schulte@gecode.org>
  *
  *  Copyright:
- *     Christian Schulte, 2004
+ *     Christian Schulte, 2004, 2016
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2016-09-22 16:19:20 +0200 (Thu, 22 Sep 2016) $ by $Author: schulte $
+ *     $Revision: 15169 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -35,41 +35,43 @@
  *
  */
 
-namespace Gecode {
+namespace Gecode { namespace Search {
 
-  namespace Search {
-    /// Create lds engine
-    GECODE_SEARCH_EXPORT Engine* lds(Space* s, size_t sz, const Options& o);
+  /// Create lds engine
+  GECODE_SEARCH_EXPORT Engine*
+  lds(Space* s, const Options& o);
+
+  /// A DFS engine builder
+  template<class T>
+  class LdsBuilder : public Builder {
+    using Builder::opt;
+  public:
+    /// The constructor
+    LdsBuilder(const Options& opt);
+    /// The actual build function
+    virtual Engine* operator() (Space* s) const;
+  };
+
+  template<class T>
+  inline
+  LdsBuilder<T>::LdsBuilder(const Options& opt)
+    : Builder(opt,LDS<T>::best) {}
+
+  template<class T>
+  Engine*
+  LdsBuilder<T>::operator() (Space* s) const {
+    return build<T,LDS>(s,opt);
   }
 
+
+}}
+
+namespace Gecode {
+
   template<class T>
   forceinline
   LDS<T>::LDS(T* s, const Search::Options& o)
-    : e(Search::lds(s,sizeof(T),o)) {}
-
-  template<class T>
-  forceinline T*
-  LDS<T>::next(void) {
-    return dynamic_cast<T*>(e->next());
-  }
-
-  template<class T>
-  forceinline Search::Statistics
-  LDS<T>::statistics(void) const {
-    return e->statistics();
-  }
-
-  template<class T>
-  forceinline bool
-  LDS<T>::stopped(void) const {
-    return e->stopped();
-  }
-
-  template<class T>
-  forceinline
-  LDS<T>::~LDS(void) {
-    delete e;
-  }
+    : Search::Base<T>(Search::lds(s,o)) {}
 
   template<class T>
   T*
@@ -78,6 +80,12 @@ namespace Gecode {
     return lds.next();
   }
 
+  template<class T>
+  SEB
+  lds(const Search::Options& o) {
+    return new Search::LdsBuilder<T>(o);
+  }
+
 }
 
 // STATISTICS: search-other
