@@ -7,8 +7,8 @@
  *     Christian Schulte, 2009
  *
  *  Last modified:
- *     $Date: 2013-07-12 18:20:11 +0200 (Fri, 12 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13877 $
+ *     $Date: 2017-03-28 16:18:06 +0200 (Tue, 28 Mar 2017) $ by $Author: schulte $
+ *     $Revision: 15620 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -46,7 +46,7 @@ namespace Gecode { namespace Search { namespace Parallel {
   /*
    * Statistics
    */
-  Statistics 
+  Statistics
   BAB::statistics(void) const {
     Statistics s;
     for (unsigned int i=0; i<workers(); i++)
@@ -54,11 +54,45 @@ namespace Gecode { namespace Search { namespace Parallel {
     return s;
   }
 
+  void
+  BAB::constrain(const Space& b) {
+    m_search.acquire();
+    if (best != NULL) {
+      best->constrain(b);
+      if (best->status() != SS_FAILED) {
+        m_search.release();
+        return;
+      }
+      delete best;
+    }
+    best = b.clone(false);
+    // Announce better solutions
+    for (unsigned int i=0; i<workers(); i++)
+      worker(i)->better(best);
+    m_search.release();
+  }
+
   /*
    * Actual work
    */
   void
   BAB::Worker::run(void) {
+    /*
+     * The engine maintains the following invariant:
+     *  - If the current space (cur) is not NULL, the path always points
+     *    to exactly that space.
+     *  - If the current space (cur) is NULL, the path always points
+     *    to the next space (if there is any).
+     *
+     * This invariant is needed so that no-goods can be extracted properly
+     * when the engine is stopped or has found a solution.
+     *
+     * An additional invariant maintained by the engine is:
+     *   For all nodes stored at a depth less than mark, there
+     *   is no guarantee of betterness. For those above the mark,
+     *   betterness is guaranteed.
+     *
+     */
     // Peform initial delay, if not first worker
     if (this != engine().worker(0))
       Support::Thread::sleep(Config::initial_delay);
@@ -100,18 +134,13 @@ namespace Gecode { namespace Search { namespace Parallel {
               m.release();
               engine().stop();
             } else {
-              /*
-               * The invariant maintained by the engine is:
-               *   For all nodes stored at a depth less than mark, there
-               *   is no guarantee of betterness. For those above the mark,
-               *   betterness is guaranteed.
-               */
               node++;
               switch (cur->status(*this)) {
               case SS_FAILED:
                 fail++;
                 delete cur;
                 cur = NULL;
+                path.next();
                 m.release();
                 break;
               case SS_SOLVED:
@@ -121,6 +150,7 @@ namespace Gecode { namespace Search { namespace Parallel {
                   Space* s = cur->clone(false);
                   delete cur;
                   cur = NULL;
+                  path.next();
                   m.release();
                   engine().solution(s);
                 }
@@ -144,8 +174,10 @@ namespace Gecode { namespace Search { namespace Parallel {
                 GECODE_NEVER;
               }
             }
-          } else if (path.next()) {
-            cur = path.recompute(d,engine().opt().a_d,*this,best,mark);
+          } else if (!path.empty()) {
+            cur = path.recompute(d,engine().opt().a_d,*this,*best,mark);
+            if (cur == NULL)
+              path.next();
             m.release();
           } else {
             idle = true;
