@@ -1,14 +1,14 @@
 /* -*- mode: C++; c-basic-offset: 2; indent-tabs-mode: nil -*- */
 /*
  *  Main authors:
- *     Guido Tack <tack@gecode.org>
+ *     Christian Schulte <schulte@gecode.org>
  *
  *  Copyright:
- *     Guido Tack, 2012
+ *     Christian Schulte, 2015
  *
  *  Last modified:
- *     $Date: 2013-07-11 12:30:18 +0200 (Thu, 11 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13840 $
+ *     $Date: 2016-04-19 17:19:45 +0200 (Tue, 19 Apr 2016) $ by $Author: schulte $
+ *     $Revision: 14967 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -35,22 +35,23 @@
  *
  */
 
-#include <gecode/search.hh>
 #include <gecode/search/meta/rbs.hh>
 
-namespace Gecode { namespace Search {
-    
-  Engine* 
-  rbs(Space* s, MetaStop* stop,
-      Engine* e, const Options& o) {
-#ifdef GECODE_HAS_THREADS
-    Options to = o.expand();
-    return new Meta::RBS(s,o.cutoff,stop,e,to);
-#else
-    return new Meta::RBS(s,o.cutoff,stop,e,o);
-#endif
+namespace Gecode { namespace Search { namespace Meta {
+
+  Stop*
+  stop(Stop* stop) {
+    return new RestartStop(stop);
   }
 
-}}
+  Engine*
+  engine(Space* master, Stop* stop, Engine* slave,
+         const Search::Statistics& stat, const Options& opt, bool best) {
+    return new RBS(master,static_cast<RestartStop*>(stop), slave,
+                   stat,opt,best);
+  }
 
-// STATISTICS: search-other
+
+}}}
+
+// STATISTICS: search-meta
