@@ -13,8 +13,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2013-07-04 17:03:13 +0200 (Thu, 04 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13801 $
+ *     $Date: 2017-02-16 12:11:51 +0100 (Thu, 16 Feb 2017) $ by $Author: schulte $
+ *     $Revision: 15434 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -44,7 +44,7 @@
 namespace Gecode { namespace Set { namespace Branch {
 
   forceinline
-  ValCommitInc::ValCommitInc(Space& home, const ValBranch& vb)
+  ValCommitInc::ValCommitInc(Space& home, const ValBranch<Var>& vb)
     : ValCommit<SetView,int>(home,vb) {}
   forceinline
   ValCommitInc::ValCommitInc(Space& home, bool shared, ValCommitInc& vc)
@@ -63,12 +63,12 @@ namespace Gecode { namespace Set { namespace Branch {
   forceinline void
   ValCommitInc::print(const Space&, unsigned int a, SetView, int i, int n,
                       std::ostream& o) const {
-    o << "var[" << i << "]." 
+    o << "var[" << i << "]."
       << ((a == 0) ? "include" : "exclude") << "(" << n << ")";
   }
 
   forceinline
-  ValCommitExc::ValCommitExc(Space& home, const ValBranch& vb)
+  ValCommitExc::ValCommitExc(Space& home, const ValBranch<Var>& vb)
     : ValCommit<SetView,int>(home,vb) {}
   forceinline
   ValCommitExc::ValCommitExc(Space& home, bool shared, ValCommitExc& vc)
@@ -87,7 +87,7 @@ namespace Gecode { namespace Set { namespace Branch {
   forceinline void
   ValCommitExc::print(const Space&, unsigned int a, SetView, int i, int n,
                       std::ostream& o) const {
-    o << "var[" << i << "]." 
+    o << "var[" << i << "]."
       << ((a == 0) ? "exclude" : "include") << "(" << n << ")";
   }
 
