@@ -7,8 +7,8 @@
  *     Christian Schulte, 2009
  *
  *  Last modified:
- *     $Date: 2010-03-04 03:40:32 +1100 (Thu, 04 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10365 $
+ *     $Date: 2017-02-16 12:11:51 +0100 (Thu, 16 Feb 2017) $ by $Author: schulte $
+ *     $Revision: 15434 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -41,14 +41,14 @@
 namespace Gecode {
 
   void
-  wait(Home home, SetVar x, void (*c)(Space& home)) {
-    if (home.failed()) return;
+  wait(Home home, SetVar x, std::function<void(Space& home)> c) {
+    GECODE_POST;
     GECODE_ES_FAIL(Kernel::UnaryWait<Set::SetView>::post(home,x,c));
   }
 
   void
-  wait(Home home, const SetVarArgs& x, void (*c)(Space& home)) {
-    if (home.failed()) return;
+  wait(Home home, const SetVarArgs& x, std::function<void(Space& home)> c) {
+    GECODE_POST;
     ViewArray<Set::SetView> xv(home,x);
     GECODE_ES_FAIL(Kernel::NaryWait<Set::SetView>::post(home,xv,c));
   }
