@@ -7,8 +7,8 @@
  *     Christopher Mears, 2012
  *
  *  Last modified:
- *     $Date: 2013-05-02 17:10:16 +0200 (Thu, 02 May 2013) $ by $Author: schulte $
- *     $Revision: 13603 $
+ *     $Date: 2017-04-01 20:27:10 +0200 (Sat, 01 Apr 2017) $ by $Author: schulte $
+ *     $Revision: 15623 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -37,15 +37,17 @@
 
 namespace Gecode { namespace Set { namespace LDSB {
 
-  template<class View, int n, class Val, unsigned int a>
-  LDSBSetBrancher<View,n,Val,a>
+  template<class View, int n, class Val, unsigned int a,
+           class Filter, class Print>
+  LDSBSetBrancher<View,n,Val,a,Filter,Print>
   ::LDSBSetBrancher(Home home, ViewArray<View>& x,
                     ViewSel<View>* vs[n],
                     ValSelCommitBase<View,Val>* vsc,
                     SymmetryImp<View>** syms, int nsyms,
-                    SetBranchFilter bf,
-                    VarValPrint vvp)
-    : LDSBBrancher<View,n,Val,a>(home, x, vs, vsc, syms, nsyms, bf, vvp),
+                    BranchFilter<Var> bf,
+                    VarValPrint<Var,Val> vvp)
+    : LDSBBrancher<View,n,Val,a,Filter,Print>
+  (home, x, vs, vsc, syms, nsyms, bf, vvp),
       _prevPos(-1),
       _copiedSyms(NULL),
       _nCopiedSyms(0),
@@ -66,10 +68,12 @@ namespace Gecode { namespace Set { namespace LDSB {
     _nNonValueSymmetries = this->_nsyms - seen;
   }
 
-  template<class View, int n, class Val, unsigned int a>
-  LDSBSetBrancher<View,n,Val,a>::
-  LDSBSetBrancher(Space& home, bool shared, LDSBSetBrancher<View,n,Val,a>& b)
-    : LDSBBrancher<View,n,Val,a>(home,shared,b),
+  template<class View, int n, class Val, unsigned int a,
+           class Filter, class Print>
+  LDSBSetBrancher<View,n,Val,a,Filter,Print>::
+  LDSBSetBrancher(Space& home, bool shared,
+                  LDSBSetBrancher<View,n,Val,a,Filter,Print>& b)
+    : LDSBBrancher<View,n,Val,a,Filter,Print>(home,shared,b),
       _prevPos(b._prevPos),
       _nNonValueSymmetries(b._nNonValueSymmetries),
       _nValueSymmetries(b._nValueSymmetries),
@@ -94,7 +98,7 @@ namespace Gecode { namespace Set { namespace LDSB {
    * used values, and makes a new symmetry containing the intersection
    * values, if there are at least two.  Returns the new symmetry, or
    * NULL if the intersection has fewer than two elements.
-   */ 
+   */
   template <class View>
   ValueSymmetryImp<View>*
   specialUpdate(Space& home, ValueSymmetryImp<View>* s, IntSet usedValues) {
@@ -114,7 +118,7 @@ namespace Gecode { namespace Set { namespace LDSB {
     for (IntSetValues v(usedValues) ; v() ; ++v) {
       s->update(Literal(0, v.val()));
     }
-    
+
     if (intersection.size() < 2)
       return NULL;
     int *a = new int[intersection.size()];
@@ -127,9 +131,10 @@ namespace Gecode { namespace Set { namespace LDSB {
     return ns;
   }
 
-  template<class View, int n, class Val, unsigned int a>
+  template<class View, int n, class Val, unsigned int a,
+           class Filter, class Print>
   void
-  LDSBSetBrancher<View,n,Val,a>::
+  LDSBSetBrancher<View,n,Val,a,Filter,Print>::
   updatePart1(Space& home, int choicePos) {
     if (_nValueSymmetries > 0) {
       // If this is a different variable from the last commit, restore
@@ -146,16 +151,16 @@ namespace Gecode { namespace Set { namespace LDSB {
             ValueSymmetryImp<View>* ns =
               specialUpdate(home, _copiedSyms[i], _leftBranchValues);
             if (ns) {
-              this->_syms = home.realloc<SymmetryImp<View>*>(this->_syms, 
-                                                             this->_nsyms, 
+              this->_syms = home.realloc<SymmetryImp<View>*>(this->_syms,
+                                                             this->_nsyms,
                                                              this->_nsyms+1);
               this->_syms[this->_nsyms] = ns;
               this->_nsyms++;
               this->_nValueSymmetries++;
-            }              
+            }
           }
         }
-        
+
         // Reset for current variable, make copy of value symmetries
         _leftBranchValues = IntSet::empty;
         _prevPos = choicePos;
@@ -164,9 +169,9 @@ namespace Gecode { namespace Set { namespace LDSB {
         _copiedSyms = home.alloc<ValueSymmetryImp<View>*>(_nCopiedSyms);
         int i = 0;
         for (int j = _nNonValueSymmetries ; j < this->_nsyms ; j++) {
-          ValueSymmetryImp<View>* vsi = 
+          ValueSymmetryImp<View>* vsi =
             static_cast<ValueSymmetryImp<View>*>(this->_syms[j]);
-          _copiedSyms[i] = 
+          _copiedSyms[i] =
             static_cast<ValueSymmetryImp<View>*>(vsi->copy(home, false));
           i++;
         }
@@ -175,13 +180,14 @@ namespace Gecode { namespace Set { namespace LDSB {
   }
 
   // Compute choice
-  template<class View, int n, class Val, unsigned int a>
+  template<class View, int n, class Val, unsigned int a,
+           class Filter, class Print>
   const Choice*
-  LDSBSetBrancher<View,n,Val,a>::choice(Space& home) {
+  LDSBSetBrancher<View,n,Val,a,Filter,Print>::choice(Space& home) {
     // Making the PVC here is not so nice, I think.
-    const Choice* c = ViewValBrancher<View,n,Val,a>::choice(home);
+    const Choice* c = ViewValBrancher<View,n,Val,a,Filter,Print>::choice(home);
     const PosValChoice<Val>* pvc = static_cast<const PosValChoice<Val>* >(c);
-    
+
     // Compute symmetries.
 
     int choicePos = pvc->pos().pos;
@@ -190,12 +196,13 @@ namespace Gecode { namespace Set { namespace LDSB {
     assert(!_stable);
     updatePart1(home, choicePos);
 
-    return LDSBBrancher<View,n,Val,a>::choice(home);
+    return LDSBBrancher<View,n,Val,a,Filter,Print>::choice(home);
   }
 
-  template<class View, int n, class Val, unsigned int a>
+  template<class View, int n, class Val, unsigned int a,
+           class Filter, class Print>
   ExecStatus
-  LDSBSetBrancher<View,n,Val,a>
+  LDSBSetBrancher<View,n,Val,a,Filter,Print>
   ::commit(Space& home, const Choice& c, unsigned int b) {
     const LDSBChoice<Val>& pvc
       = static_cast<const LDSBChoice<Val>&>(c);
@@ -204,7 +211,7 @@ namespace Gecode { namespace Set { namespace LDSB {
 
     if (!_stable)
       updatePart1(home, choicePos);
-    
+
     if (b == 0) {
       IntArgs ia;
       for (IntSetValues v(_leftBranchValues) ; v() ; ++v) {
@@ -212,15 +219,17 @@ namespace Gecode { namespace Set { namespace LDSB {
       }
       ia << choiceVal;
       _leftBranchValues = IntSet(ia);
-        
+
       // Post the branching constraint.
-      ExecStatus fromBase = ViewValBrancher<View,n,Val,a>::commit(home, c, b);
+      ExecStatus fromBase = ViewValBrancher<View,n,Val,a,Filter,Print>
+        ::commit(home, c, b);
       GECODE_ES_CHECK(fromBase);
       for (int i = 0 ; i < this->_nsyms ; i++)
         this->_syms[i]->update(Literal(choicePos, choiceVal));
     } else if (b == 1) {
       // Post the branching constraint.
-      ExecStatus fromBase = ViewValBrancher<View,n,Val,a>::commit(home, c, b);
+      ExecStatus fromBase = ViewValBrancher<View,n,Val,a,Filter,Print>
+        ::commit(home, c, b);
       GECODE_ES_CHECK(fromBase);
 
       // Post prunings.
@@ -232,27 +241,59 @@ namespace Gecode { namespace Set { namespace LDSB {
         GECODE_ME_CHECK(me);
       }
     }
-    
+
     return ES_OK;
   }
-    
-  template<class View, int n, class Val, unsigned int a>
+
+  template<class View, int n, class Val, unsigned int a,
+           class Filter, class Print>
   Actor*
-  LDSBSetBrancher<View,n,Val,a>::copy(Space& home, bool shared) {
-    return new (home) LDSBSetBrancher<View,n,Val,a>(home,shared,*this);
+  LDSBSetBrancher<View,n,Val,a,Filter,Print>::copy(Space& home, bool shared) {
+    return new (home) LDSBSetBrancher<View,n,Val,a,Filter,Print>
+      (home,shared,*this);
   }
 
-  template<class View, int n, class Val, unsigned int a>
-  forceinline BrancherHandle
-  LDSBSetBrancher<View,n,Val,a>::
+  template<class View, int n, class Val, unsigned int a,
+           class Filter, class Print>
+  forceinline void
+  LDSBSetBrancher<View,n,Val,a,Filter,Print>::
   post(Home home, ViewArray<View>& x,
        ViewSel<View>* vs[n], ValSelCommitBase<View,Val>* vsc,
        SymmetryImp<View>** syms, int nsyms,
-       SetBranchFilter bf,
-       VarValPrint vvp) {
-    return *new (home) LDSBSetBrancher<View,n,Val,a>(home,x,vs,vsc,syms,nsyms,bf,vvp);
+       BranchFilter<Var> bf,
+       VarValPrint<Var,Val> vvp) {
+    (void) new (home) LDSBSetBrancher<View,n,Val,a,Filter,Print>
+      (home,x,vs,vsc,syms,nsyms,bf,vvp);
   }
 
+  template<class View, int n, class Val, unsigned int a>
+  forceinline void
+  postldsbsetbrancher(Home home,
+                      ViewArray<View>& x,
+                      ViewSel<View>* vs[n],
+                      ValSelCommitBase<View,Val>* vsc,
+                      SymmetryImp<View>** syms, int nsyms,
+                      BranchFilter<typename View::VarType> bf,
+                      VarValPrint<typename View::VarType,Val> vvp) {
+    if (bf) {
+      if (vvp) {
+        LDSBSetBrancher<View,n,Val,a,BrancherFilter<View>,BrancherPrint<View,Val> >
+          ::post(home,x,vs,vsc,syms,nsyms,bf,vvp);
+      } else {
+        LDSBSetBrancher<View,n,Val,a,BrancherFilter<View>,BrancherNoPrint<View,Val> >
+          ::post(home,x,vs,vsc,syms,nsyms,bf,vvp);
+      }
+    } else {
+      if (vvp) {
+        LDSBSetBrancher<View,n,Val,a,BrancherNoFilter<View>,BrancherPrint<View,Val> >
+          ::post(home,x,vs,vsc,syms,nsyms,bf,vvp);
+      } else {
+        LDSBSetBrancher<View,n,Val,a,BrancherNoFilter<View>,BrancherNoPrint<View,Val> >
+          ::post(home,x,vs,vsc,syms,nsyms,bf,vvp);
+      }
+    }
+  }      
+
 }}}
 
 // STATISTICS: set-branch
