@@ -10,8 +10,8 @@
  *     Guido Tack, 2004, 2005
  *
  *  Last modified:
- *     $Date: 2010-03-03 17:40:32 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10365 $
+ *     $Date: 2016-05-23 22:18:23 +0200 (Mon, 23 May 2016) $ by $Author: schulte $
+ *     $Revision: 15073 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -47,7 +47,7 @@ namespace Gecode {
 
   void
   rel(Home home, SetOpType op, const SetVarArgs& x, SetVar y) {
-    if (home.failed()) return;
+    GECODE_POST;
     ViewArray<SetView> xa(home,x);
     switch (op) {
     case SOT_UNION:
@@ -74,7 +74,7 @@ namespace Gecode {
 
   void
   rel(Home home, SetOpType op, const SetVarArgs& x, const IntSet& z, SetVar y) {
-    if (home.failed()) return;
+    GECODE_POST;
     Set::Limits::check(z, "Set::rel");
     ViewArray<SetView> xa(home,x);
     switch (op) {
