@@ -13,8 +13,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2012-09-07 17:31:22 +0200 (Fri, 07 Sep 2012) $ by $Author: schulte $
- *     $Revision: 13068 $
+ *     $Date: 2016-10-25 12:52:26 +0200 (Tue, 25 Oct 2016) $ by $Author: schulte $
+ *     $Revision: 15233 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -279,28 +279,33 @@ namespace Gecode { namespace Set { namespace RelOp {
     bool oldModified = false;
 
     do {
-      oldModified = modified;
-      modified = false;
-      if (modified || oldModified || ubevent)
-        GECODE_ES_CHECK(unionNXiUB(home, modified, x, y,unionOfDets));
-      if (modified || oldModified || ubevent)
-        GECODE_ES_CHECK(partitionNYUB(home, modified, x, y,unionOfDets));
-      if (modified || oldModified || anybevent)
-        GECODE_ES_CHECK(partitionNXiLB(home, modified, x, y,unionOfDets));
-      if (modified || oldModified || lbevent)
-        GECODE_ES_CHECK(partitionNYLB(home, modified, x, y,unionOfDets));
-      if (modified || oldModified || cardevent || ubevent)
-        GECODE_ES_CHECK(unionNCard(home, modified, x, y, unionOfDets));
-    } while (modified);
+      do {
+        oldModified = modified;
+        modified = false;
+        if (modified || oldModified || ubevent)
+          GECODE_ES_CHECK(unionNXiUB(home, modified, x, y,unionOfDets));
+        if (modified || oldModified || ubevent)
+          GECODE_ES_CHECK(partitionNYUB(home, modified, x, y,unionOfDets));
+        if (modified || oldModified || anybevent)
+          GECODE_ES_CHECK(partitionNXiLB(home, modified, x, y,unionOfDets));
+        if (modified || oldModified || lbevent)
+          GECODE_ES_CHECK(partitionNYLB(home, modified, x, y,unionOfDets));
+        if (modified || oldModified || cardevent || ubevent) {
+          GECODE_ES_CHECK(unionNCard(home, modified, x, y, unionOfDets));
+        }
+      } while (modified);
 
-    for(int i=0;i<x.size();i++){
-      //Do not reverse! Eats away the end of the array!
-      while (i<x.size() && x[i].assigned()) {
-        GlbRanges<View0> det(x[i]);
-        unionOfDets.includeI(home,det);
-        x.move_lst(i);
+      for(int i=0;i<x.size();i++){
+        //Do not reverse! Eats away the end of the array!
+        while (i<x.size() && x[i].assigned()) {
+          GlbRanges<View0> det(x[i]);
+          unionOfDets.includeI(home,det);
+          x.move_lst(i);
+          modified = true;
+        }
       }
-    }
+
+    } while (modified);
     // When we run out of variables, make a final check and disolve:
     if (x.size()==0) {
       BndSetRanges all1(unionOfDets);
