@@ -10,8 +10,8 @@
  *     Guido Tack, 2004, 2005
  *
  *  Last modified:
- *     $Date: 2013-02-27 17:15:18 +0100 (Wed, 27 Feb 2013) $ by $Author: schulte $
- *     $Revision: 13426 $
+ *     $Date: 2017-03-10 10:15:56 +0100 (Fri, 10 Mar 2017) $ by $Author: schulte $
+ *     $Revision: 15566 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -42,15 +42,14 @@
 #include <gecode/set/rel-op.hh>
 #include <gecode/set/int.hh>
 
-namespace Gecode {
-  using namespace Set;
-  using namespace Set::Rel;
-  using namespace Set::RelOp;
+namespace Gecode { namespace Set {
 
   template<class View0, class View1>
   void
   rel_post(Home home, View0 x0, SetRelType r, View1 x1) {
-    if (home.failed()) return;
+    using namespace Set::Rel;
+    using namespace Set::RelOp;
+    GECODE_POST;
     switch (r) {
     case SRT_EQ:
       GECODE_ES_FAIL((Eq<View0,View1>::post(home,x0,x1)));
@@ -98,7 +97,9 @@ namespace Gecode {
   template<class View0, class View1, ReifyMode rm>
   void
   rel_re(Home home, View0 x, SetRelType r, View1 y, BoolVar b) {
-    if (home.failed()) return;
+    using namespace Set::Rel;
+    using namespace Set::RelOp;
+    GECODE_POST;
     switch (r) {
     case SRT_EQ:
       GECODE_ES_FAIL((ReEq<View0,View1,Gecode::Int::BoolView,rm>
@@ -125,10 +126,10 @@ namespace Gecode {
       }
       break;
     case SRT_SUB:
-      GECODE_ES_FAIL((ReSubset<View0,View1,rm>::post(home, x,y,b)));
+      GECODE_ES_FAIL((ReSubset<View0,View1,Gecode::Int::BoolView,rm>::post(home, x,y,b)));
       break;
     case SRT_SUP:
-      GECODE_ES_FAIL((ReSubset<View1,View0,rm>::post(home, y,x,b)));
+      GECODE_ES_FAIL((ReSubset<View1,View0,Gecode::Int::BoolView,rm>::post(home, y,x,b)));
       break;
     case SRT_DISJ:
       {
@@ -136,7 +137,8 @@ namespace Gecode {
         // ( y <= complement(x) ) <=> b
 
         ComplementView<View0> xc(x);
-        GECODE_ES_FAIL((ReSubset<View1,ComplementView<View0>,rm>
+        GECODE_ES_FAIL((ReSubset<View1,ComplementView<View0>,
+                        Gecode::Int::BoolView,rm>
                         ::post(home, y, xc, b)));
       }
       break;
@@ -165,13 +167,19 @@ namespace Gecode {
     }
   }
 
+}}
+
+namespace Gecode {
+
   void
   rel(Home home, SetVar x, SetRelType r, SetVar y) {
+    using namespace Set;
     rel_post<SetView,SetView>(home,x,r,y);
   }
 
   void
   rel(Home home, SetVar s, SetRelType r, IntVar x) {
+    using namespace Set;
     Gecode::Int::IntView xv(x);
     SingletonView xsingle(xv);
     rel_post<SetView,SingletonView>(home,s,r,xv);
@@ -179,6 +187,7 @@ namespace Gecode {
 
   void
   rel(Home home, IntVar x, SetRelType r, SetVar s) {
+    using namespace Set;
     switch (r) {
     case SRT_SUB:
       rel(home, s, SRT_SUP, x);
@@ -193,6 +202,7 @@ namespace Gecode {
 
   void
   rel(Home home, SetVar x, SetRelType rt, SetVar y, Reify r) {
+    using namespace Set;
     switch (r.mode()) {
     case RM_EQV:
       rel_re<SetView,SetView,RM_EQV>(home,x,rt,y,r.var());
@@ -209,6 +219,7 @@ namespace Gecode {
 
   void
   rel(Home home, SetVar s, SetRelType rt, IntVar x, Reify r) {
+    using namespace Set;
     Gecode::Int::IntView xv(x);
     SingletonView xsingle(xv);
     switch (r.mode()) {
@@ -227,6 +238,7 @@ namespace Gecode {
 
   void
   rel(Home home, IntVar x, SetRelType rt, SetVar s, Reify r) {
+    using namespace Set;
     switch (rt) {
     case SRT_SUB:
       rel(home, s, SRT_SUP, x, r);
