@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-02-05 11:48:53 +0100 (Thu, 05 Feb 2009) $ by $Author: schulte $
- *     $Revision: 8155 $
+ *     $Date: 2017-02-21 06:45:56 +0100 (Tue, 21 Feb 2017) $ by $Author: schulte $
+ *     $Revision: 15465 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -77,7 +77,7 @@ namespace Gecode { namespace Set {
         glb.become(home, lub);
         glb.card(glb.size());
         lub.card(glb.size());
-        return ME_SET_FAILED;
+        return fail(home);
       }
       me = ME_SET_CLUB;
     }
@@ -99,7 +99,7 @@ namespace Gecode { namespace Set {
         glb.become(home, lub);
         glb.card(glb.size());
         lub.card(glb.size());
-        return ME_SET_FAILED;
+        return fail(home);
       }
       me = ME_SET_CGLB;
     }
@@ -136,6 +136,25 @@ namespace Gecode { namespace Set {
     return new (home) SetVarImp(home,share,*this);
   }
 
+  /*
+   * Dependencies
+   *
+   */
+  void
+  SetVarImp::subscribe(Space& home, Propagator& p, PropCond pc,
+                       bool schedule) {
+    SetVarImpBase::subscribe(home,p,pc,assigned(),schedule);
+  }
+  void
+  SetVarImp::subscribe(Space& home, Advisor& a, bool fail) {
+    SetVarImpBase::subscribe(home,a,assigned(),fail);
+  }
+  void
+  SetVarImp::reschedule(Space& home, Propagator& p, PropCond pc) {
+    SetVarImpBase::reschedule(home,p,pc,assigned());
+  }
+
+
 }}
 
 // STATISTICS: set-var
