@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-01-20 23:44:27 +0100 (Tue, 20 Jan 2009) $ by $Author: schulte $
- *     $Revision: 8082 $
+ *     $Date: 2017-03-01 04:28:36 +0100 (Wed, 01 Mar 2017) $ by $Author: schulte $
+ *     $Revision: 15541 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -80,6 +80,25 @@
 
 #endif
 
+/**
+ * \def GECODE_VALID_FUNCTION
+ * \brief Assert that a function is valid
+ *
+ * This is preferred over assert as it is used for optimization,
+ * if supported by a compiler (for example, Microsoft Visual C++).
+ *
+ */
+
+#if defined(_MSC_VER) && defined(NDEBUG)
+
+#define GECODE_VALID_FUNCTION(f) __assume(static_cast<bool>(f));
+
+#else
+
+#define GECODE_VALID_FUNCTION(f) assert(static_cast<bool>(f));
+
+#endif
+
 /**
  * \def GECODE_ASSUME
  * \brief Assert certain property
