@@ -10,8 +10,8 @@
  *     David Rijsman <david.rijsman@quintiq.com>
  *
  *  Last modified:
- *     $Date: 2013-10-15 00:46:56 +0200 (Tue, 15 Oct 2013) $ by $Author: tack $
- *     $Revision: 14025 $
+ *     $Date: 2016-04-19 17:19:45 +0200 (Tue, 19 Apr 2016) $ by $Author: schulte $
+ *     $Revision: 14967 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -76,20 +76,20 @@
  * This is very simplistic, just enough for parallel search engines. Do
  * not mistake it for a full-fledged thread package.
  *
- * If the platform supports threads, the macro GECODE_HAS_THREADS is 
+ * If the platform supports threads, the macro GECODE_HAS_THREADS is
  * defined. If threads are not supported, all classes are
  * still available, but are noops with the exception of trying to
  * create a new thread which will throw an exception.
  *
  *
  * \ingroup FuncSupport
- */  
+ */
 
 namespace Gecode { namespace Support {
 
   /**
    * \brief A mutex for mutual exclausion among several threads
-   * 
+   *
    * It is not specified whether the mutex is recursive or not.
    * Likewise, there is no guarantee of fairness among the
    * blocking threads.
@@ -140,10 +140,10 @@ namespace Gecode { namespace Support {
 
   /**
    * \brief A fast mutex for mutual exclausion among several threads
-   * 
+   *
    * This mutex is implemeneted using spin locks on some platforms
    * and is not guaranteed to be compatible with events. It should be used
-   * for low-contention locks that are only acquired for short periods of 
+   * for low-contention locks that are only acquired for short periods of
    * time.
    *
    * It is not specified whether the mutex is recursive or not.
@@ -214,7 +214,7 @@ namespace Gecode { namespace Support {
 
   /**
    * \brief An event for synchronization
-   * 
+   *
    * An event can be waited on by a single thread until the event is
    * signalled.
    *
@@ -224,7 +224,7 @@ namespace Gecode { namespace Support {
   private:
 #ifdef GECODE_THREADS_WINDOWS
     /// The Windows specific handle to an event
-    HANDLE w_h;    
+    HANDLE w_h;
 #endif
 #ifdef GECODE_THREADS_PTHREADS
     /// The Pthread mutex
@@ -256,7 +256,16 @@ namespace Gecode { namespace Support {
    * \ingroup FuncSupportThread
    */
   class Runnable {
+  private:
+    /// Whether to delete the object when terminated
+    bool d;
   public:
+    /// Initialize, \a d defines whether object is deleted when terminated
+    Runnable(bool d=true);
+    /// Set whether to delete upon termination
+    void todelete(bool d);
+    /// Return whether to be deleted upon termination
+    bool todelete(void) const;
     /// The function that is executed when the thread starts
     virtual void run(void) = 0;
     /// Destructor
@@ -311,7 +320,7 @@ namespace Gecode { namespace Support {
      * After \a r terminates, \a r is deleted. After that, the thread
      * terminates.
      *
-     * If the operatins system does not support any threads, throws an
+     * If the operating system does not support any threads, throws an
      * exception of type Support::OperatingSystemError.
      */
     static void run(Runnable* r);
