@@ -11,8 +11,8 @@
  *     Vincent Barichard, 2012
  *
  *  Last modified:
- *     $Date: 2013-05-29 13:53:43 +0200 (Wed, 29 May 2013) $ by $Author: schulte $
- *     $Revision: 13672 $
+ *     $Date: 2017-02-17 09:01:39 +0100 (Fri, 17 Feb 2017) $ by $Author: schulte $
+ *     $Revision: 15441 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -131,7 +131,7 @@ namespace Test { namespace Assign {
 
   /** \name Collection of possible arguments for integer assignments
    *
-   * \relates IntTestSpace BoolTestSpace
+   * \relates IntTestSpace
    */
   //@{
   /// Names for integer assignments
@@ -149,6 +149,23 @@ namespace Test { namespace Assign {
   int int_val(const Gecode::Space&, Gecode::IntVar x, int) {
     return x.min();
   }
+  //@}
+
+  /** \name Collection of possible arguments for Boolean assignments
+   *
+   * \relates BoolTestSpace
+   */
+  //@{
+  /// Names for integer assignments
+  const char* bool_assign_name[] = {
+    "BOOL_ASSIGN_MIN",
+    "BOOL_ASSIGN_MAX",
+    "BOOL_ASSIGN_RND",
+    "BOOL_ASSIGN"
+  };
+  /// Number of integer value selections
+  const int n_bool_assign =
+    sizeof(bool_assign_name)/sizeof(const char*);
   /// Test function for branch value function
   int bool_val(const Gecode::Space&, Gecode::BoolVar x, int) {
     return x.min();
@@ -214,19 +231,18 @@ namespace Test { namespace Assign {
     post(*root, root->x);
     (void) root->status();
 
-    for (int val = n_int_assign; val--; ) {
+    for (int val = n_bool_assign; val--; ) {
       BoolTestSpace* clone = static_cast<BoolTestSpace*>(root->clone(false));
       Gecode::Search::Options o;
       o.a_d = Base::rand(10);
       o.c_d = Base::rand(10);
       Rnd r(1);
-      IntAssign ia;
+      BoolAssign ia;
       switch (val) {
-      case 0: ia = INT_ASSIGN_MIN(); break;
-      case 1: ia = INT_ASSIGN_MED(); break;
-      case 2: ia = INT_ASSIGN_MAX(); break;
-      case 3: ia = INT_ASSIGN_RND(r); break;
-      case 4: ia = INT_ASSIGN(&bool_val); break;
+      case 0: ia = BOOL_ASSIGN_MIN(); break;
+      case 1: ia = BOOL_ASSIGN_MAX(); break;
+      case 2: ia = BOOL_ASSIGN_RND(r); break;
+      case 3: ia = BOOL_ASSIGN(&bool_val); break;
       }
 
       assign(*clone, clone->x, ia);
@@ -310,7 +326,7 @@ namespace Test { namespace Assign {
       case 7: sa = SET_ASSIGN_RND_EXC(r); break;
       case 8: sa = SET_ASSIGN(&set_val); break;
       }
-          
+
       assign(*clone, clone->x, sa);
       Gecode::DFS<SetTestSpace> e_s(clone, o);
       delete clone;
@@ -352,7 +368,7 @@ namespace Test { namespace Assign {
   const int n_float_assign =
     sizeof(float_assign_name)/sizeof(const char*);
   /// Test function for branch value function
-  Gecode::FloatNumBranch float_val(const Gecode::Space&, 
+  Gecode::FloatNumBranch float_val(const Gecode::Space&,
                                    Gecode::FloatVar x, int) {
     Gecode::FloatNumBranch nl; nl.n=x.med(); nl.l=true;
     return nl;
@@ -385,7 +401,7 @@ namespace Test { namespace Assign {
       case 2: fa = FLOAT_ASSIGN_RND(r); break;
       case 3: fa = FLOAT_ASSIGN(&float_val); break;
       }
-          
+
       assign(*clone, clone->x, fa);
       Gecode::DFS<FloatTestSpace> e_s(clone, o);
       delete clone;
