@@ -7,8 +7,8 @@
  *     Christian Schulte, 2005
  *
  *  Last modified:
- *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10684 $
+ *     $Date: 2016-04-19 17:19:45 +0200 (Tue, 19 Apr 2016) $ by $Author: schulte $
+ *     $Revision: 14967 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -59,7 +59,7 @@ namespace Test { namespace Int {
        /// Create and register test
        IntIntVar(const std::string& s, const Gecode::IntArgs& c0,
                  int min, int max)
-         : Test("Element::Int::Int::Var::"+s,2,min,max), 
+         : Test("Element::Int::Int::Var::"+s,2,min,max),
            c(c0) {}
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
@@ -158,8 +158,8 @@ namespace Test { namespace Int {
      class VarIntVar : public Test {
      public:
        /// Create and register test
-       VarIntVar(Gecode::IntConLevel icl)
-         : Test("Element::Var::Int::Var::"+str(icl),6,-1,3,false,icl) {}
+       VarIntVar(Gecode::IntPropLevel ipl)
+         : Test("Element::Var::Int::Var::"+str(ipl),6,-1,3,false,ipl) {}
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          return (x[0]>= 0) && (x[0]<x.size()-2) && x[2+x[0]]==x[1];
@@ -169,7 +169,7 @@ namespace Test { namespace Int {
          Gecode::IntVarArgs c(x.size()-2);
          for (int i=0; i<x.size()-2; i++)
            c[i]=x[2+i];
-         Gecode::element(home, c, x[0], x[1], icl);
+         Gecode::element(home, c, x[0], x[1], ipl);
        }
      };
 
@@ -180,9 +180,9 @@ namespace Test { namespace Int {
        int r;
      public:
        /// Create and register test
-       VarIntInt(Gecode::IntConLevel icl, int r0)
-         : Test("Element::Var::Int::Int::"+str(icl)+"::"+str(r0),
-                5,-1,3,false,icl), r(r0) {
+       VarIntInt(Gecode::IntPropLevel ipl, int r0)
+         : Test("Element::Var::Int::Int::"+str(ipl)+"::"+str(r0),
+                5,-1,3,false,ipl), r(r0) {
          contest = CTL_NONE;
        }
        /// %Test whether \a x is solution
@@ -194,7 +194,7 @@ namespace Test { namespace Int {
          Gecode::IntVarArgs c(x.size()-1);
          for (int i=0; i<x.size()-1; i++)
            c[i]=x[1+i];
-         Gecode::element(home, c, x[0], r, icl);
+         Gecode::element(home, c, x[0], r, ipl);
        }
      };
 
@@ -202,8 +202,8 @@ namespace Test { namespace Int {
      class VarIntShared : public Test {
      public:
        /// Create and register test
-       VarIntShared(Gecode::IntConLevel icl)
-         : Test("Element::Var::Int::Shared::"+str(icl),5,-1,3,false,icl) {
+       VarIntShared(Gecode::IntPropLevel ipl)
+         : Test("Element::Var::Int::Shared::"+str(ipl),5,-1,3,false,ipl) {
          contest = CTL_NONE;
        }
        /// %Test whether \a x is solution
@@ -215,7 +215,7 @@ namespace Test { namespace Int {
          Gecode::IntVarArgs c(x.size()-1);
          for (int i=0; i<x.size()-1; i++)
            c[i]=x[1+i];
-         Gecode::element(home, c, x[0], x[0], icl);
+         Gecode::element(home, c, x[0], x[0], ipl);
        }
      };
 
@@ -264,7 +264,25 @@ namespace Test { namespace Int {
          BoolVarArgs c(x.size()-1);
          for (int i=0; i<x.size()-1; i++)
            c[i]=channel(home,x[1+i]);
-         element(home, c, x[0], r);
+         if (r == 1) {
+           switch (Base::rand(3)) {
+           case 0:
+             element(home, c, x[0], 1);
+             break;
+           case 1:
+             {
+               BoolVar one(home,1,1);
+               rel(home, element(c,x[0]) == one);
+             }
+             break;
+           case 2:
+             rel(home, element(c,x[0]));
+             break;
+           default: GECODE_NEVER;
+           }
+         } else {
+           element(home, c, x[0], r);
+         }
        }
      };
 
@@ -277,7 +295,7 @@ namespace Test { namespace Int {
      public:
        /// Create and register test
        MatrixIntIntVarXY(void)
-         : Test("Element::Matrix::Int::IntVar::XY",3,0,5,false), 
+         : Test("Element::Matrix::Int::IntVar::XY",3,0,5,false),
            tm(6, 0,1,2,3,4,5) {}
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
@@ -305,7 +323,7 @@ namespace Test { namespace Int {
      public:
        /// Create and register test
        MatrixIntIntVarXX(void)
-         : Test("Element::Matrix::Int::IntVar::XX",2,0,3,false), 
+         : Test("Element::Matrix::Int::IntVar::XX",2,0,3,false),
            tm(4, 0,1,2,3) {}
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
@@ -333,7 +351,7 @@ namespace Test { namespace Int {
      public:
        /// Create and register test
        MatrixIntBoolVarXY(void)
-         : Test("Element::Matrix::Int::BoolVar::XY",3,0,3,false), 
+         : Test("Element::Matrix::Int::BoolVar::XY",3,0,3,false),
            tm(4, 0,1,1,0) {}
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
@@ -361,7 +379,7 @@ namespace Test { namespace Int {
      public:
        /// Create and register test
        MatrixIntBoolVarXX(void)
-         : Test("Element::Matrix::Int::BoolVar::XX",2,0,3,false), 
+         : Test("Element::Matrix::Int::BoolVar::XX",2,0,3,false),
            tm(4, 0,1,1,0) {}
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
@@ -460,7 +478,7 @@ namespace Test { namespace Int {
          // x-coordinate: x[0], y-coordinate: x[1], result: x[2]
          using namespace Gecode;
          BoolVarArgs tm(4);
-         tm[0]=channel(home,x[3]); tm[1]=channel(home,x[4]); 
+         tm[0]=channel(home,x[3]); tm[1]=channel(home,x[4]);
          tm[2]=channel(home,x[5]); tm[3]=channel(home,x[6]);
          Matrix<BoolVarArgs> m(tm,2,2);
          element(home, m, x[0], x[1], channel(home,x[2]));
@@ -488,7 +506,7 @@ namespace Test { namespace Int {
          // x-coordinate: x[0], y-coordinate: x[1], result: x[1]
          using namespace Gecode;
          BoolVarArgs tm(4);
-         tm[0]=channel(home,x[2]); tm[1]=channel(home,x[3]); 
+         tm[0]=channel(home,x[2]); tm[1]=channel(home,x[3]);
          tm[2]=channel(home,x[4]); tm[3]=channel(home,x[5]);
          Matrix<BoolVarArgs> m(tm,2,2);
          element(home, m, x[0], x[0], channel(home,x[1]));
@@ -565,16 +583,16 @@ namespace Test { namespace Int {
            (void) new IntBoolInt("C",bc3,i);
          }
 
-         (void) new VarIntVar(ICL_BND);
-         (void) new VarIntVar(ICL_DOM);
+         (void) new VarIntVar(IPL_BND);
+         (void) new VarIntVar(IPL_DOM);
 
          for (int i=-4; i<=4; i++) {
-           (void) new VarIntInt(ICL_BND,i);
-           (void) new VarIntInt(ICL_DOM,i);
+           (void) new VarIntInt(IPL_BND,i);
+           (void) new VarIntInt(IPL_DOM,i);
          }
 
-         (void) new VarIntShared(ICL_BND);
-         (void) new VarIntShared(ICL_DOM);
+         (void) new VarIntShared(IPL_BND);
+         (void) new VarIntShared(IPL_DOM);
 
          (void) new VarBoolVar();
          (void) new VarBoolInt(0);
