@@ -7,8 +7,8 @@
  *     Christian Schulte, 2005
  *
  *  Last modified:
- *     $Date: 2011-11-29 17:20:37 +0100 (Tue, 29 Nov 2011) $ by $Author: schulte $
- *     $Revision: 12486 $
+ *     $Date: 2016-11-08 17:23:24 +0100 (Tue, 08 Nov 2016) $ by $Author: schulte $
+ *     $Revision: 15253 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -56,9 +56,9 @@ namespace Test { namespace Int {
        Gecode::IntRelType irt;
      public:
        /// Create and register test
-       IntVarXY(Gecode::IntRelType irt0, int n, Gecode::IntConLevel icl)
-         : Test("Rel::Int::Var::XY::"+str(irt0)+"::"+str(icl)+"::"+str(n),
-                n+1,-3,3,n==1,icl),
+       IntVarXY(Gecode::IntRelType irt0, int n, Gecode::IntPropLevel ipl)
+         : Test("Rel::Int::Var::XY::"+str(irt0)+"::"+str(ipl)+"::"+str(n),
+                n+1,-3,3,n==1,ipl),
            irt(irt0) {}
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
@@ -72,18 +72,18 @@ namespace Test { namespace Int {
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
          using namespace Gecode;
          if (x.size() == 2) {
-           rel(home, x[0], irt, x[1], icl);
+           rel(home, x[0], irt, x[1], ipl);
          } else {
            IntVarArgs y(2);
            y[0]=x[0]; y[1]=x[1];
-           rel(home, y, irt, x[2], icl);
+           rel(home, y, irt, x[2], ipl);
          }
        }
        /// Post reified constraint on \a x for \a r
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x,
                          Gecode::Reify r) {
          assert(x.size() == 2);
-         Gecode::rel(home, x[0], irt, x[1], r, icl);
+         Gecode::rel(home, x[0], irt, x[1], r, ipl);
        }
      };
 
@@ -94,9 +94,9 @@ namespace Test { namespace Int {
        Gecode::IntRelType irt;
      public:
        /// Create and register test
-       IntVarXX(Gecode::IntRelType irt0, Gecode::IntConLevel icl)
-         : Test("Rel::Int::Var::XX::"+str(irt0)+"::"+str(icl),
-                1,-3,3,true,icl),
+       IntVarXX(Gecode::IntRelType irt0, Gecode::IntPropLevel ipl)
+         : Test("Rel::Int::Var::XX::"+str(irt0)+"::"+str(ipl),
+                1,-3,3,true,ipl),
            irt(irt0) {
          contest = ((irt != Gecode::IRT_LE) &&
                     (irt != Gecode::IRT_GR) &&
@@ -109,12 +109,12 @@ namespace Test { namespace Int {
        }
        /// Post constraint on \a x
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
-         Gecode::rel(home, x[0], irt, x[0], icl);
+         Gecode::rel(home, x[0], irt, x[0], ipl);
        }
        /// Post reified constraint on \a x for \a r
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x,
                          Gecode::Reify r) {
-         Gecode::rel(home, x[0], irt, x[0], r, icl);
+         Gecode::rel(home, x[0], irt, x[0], r, ipl);
        }
      };
 
@@ -268,9 +268,9 @@ namespace Test { namespace Int {
        Gecode::IntRelType irt;
      public:
        /// Create and register test
-       IntSeq(int n, Gecode::IntRelType irt0, Gecode::IntConLevel icl)
-         : Test("Rel::Int::Seq::"+str(n)+"::"+str(irt0)+"::"+str(icl),
-                n,-3,3,false,icl),
+       IntSeq(int n, Gecode::IntRelType irt0, Gecode::IntPropLevel ipl)
+         : Test("Rel::Int::Seq::"+str(n)+"::"+str(irt0)+"::"+str(ipl),
+                n,-3,3,false,ipl),
            irt(irt0) {}
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
@@ -290,7 +290,7 @@ namespace Test { namespace Int {
        }
        /// Post constraint on \a x
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
-         Gecode::rel(home, x, irt, icl);
+         Gecode::rel(home, x, irt, ipl);
        }
      };
 
@@ -301,9 +301,9 @@ namespace Test { namespace Int {
        Gecode::IntRelType irt;
      public:
        /// Create and register test
-       IntSharedSeq(int n, Gecode::IntRelType irt0, Gecode::IntConLevel icl)
-         : Test("Rel::Int::Seq::Shared::"+str(n)+"::"+str(irt0)+"::"+str(icl),
-                n,-3,3,false,icl),
+       IntSharedSeq(int n, Gecode::IntRelType irt0, Gecode::IntPropLevel ipl)
+         : Test("Rel::Int::Seq::Shared::"+str(n)+"::"+str(irt0)+"::"+str(ipl),
+                n,-3,3,false,ipl),
            irt(irt0) {}
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
@@ -327,9 +327,9 @@ namespace Test { namespace Int {
          using namespace Gecode;
          int n = x.size();
          IntVarArgs y(2*n);
-         for (int i=n; i--; ) 
+         for (int i=n; i--; )
            y[i] = y[n+i] = x[i];
-         rel(home, y, irt, icl);
+         rel(home, y, irt, ipl);
        }
      };
 
@@ -408,14 +408,14 @@ namespace Test { namespace Int {
      };
 
      /// %Test for relation between same sized arrays of integer variables
-     class IntArray : public Test {
+     class IntArrayVar : public Test {
      protected:
        /// Integer relation type to propagate
        Gecode::IntRelType irt;
      public:
        /// Create and register test
-       IntArray(Gecode::IntRelType irt0)
-         : Test("Rel::Int::Array::"+str(irt0),6,-2,2), irt(irt0) {}
+       IntArrayVar(Gecode::IntRelType irt0)
+         : Test("Rel::Int::Array::Var::"+str(irt0),6,-2,2), irt(irt0) {}
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          int n=x.size() >> 1;
@@ -439,6 +439,35 @@ namespace Test { namespace Int {
        }
      };
 
+     /// %Test for relation between same sized arrays of integer variables and integers
+     class IntArrayInt : public Test {
+     protected:
+       /// Integer relation type to propagate
+       Gecode::IntRelType irt;
+     public:
+       /// Create and register test
+       IntArrayInt(Gecode::IntRelType irt0)
+         : Test("Rel::Int::Array::Int::"+str(irt0),3,-2,2), irt(irt0) {}
+       /// %Test whether \a x is solution
+       virtual bool solution(const Assignment& x) const {
+         Gecode::IntArgs y(3, 0,0,0);
+         int n=x.size();
+         for (int i=0; i<n; i++)
+           if (x[i] != y[i])
+             return cmp(x[i],irt,y[i]);
+         return ((irt == Gecode::IRT_LQ) || (irt == Gecode::IRT_GQ) ||
+                 (irt == Gecode::IRT_EQ));
+         GECODE_NEVER;
+         return false;
+       }
+       /// Post constraint on \a x
+       virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
+         using namespace Gecode;
+         IntArgs y(3, 0,0,0);
+         rel(home, x, irt, y);
+       }
+     };
+
      /// %Test for relation between differently sized arrays of integer variables
      class IntArrayDiff : public Test {
      protected:
@@ -452,7 +481,7 @@ namespace Test { namespace Int {
        /// Create and register test
        IntArrayDiff(Gecode::IntRelType irt0, int m)
          : Test("Rel::Int::Array::"+str(irt0)+"::"+str(m)+"::"+str(n-m),
-                n,-2,2), 
+                n,-2,2),
            irt(irt0), n_fst(m) {
          assert(n_fst <= n);
        }
@@ -480,14 +509,14 @@ namespace Test { namespace Int {
      };
 
      /// %Test for relation between arrays of Boolean variables
-     class BoolArray : public Test {
+     class BoolArrayVar : public Test {
      protected:
        /// Integer relation type to propagate
        Gecode::IntRelType irt;
      public:
        /// Create and register test
-       BoolArray(Gecode::IntRelType irt0)
-         : Test("Rel::Bool::Array::"+str(irt0),10,0,1), irt(irt0) {}
+       BoolArrayVar(Gecode::IntRelType irt0)
+         : Test("Rel::Bool::Array::Var::"+str(irt0),10,0,1), irt(irt0) {}
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          int n=x.size() >> 1;
@@ -511,6 +540,38 @@ namespace Test { namespace Int {
        }
      };
 
+     /// %Test for relation between arrays of Boolean variables and integers
+     class BoolArrayInt : public Test {
+     protected:
+       /// Integer relation type to propagate
+       Gecode::IntRelType irt;
+     public:
+       /// Create and register test
+       BoolArrayInt(Gecode::IntRelType irt0)
+         : Test("Rel::Bool::Array::Int::"+str(irt0),5,0,1), irt(irt0) {}
+       /// %Test whether \a x is solution
+       virtual bool solution(const Assignment& x) const {
+         Gecode::IntArgs y(5, 0,0,1,0,0);
+         for (int i=0; i<5; i++)
+           if (x[i] != y[i])
+             return cmp(x[i],irt,y[i]);
+         return ((irt == Gecode::IRT_LQ) || (irt == Gecode::IRT_GQ) ||
+                 (irt == Gecode::IRT_EQ));
+         GECODE_NEVER;
+         return false;
+       }
+       /// Post constraint on \a x
+       virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
+         using namespace Gecode;
+         Gecode::IntArgs z(5, 0,0,1,0,0);
+         int n=x.size();
+         BoolVarArgs y(n);
+         for (int i=0; i<n; i++)
+           y[i]=channel(home,x[i]);
+         rel(home, y, irt, z);
+       }
+     };
+
      /// Help class to create and register tests
      class Create {
      public:
@@ -518,18 +579,18 @@ namespace Test { namespace Int {
        Create(void) {
          using namespace Gecode;
          for (IntRelTypes irts; irts(); ++irts) {
-           for (IntConLevels icls; icls(); ++icls) {
-             (void) new IntVarXY(irts.irt(),1,icls.icl());
-             (void) new IntVarXY(irts.irt(),2,icls.icl());
-             (void) new IntVarXX(irts.irt(),icls.icl());
-             (void) new IntSeq(1,irts.irt(),icls.icl());
-             (void) new IntSeq(2,irts.irt(),icls.icl());
-             (void) new IntSeq(3,irts.irt(),icls.icl());
-             (void) new IntSeq(5,irts.irt(),icls.icl());
-             (void) new IntSharedSeq(1,irts.irt(),icls.icl());
-             (void) new IntSharedSeq(2,irts.irt(),icls.icl());
-             (void) new IntSharedSeq(3,irts.irt(),icls.icl());
-             (void) new IntSharedSeq(4,irts.irt(),icls.icl());
+           for (IntPropLevels ipls; ipls(); ++ipls) {
+             (void) new IntVarXY(irts.irt(),1,ipls.ipl());
+             (void) new IntVarXY(irts.irt(),2,ipls.ipl());
+             (void) new IntVarXX(irts.irt(),ipls.ipl());
+             (void) new IntSeq(1,irts.irt(),ipls.ipl());
+             (void) new IntSeq(2,irts.irt(),ipls.ipl());
+             (void) new IntSeq(3,irts.irt(),ipls.ipl());
+             (void) new IntSeq(5,irts.irt(),ipls.ipl());
+             (void) new IntSharedSeq(1,irts.irt(),ipls.ipl());
+             (void) new IntSharedSeq(2,irts.irt(),ipls.ipl());
+             (void) new IntSharedSeq(3,irts.irt(),ipls.ipl());
+             (void) new IntSharedSeq(4,irts.irt(),ipls.ipl());
            }
            (void) new BoolVarXY(irts.irt(),1);
            (void) new BoolVarXY(irts.irt(),2);
@@ -551,10 +612,12 @@ namespace Test { namespace Int {
              (void) new BoolInt(irts.irt(),1,c);
              (void) new BoolInt(irts.irt(),2,c);
            }
-           (void) new IntArray(irts.irt());
+           (void) new IntArrayVar(irts.irt());
+           (void) new IntArrayInt(irts.irt());
            for (int n_fst=0; n_fst<=4; n_fst++)
              (void) new IntArrayDiff(irts.irt(),n_fst);
-           (void) new BoolArray(irts.irt());
+           (void) new BoolArrayVar(irts.irt());
+           (void) new BoolArrayInt(irts.irt());
          }
        }
      };
