@@ -7,8 +7,8 @@
  *     Guido Tack, 2005
  *
  *  Last modified:
- *     $Date: 2014-04-29 08:01:25 +0200 (Tue, 29 Apr 2014) $ by $Author: schulte $
- *     $Revision: 14117 $
+ *     $Date: 2016-12-02 13:20:09 +0100 (Fri, 02 Dec 2016) $ by $Author: schulte $
+ *     $Revision: 15304 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -35,6 +35,8 @@
  *
  */
 
+#include <gecode/minimodel.hh>
+
 #include "test/set.hh"
 
 using namespace Gecode;
@@ -51,6 +53,7 @@ namespace Test { namespace Set {
     //@{
 
     static IntSet ds_33(-3,3);
+    static IntSet ds_03(0,3);
 
     /// %Test for binary set relation constraint
     class RelBin : public SetTest {
@@ -89,12 +92,12 @@ namespace Test { namespace Set {
         switch (srt) {
         case SRT_EQ: return Iter::Ranges::equal(xr0, xr1);
         case SRT_NQ: return !Iter::Ranges::equal(xr0, xr1);
-        
+
         case SRT_LQ: return (!xr0()) || in(minSymDiff(x),xr1,true);
         case SRT_LE: return xr0() ? in(minSymDiff(x),xr1) : xr1();
         case SRT_GQ: return (!xr1()) || in(minSymDiff(x),xr0,true);
         case SRT_GR: return xr1() ? in(minSymDiff(x),xr0) : xr0();
-        
+
         case SRT_SUB: return Iter::Ranges::subset(xr0, xr1);
         case SRT_SUP: return Iter::Ranges::subset(xr1, xr0);
         case SRT_DISJ:
@@ -129,6 +132,33 @@ namespace Test { namespace Set {
           Gecode::rel(home, x[0], srt, x[0], r);
       }
     };
+
+    /// %Test for if-then-else-constraint
+    class ITE : public SetTest {
+    public:
+      /// Construct and register test
+      ITE(void)
+        : SetTest("ITE",3,ds_03,false,1) {}
+      /// Check whether \a x is a solution
+      virtual bool solution(const SetAssignment& x) const {
+        if ((x.intval() < 0) || (x.intval() > 1))
+          return false;
+        if (x.intval() == 1) {
+          CountableSetRanges xr0(x.lub, x[0]);
+          CountableSetRanges xr2(x.lub, x[2]);
+          return Iter::Ranges::equal(xr0,xr2);
+        } else {
+          CountableSetRanges xr1(x.lub, x[1]);
+          CountableSetRanges xr2(x.lub, x[2]);
+          return Iter::Ranges::equal(xr1,xr2);
+        }
+      }
+      /// Post constraint on \a x and \a y
+      void post(Space& home, SetVarArray& x, IntVarArray& y) {
+        Gecode::ite(home, Gecode::channel(home,y[0]), x[0], x[1], x[2]);
+      }
+    };
+
     RelBin _relbin_eq(Gecode::SRT_EQ,false);
     RelBin _relbin_lq(Gecode::SRT_LQ,false);
     RelBin _relbin_le(Gecode::SRT_LE,false);
@@ -150,6 +180,7 @@ namespace Test { namespace Set {
     RelBin _relbin_shared_disj(Gecode::SRT_DISJ,true);
     RelBin _relbin_shared_cmpl(Gecode::SRT_CMPL,true);
 
+    ITE _ite;
     //@}
 
 }}}
